@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,19 +13,32 @@
 #include "btbookshelfmodel.h"
 
 #include <QIcon>
+#include <QSet>
+#include <QtAlgorithms>
+#include <QtGlobal>
 #include "../../util/btassert.h"
 #include "../../util/btconnect.h"
 #include "../../util/macros.h"
+#include "../drivers/cswordmoduleinfo.h"
+#include "../drivers/btconstmoduleset.h"
 
 
-int BtBookshelfModel::rowCount(const QModelIndex & parent) const {
+BtBookshelfModel::BtBookshelfModel(ConstructInPrivate const &) {}
+
+std::shared_ptr<BtBookshelfModel> BtBookshelfModel::newInstance()
+{ return std::make_shared<BtBookshelfModel>(ConstructInPrivate()); }
+
+BtBookshelfModel::~BtBookshelfModel() noexcept = default;
+
+int BtBookshelfModel::rowCount(QModelIndex const & parent) const {
     if (parent.isValid())
         return 0;
 
     return m_data.size();
 }
 
-QVariant BtBookshelfModel::data(CSwordModuleInfo * module, int role) const {
+QVariant BtBookshelfModel::data(CSwordModuleInfo * module, int const role) const
+{
     BT_ASSERT(module);
     switch (role) {
         case Qt::DisplayRole:
@@ -47,11 +60,11 @@ QVariant BtBookshelfModel::data(CSwordModuleInfo * module, int role) const {
         case ModuleHasIndexRole:
             return module->hasIndex();
         case ModuleIndexSizeRole:
-            return static_cast<qulonglong>(module->indexSize());
+            return module->indexSize();
         case ModuleDescriptionRole:
             return module->config(CSwordModuleInfo::Description);
         case Qt::ToolTipRole:
-            return QString("<b>%1:</b><br/>%2")
+            return QStringLiteral("<b>%1:</b><br/>%2")
                        .arg(module->name())
                        .arg(module->config(CSwordModuleInfo::Description));
         default:
@@ -59,20 +72,21 @@ QVariant BtBookshelfModel::data(CSwordModuleInfo * module, int role) const {
     }
 }
 
-QVariant BtBookshelfModel::data(const QModelIndex &index, int role) const {
+QVariant BtBookshelfModel::data(QModelIndex const & index, int const role) const
+{
     if (!index.isValid() || index.column() != 0 || index.parent().isValid())
         return QVariant();
 
-    int row = index.row();
+    int const row = index.row();
     if (row >= m_data.size())
         return QVariant();
 
     return data(m_data.at(row), role);
 }
 
-QVariant BtBookshelfModel::headerData(int section,
-                                      Qt::Orientation orientation,
-                                      int role) const
+QVariant BtBookshelfModel::headerData(int const section,
+                                      Qt::Orientation const orientation,
+                                      int const role) const
 {
     if (role == Qt::DisplayRole
        && orientation == Qt::Horizontal
@@ -84,11 +98,11 @@ QVariant BtBookshelfModel::headerData(int section,
     return QVariant();
 }
 
-bool BtBookshelfModel::setData(const QModelIndex & index,
-                               const QVariant & value,
-                               int role)
+bool BtBookshelfModel::setData(QModelIndex const & index,
+                               QVariant const & value,
+                               int const role)
 {
-    int row = index.row();
+    int const row = index.row();
     if (role == ModuleHiddenRole
         && row >= 0
         && row < m_data.size()
@@ -105,7 +119,7 @@ bool BtBookshelfModel::setData(const QModelIndex & index,
     return false;
 }
 
-void BtBookshelfModel::clear(bool destroy) {
+void BtBookshelfModel::clear(bool const destroy) {
     if (m_data.size() <= 0)
         return;
 
@@ -134,32 +148,8 @@ void BtBookshelfModel::addModule(CSwordModuleInfo * const module) {
     endInsertRows();
 }
 
-void BtBookshelfModel::addModules(BtModuleSet const & modules) {
-    QList<CSwordModuleInfo *> newModules;
-    Q_FOREACH(CSwordModuleInfo * const module, modules)
-        if (!m_data.contains(module))
-            newModules.append(module);
-
-    if (newModules.isEmpty())
-        return;
-
-    beginInsertRows(QModelIndex(),
-                    m_data.size(),
-                    m_data.size() + newModules.size() - 1);
-    Q_FOREACH(CSwordModuleInfo * const module, newModules) {
-        m_data.append(module);
-        BT_CONNECT(module, &CSwordModuleInfo::hiddenChanged,
-                   this,   &BtBookshelfModel::moduleHidden);
-        BT_CONNECT(module, &CSwordModuleInfo::hasIndexChanged,
-                   this,   &BtBookshelfModel::moduleIndexed);
-        BT_CONNECT(module, &CSwordModuleInfo::unlockedChanged,
-                   this,   &BtBookshelfModel::moduleUnlocked);
-    }
-    endInsertRows();
-}
-
 void BtBookshelfModel::removeModule(CSwordModuleInfo * const module,
-                                    bool destroy) {
+                                    bool const destroy) {
     const int index = m_data.indexOf(module);
     if (index == -1)
         return;
@@ -177,8 +167,8 @@ void BtBookshelfModel::removeModule(CSwordModuleInfo * const module,
         delete module;
 }
 
-void BtBookshelfModel::removeModules(const QList<CSwordModuleInfo *> & modules,
-                                     bool destroy)
+void BtBookshelfModel::removeModules(QList<CSwordModuleInfo *> const & modules,
+                                     bool const destroy)
 {
     QSet<CSwordModuleInfo *> moduleSet;
     for (auto module: modules)
@@ -186,14 +176,16 @@ void BtBookshelfModel::removeModules(const QList<CSwordModuleInfo *> & modules,
     removeModules(moduleSet, destroy);
 }
 
-void BtBookshelfModel::removeModules(BtConstModuleSet const & modules, bool destroy){
+void BtBookshelfModel::removeModules(BtConstModuleSet const & modules,
+                                     bool const destroy)
+{
     // This is inefficient, since signals are emitted for each removed module:
-    Q_FOREACH(CSwordModuleInfo const * const module, modules)
+    for (auto const * const module : modules)
         removeModule(const_cast<CSwordModuleInfo *>(module), destroy);
 }
 
-CSwordModuleInfo * BtBookshelfModel::getModule(const QString & name) const {
-    Q_FOREACH(CSwordModuleInfo * const module, m_data)
+CSwordModuleInfo * BtBookshelfModel::getModule(QString const & name) const {
+    for (auto * const module : m_data)
         if (UNLIKELY(module->name() == name))
             return module;
     return nullptr;
@@ -221,5 +213,5 @@ void BtBookshelfModel::moduleDataChanged(CSwordModuleInfo * module) {
     BT_ASSERT(m_data.count(module) == 1);
 
     QModelIndex i(index(m_data.indexOf(module), 0));
-    emit dataChanged(i, i);
+    Q_EMIT dataChanged(i, i);
 }
