@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,11 +12,14 @@
 
 #include "categoryitem.h"
 
+#include <QIcon>
+#include "../drivers/cswordmoduleinfo.h"
+
 
 namespace BookshelfModel {
 
 
-QVariant CategoryItem::data(int role) const {
+QVariant CategoryItem::data(int const role) const {
     switch (role) {
 
         case Qt::DisplayRole:
@@ -31,11 +34,11 @@ QVariant CategoryItem::data(int role) const {
     }
 }
 
-bool CategoryItem::operator<(const Item & other) const {
+bool CategoryItem::operator<(Item const & other) const {
     if (other.type() != ITEM_CATEGORY)
         return ITEM_CATEGORY < other.type();
 
-    const CategoryItem & o = static_cast<const CategoryItem &>(other);
+    auto & o = static_cast<CategoryItem const &>(other);
     if (m_category == CSwordModuleInfo::UnknownCategory)
         return false;
     if (o.m_category == CSwordModuleInfo::UnknownCategory)
