@@ -2,19 +2,20 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef INDEXINGITEM_H
-#define INDEXINGITEM_H
+#pragma once
 
 #include "item.h"
 
+#include <Qt>
+#include <QVariant>
 #include "../drivers/cswordmoduleinfo.h"
 
 
@@ -22,23 +23,20 @@ namespace BookshelfModel {
 
 class IndexingItem: public GroupItem<Item::ITEM_INDEXING> {
 
-public: /* Methods: */
+public: // methods:
 
-    inline IndexingItem(const CSwordModuleInfo & module)
+    IndexingItem(CSwordModuleInfo const & module)
         : m_indexed(module.hasIndex()) {}
 
     QVariant data(int role = Qt::DisplayRole) const override;
 
-    inline bool fitFor(const CSwordModuleInfo & module) const override {
-        return module.hasIndex() == m_indexed;
-    }
+    bool fitFor(CSwordModuleInfo const & module) const override
+    { return module.hasIndex() == m_indexed; }
 
-private: /* Fields: */
+private: // fields:
 
     bool m_indexed;
 
 };
 
 } // namespace BookshelfModel
-
-#endif // INDEXINGITEM_H
