@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,6 +12,9 @@
 
 #include "item.h"
 
+#include <QtAlgorithms>
+#include <QString>
+#include "../../util/btassert.h"
 #include "btbookshelfmodel.h"
 
 
@@ -21,17 +24,15 @@ Item::~Item() {
     qDeleteAll(m_children);
 }
 
-int Item::indexFor(Item * newItem) {
-    BT_ASSERT(newItem);
-
+int Item::indexFor(Item const & newItem) {
     if (m_children.empty())
         return 0;
 
     int i = 0;
     for (;;) {
-        Item * const nextItem(m_children.at(i));
-        BT_ASSERT(nextItem->type() == newItem->type());
-        if (*newItem < *nextItem)
+        auto const & nextItem = *m_children.at(i);
+        BT_ASSERT(nextItem.type() == newItem.type());
+        if (newItem < nextItem)
             return i;
 
         i++;
@@ -40,7 +41,7 @@ int Item::indexFor(Item * newItem) {
     }
 }
 
-QVariant Item::data(int role) const {
+QVariant Item::data(int const role) const {
     switch (role) {
 
         case Qt::CheckStateRole:
@@ -50,7 +51,7 @@ QVariant Item::data(int role) const {
             if (m_children.empty())
                 return true;
 
-            Q_FOREACH(Item const * const child, m_children)
+            for (auto const * const child : m_children)
                 if (!child->data(role).toBool())
                     return false;
             return true;
@@ -61,15 +62,15 @@ QVariant Item::data(int role) const {
     }
 }
 
-bool Item::operator<(const Item & other) const {
+bool Item::operator<(Item const & other) const {
     if (m_type != other.type())
         return m_type < other.type();
 
-    const QString first(data(Qt::DisplayRole).toString().toLower());
-    const QString second(other.data(Qt::DisplayRole).toString().toLower());
+    auto const first(data(Qt::DisplayRole).toString().toLower());
+    auto const second(other.data(Qt::DisplayRole).toString().toLower());
     return first.localeAwareCompare(second) < 0;
 }
 
-bool RootItem::fitFor(const CSwordModuleInfo &) const { return true; }
+bool RootItem::fitFor(CSwordModuleInfo const &) const { return true; }
 
 } // namespace BookshelfModel
