@@ -2,44 +2,44 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef LANGUAGEITEM_H
-#define LANGUAGEITEM_H
+#pragma once
 
 #include "item.h"
 
+#include <Qt>
+#include <QVariant>
+#include <memory>
 #include "../drivers/cswordmoduleinfo.h"
-#include "btbookshelfmodel.h"
 
 
+class Language;
+
 namespace BookshelfModel {
 
 class LanguageItem: public GroupItem<Item::ITEM_LANGUAGE> {
 
-public: /* Methods: */
+public: // methods:
 
-    inline LanguageItem(const CSwordModuleInfo & module)
+    LanguageItem(CSwordModuleInfo const & module)
         : m_language(module.language()) {}
 
     QVariant data(int role = Qt::DisplayRole) const override;
 
-    inline bool fitFor(const CSwordModuleInfo & module) const override {
-        return module.language() == m_language;
-    }
+    bool fitFor(CSwordModuleInfo const & module) const override
+    { return module.language() == m_language; }
 
-private: /* Fields: */
+private: // fields:
 
-    const CLanguageMgr::Language * m_language;
+    std::shared_ptr<Language const> m_language;
 
 };
 
 } // namespace BookshelfModel
-
-#endif // LANGUAGEITEM_H
