@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -24,16 +24,20 @@
 
 #include <algorithm>
 #include <memory>
+#include <QDir>
 #include <QDomElement>
 #include <QDomNode>
 #include <QFile>
 #include <QIODevice>
 #include <QList>
 #include <QString>
-#include <QTextCodec>
+#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    #include <QTextCodec>
+#endif
 #include <QTextStream>
 #include <QTime>
 #include <QTimer>
+#include <utility>
 #include "../util/btassert.h"
 #include "../util/btconnect.h"
 #include "../util/cresmgr.h"
@@ -50,238 +54,210 @@
 
 
 namespace {
+
 inline QString toHeader(QString const & key, QString const & moduleName)
-{ return QString::fromLatin1("%1 (%2)").arg(key).arg(moduleName); }
+{ return QStringLiteral("%1 (%2)").arg(key).arg(moduleName); }
+
+class BookmarkFolder;
+
+class BookmarkItemBase {
+
+public: // methods:
+
+    BookmarkItemBase(BookmarkFolder * parent = nullptr);
+
+    BookmarkItemBase(const BookmarkItemBase & other)
+        : m_parent(other.m_parent)
+        , m_text(other.m_text)
+    {}
+
+    virtual ~BookmarkItemBase() {}
+
+    void setText(QString const & text) { m_text = text; }
+
+    QString const & text() const { return m_text; }
+
+    virtual QString toolTip() const { return {}; }
+
+    virtual Qt::ItemFlags flags() const noexcept { return Qt::NoItemFlags; }
+
+    virtual QIcon const & icon() const noexcept {
+        static QIcon const noIcon;
+        return noIcon;
+    }
+
+    void setParent(BookmarkFolder * parent) { m_parent = parent; }
+
+    BookmarkFolder * parent() const { return m_parent; }
+
+    /** \returns index of this item in parent's child array. */
+    int index() const;
+
+private:
+
+    BookmarkFolder * m_parent;
+    QString m_text;
+
+};
+
+class BookmarkItem final : public BookmarkItemBase {
+public:
+
+    BookmarkItem(BookmarkFolder * parent);
+
+    /** Creates a bookmark with module, key and description. */
+    BookmarkItem(const CSwordModuleInfo & module, const QString & key,
+                 const QString & description, const QString & title);
+
+    /** Creates a copy. */
+    BookmarkItem(const BookmarkItem & other);
+
+    Qt::ItemFlags flags() const noexcept final override {
+        return Qt::ItemIsSelectable // | Qt::ItemIsEditable
+               | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled
+               | Qt::ItemIsEnabled;
+    }
+
+    QIcon const & icon() const noexcept final override
+    { return CResMgr::mainIndex::bookmark::icon(); }
+
+    /** Returns the used module, 0 if there is no such module. */
+    CSwordModuleInfo * module() const;
+
+    /** Returns the used key. */
+    QString key() const;
+
+    void setKey(QString const & key) { m_key = key; }
+
+    /** Returns the used description. */
+    QString const & description() const { return m_description; }
+
+    void setDescription(QString const & description)
+    { m_description = description; }
+
+    /** Returns a tooltip for this bookmark. */
+    QString toolTip() const override;
+
+    /** Returns the english key.*/
+    QString const & englishKey() const { return m_key; }
+
+    void setModule(QString const & moduleName)
+    { m_moduleName = moduleName; }
+
+    QString const & moduleName() const { return m_moduleName; }
+
+private:
+    QString m_key;
+    QString m_description;
+    QString m_moduleName;
+
+};
+
+class BookmarkFolder final : public BookmarkItemBase {
+public:
+
+    BookmarkFolder(const QString & name, BookmarkFolder * parent = nullptr);
+
+    ~BookmarkFolder() final override { qDeleteAll(m_children); }
+
+    Qt::ItemFlags flags() const noexcept final override {
+        return Qt::ItemIsSelectable | Qt::ItemIsEditable
+               | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled
+               | Qt::ItemIsEnabled;
+    }
+
+    QIcon const & icon() const noexcept final override
+    { return CResMgr::mainIndex::closedFolder::icon(); }
+
+    /** Children routines. */
+    void addChild(BookmarkItemBase * child) {
+        child->setParent(this);
+        BT_ASSERT(!m_children.contains(child));
+        m_children.append(child);
+    }
+
+    QList<BookmarkItemBase *> & children() noexcept { return m_children; }
+    QList<BookmarkItemBase *> const & children() const noexcept
+    { return m_children; }
+
+    void insertChild(int index, BookmarkItemBase * child) {
+        child->setParent(this);
+        BT_ASSERT(!m_children.contains(child));
+        m_children.insert(index, child);
+    }
+
+    void insertChildren(int index, QList<BookmarkItemBase *> children) {
+        for (auto * const c : children)
+            insertChild(index++, c);
+    }
+
+    void removeChild(int index) {
+        delete m_children[index];
+        m_children.removeAt(index);
+    }
+
+    /** Returns true if the given item is this or a direct or indirect subitem of this. */
+    bool hasDescendant(BookmarkItemBase const * item) const;
+
+    /** Creates a deep copy of this item. */
+    BookmarkFolder * deepCopy() const;
+
+private: // Fields:
+
+    QList<BookmarkItemBase *> m_children;
+
+};
+
+
+BookmarkItemBase::BookmarkItemBase(BookmarkFolder * parent)
+    : m_parent(parent)
+{
+    if (m_parent)
+        m_parent->addChild(this);
+}
+
+int BookmarkItemBase::index() const {
+    BT_ASSERT(m_parent);
+    return m_parent->children().indexOf(
+        const_cast<BookmarkItemBase *>(this));
+}
+
 }
 
 class BtBookmarksModelPrivate {
 
-public: /* Tyepes */
-
-    class BookmarkItemBase {
-
-    public: /* Methods: */
-
-        inline BookmarkItemBase(BookmarkItemBase * parent = nullptr)
-            : m_parent(parent) {
-            if(m_parent) {
-                BT_ASSERT(!m_parent->m_children.contains(this));
-                m_parent->m_children.append(this);
-            }
-        }
-        BookmarkItemBase(const BookmarkItemBase & other)
-            : m_flags(other.m_flags)
-            , m_icon(other.m_icon)
-            , m_parent(other.m_parent)
-            , m_text(other.m_text)
-            , m_tooltip(other.m_tooltip) {;}
-        virtual ~BookmarkItemBase() {
-            qDeleteAll(m_children);
-        }
-
-        /** Children routines. */
-        inline void addChild(BookmarkItemBase * child) {
-            child->setParent(this);
-            BT_ASSERT(!m_children.contains(child));
-            m_children.append(child);
-        }
-
-        inline int childCount() const { return m_children.size(); }
-
-        inline BookmarkItemBase * child(int index) const {
-            return m_children[index];
-        }
-
-        inline QList<BookmarkItemBase *> & children() {
-            return m_children;
-        }
-
-        inline void insertChild(int index, BookmarkItemBase * child) {
-            child->setParent(this);
-            BT_ASSERT(!m_children.contains(child));
-            m_children.insert(index, child);
-        }
-
-        inline void insertChildren(int index, QList<BookmarkItemBase *> children) {
-            Q_FOREACH(BookmarkItemBase * const c, children)
-                insertChild(index++, c);
-        }
-
-        inline void removeChild(int index) {
-            delete m_children[index];
-            m_children.removeAt(index);
-        }
-
-
-        inline void setText(const QString & text) { m_text = text; }
-
-        inline const QString & text() const { return m_text; }
-
-        inline void setToolTip(const QString & tooltip) { m_tooltip = tooltip; }
-
-        virtual QString toolTip() const { return m_tooltip; }
-
-        inline void setFlags(Qt::ItemFlags flags) { m_flags = flags; }
-
-        inline Qt::ItemFlags flags() const { return m_flags; }
-
-        inline void setIcon(const QIcon & icon) { m_icon = icon; }
-
-        inline QIcon icon() const { return m_icon; }
-
-        inline void setParent(BookmarkItemBase * parent) {
-            m_parent = parent;
-        }
-
-        inline BookmarkItemBase * parent() const { return m_parent; }
-
-        /**
-          \returns index of this item in parent's child array.
-         */
-        inline int index() const {
-            BT_ASSERT(parent());
-            for(int i = 0; i < parent()->childCount(); ++i)
-                if(parent()->child(i) == this)
-                    return i;
-            return -1;
-        }
-
-    private:
-
-        QList<BookmarkItemBase *> m_children;
-        Qt::ItemFlags m_flags;
-        QIcon m_icon;
-        BookmarkItemBase * m_parent;
-        QString m_text;
-        QString m_tooltip;
-
-    };
-
-    class BookmarkItem : public BookmarkItemBase {
-    public:
-        friend class BookmarkLoader;
-
-        BookmarkItem(BookmarkItemBase * parent);
-
-        /** Creates a bookmark with module, key and description. */
-        BookmarkItem(const CSwordModuleInfo & module, const QString & key,
-                       const QString & description, const QString & title);
-
-        /** Creates a copy. */
-        BookmarkItem(const BookmarkItem & other);
-
-        /** Returns the used module, 0 if there is no such module. */
-        CSwordModuleInfo * module() const;
-
-        /** Returns the used key. */
-        QString key() const;
-
-        inline void setKey(const QString & key) { m_key = key; }
-
-        /** Returns the used description. */
-        inline const QString &description() const { return m_description; }
-
-        inline void setDescription(const QString & description) { m_description = description; }
-
-        /** Returns a tooltip for this bookmark. */
-        QString toolTip() const override;
-
-        /** Returns the english key.*/
-        inline const QString & englishKey() const { return m_key; }
-
-        inline void setModule(const QString & moduleName) { m_moduleName = moduleName; }
-
-        inline const QString & moduleName() const { return m_moduleName; }
-
-    private:
-        QString m_key;
-        QString m_description;
-        QString m_moduleName;
-
-    };
-
-    class BookmarkFolder : public BookmarkItemBase {
-    public:
-
-        BookmarkFolder(const QString & name, BookmarkItemBase * parent = nullptr);
-
-        /** Returns a list of direct childs of this item. */
-        QList<BookmarkItemBase *> getChildList() const;
-
-        /** Returns true if the given item is this or a direct or indirect subitem of this. */
-        bool hasDescendant(BookmarkItemBase const * item) const;
-
-        /** Creates a deep copy of this item. */
-        BookmarkFolder * deepCopy() const;
-
-    };
-
-
-public: /* Methods */
+public: // methods:
 
     BtBookmarksModelPrivate(BtBookmarksModel * parent)
-        : m_rootItem(new BookmarkFolder("Root"))
+        : m_rootItem(new BookmarkFolder(QStringLiteral("Root")))
         , q_ptr(parent)
     {
-        m_saveTimer.setInterval(0.5 * 60 * 1000);
+        m_saveTimer.setInterval(30 * 1000);
         m_saveTimer.setSingleShot(true);
     }
     ~BtBookmarksModelPrivate() { delete m_rootItem; }
 
-    inline static QString defaultBookmarksFile() {
-        return util::directory::getUserBaseDir().absolutePath() + "/bookmarks.xml";
+    static QString defaultBookmarksFile() {
+        return util::directory::getUserBaseDir().absolutePath()
+                + QStringLiteral("/bookmarks.xml");
     }
 
     BookmarkItemBase * item(const QModelIndex & index) const {
-        if(index.isValid()) {
-#ifdef QT_DEBUG
-            {
-                // check for item in tree
-                QList<BookmarkItemBase *> items;
-                items << m_rootItem;
-                for(int c = 0; ; ++c) {
-                    if(items[c] == index.internalPointer())
-                        break;
-                    if(items[c]->childCount())
-                        items.append(items[c]->children());
-                    BT_ASSERT(c < items.size());
-                }
-            }
-#endif
-            return reinterpret_cast<BookmarkItemBase *>(index.internalPointer());
-        }
-        else
-            return m_rootItem;
+        if (index.isValid())
+            return static_cast<BookmarkItemBase *>(index.internalPointer());
+        return m_rootItem;
     }
 
     template <typename T>
-    inline T * itemAs(QModelIndex const & index) const
+    T * itemAs(QModelIndex const & index) const
     { return dynamic_cast<T *>(item(index)); }
 
-    /// \test
-    void printItems() const {
-        QList<BookmarkItemBase *> items;
-        QList<int> spaces;
-        items << m_rootItem;
-        spaces << 0;
-        for(int c = 0; c < items.size(); ++c) {
-            // qDebug() << QString().fill('\t', spaces[c]) << items[c]->text().left(24) << items[c]
-            //       << items[c]->parent() << items[c]->childCount();
-            if(items[c]->childCount())
-                for(int i = 0; i < items[c]->childCount(); ++i) {
-                    items.insert(c + i + 1, items[c]->children()[i]);
-                    spaces.insert(c + i + 1, spaces[c] + 1);
-                }
-        }
-    }
-
     void needSave(){
         if(m_defaultModel == q_ptr){
             if(!m_saveTimer.isActive())
                 m_saveTimer.start();
         }
     }
-public: /* Loader */
 
     /** Loads a list of items (with subitem trees) from a named file
     * or from the default bookmarks file. */
@@ -295,7 +271,7 @@ public: /* Loader */
 
         doc.setContent(bookmarksFile);
         QDomElement document = doc.documentElement();
-        if ( document.tagName() != "SwordBookmarks" ) {
+        if (document.tagName() != QStringLiteral("SwordBookmarks")) {
             qWarning("Not a BibleTime Bookmark XML file");
             return QList<BookmarkItemBase*>();
         }
@@ -318,151 +294,153 @@ public: /* Loader */
     }
 
     /** Create a new item from a document element. */
-    BookmarkItemBase * handleXmlElement(QDomElement & element, BookmarkItemBase * parent) {
-        BookmarkItemBase* newItem = nullptr;
-        if (element.tagName() == "Folder") {
+    BookmarkItemBase * handleXmlElement(QDomElement & element, BookmarkFolder * parent) {
+        if (element.tagName() == QStringLiteral("Folder")) {
             BookmarkFolder* newFolder = new BookmarkFolder(QString(), parent);
-            if (element.hasAttribute("caption")) {
-                newFolder->setText(element.attribute("caption"));
+            if (element.hasAttribute(QStringLiteral("caption"))) {
+                newFolder->setText(element.attribute(
+                                       QStringLiteral("caption")));
             }
             QDomNodeList childList = element.childNodes();
             for (int i = 0; i < childList.length(); i++) {
                 QDomElement newElement = childList.at(i).toElement();
                 handleXmlElement(newElement, newFolder); // passing parent in constructor will add items to tree
             }
-            newItem = newFolder;
+            return newFolder;
         }
-        else if (element.tagName() == "Bookmark") {
+        if (element.tagName() == QStringLiteral("Bookmark")) {
             BookmarkItem* newBookmarkItem = new BookmarkItem(parent);
-            if (element.hasAttribute("modulename")) {
+            if (element.hasAttribute(QStringLiteral("modulename"))) {
                 //we use the name in all cases, even if the module isn't installed anymore
-                newBookmarkItem->setModule(element.attribute("modulename"));
+                newBookmarkItem->setModule(
+                            element.attribute(QStringLiteral("modulename")));
             }
-            if (element.hasAttribute("key")) {
-                newBookmarkItem->setKey(element.attribute("key"));
+            if (element.hasAttribute(QStringLiteral("key"))) {
+                newBookmarkItem->setKey(
+                            element.attribute(QStringLiteral("key")));
             }
-            if (element.hasAttribute("description")) {
-                newBookmarkItem->setDescription(element.attribute("description"));
+            if (element.hasAttribute(QStringLiteral("description"))) {
+                newBookmarkItem->setDescription(
+                            element.attribute(QStringLiteral("description")));
             }
-            if (element.hasAttribute("title")) {
-                newBookmarkItem->setText(element.attribute("title"));
+            if (element.hasAttribute(QStringLiteral("title"))) {
+                newBookmarkItem->setText(
+                            element.attribute(QStringLiteral("title")));
             }
-            newItem = newBookmarkItem;
+            return newBookmarkItem;
         }
-        return newItem;
+        return nullptr;
     }
 
     /** Loads a bookmark XML document from a named file or from the default bookmarks file. */
     QString loadXmlFromFile(QString fileName = QString()) {
-
         if (fileName.isEmpty())
             fileName = defaultBookmarksFile();
 
-        QFile file(fileName);
-        if (!file.exists())
-            return QString();
+        QTextStream t;
+        t.setAutoDetectUnicode(false);
+        #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+        t.setCodec(QTextCodec::codecForName(QByteArrayLiteral("UTF-8")));
+        #else
+        t.setEncoding(QStringConverter::Utf8);
+        #endif
 
-        QString xml;
-        if (file.open(QIODevice::ReadOnly)) {
-            QTextStream t;
-            t.setAutoDetectUnicode(false);
-            t.setCodec(QTextCodec::codecForName("UTF-8"));
-            t.setDevice(&file);
-            xml = t.readAll();
-            file.close();
-        }
-        return xml;
+        QFile file(fileName);
+        if (!file.open(QIODevice::ReadOnly))
+            return {};
+
+        t.setDevice(&file);
+        return t.readAll();
     }
 
     /** Takes one item and saves the tree which is under it to a named file
     * or to the default bookmarks file, asking the user about overwriting if necessary. */
-    QString serializeTreeFromRootItem(BookmarkItemBase * rootItem) {
+    QString serializeTreeFromRootItem(BookmarkFolder * rootItem) {
         BT_ASSERT(rootItem);
 
-        QDomDocument doc("DOC");
-        doc.appendChild( doc.createProcessingInstruction( "xml", "version=\"1.0\" encoding=\"UTF-8\"" ) );
+        QDomDocument doc(QStringLiteral("DOC"));
+        doc.appendChild(
+                    doc.createProcessingInstruction(
+                        QStringLiteral("xml"),
+                        QStringLiteral("version=\"1.0\" encoding=\"UTF-8\"")));
 
-        QDomElement content = doc.createElement("SwordBookmarks");
-        content.setAttribute("syntaxVersion", CURRENT_SYNTAX_VERSION);
+        auto content =
+                doc.createElement(QStringLiteral("SwordBookmarks"));
+        content.setAttribute(QStringLiteral("syntaxVersion"),
+                             CURRENT_SYNTAX_VERSION);
         doc.appendChild(content);
 
         //append the XML nodes of all child items
 
-        for (int i = 0; i < rootItem->childCount(); i++) {
-            saveItem(rootItem->child(i), content);
-        }
+        for (auto const * const itemPtr : rootItem->children())
+            saveItem(itemPtr, content);
         return doc.toString();
     }
 
     /** Writes one item to a document element. */
-    void saveItem(BookmarkItemBase * item, QDomElement & parentElement) {
-        BookmarkFolder* folderItem = nullptr;
-        BookmarkItem* bookmarkItem = nullptr;
+    void saveItem(BookmarkItemBase const * item, QDomElement & parentElement) {
+        BookmarkFolder const * folderItem = nullptr;
+        BookmarkItem const * bookmarkItem = nullptr;
 
-        if ((folderItem = dynamic_cast<BookmarkFolder*>(item))) {
-            QDomElement elem = parentElement.ownerDocument().createElement("Folder");
-            elem.setAttribute("caption", folderItem->text());
+        if ((folderItem = dynamic_cast<BookmarkFolder const *>(item))) {
+            auto elem =
+                    parentElement.ownerDocument().createElement(
+                        QStringLiteral("Folder"));
+            elem.setAttribute(QStringLiteral("caption"), folderItem->text());
 
             parentElement.appendChild(elem);
 
-            for (int i = 0; i < folderItem->childCount(); i++) {
-                saveItem(folderItem->child(i), elem);
-            }
+            for (auto const * const itemPtr : folderItem->children())
+                saveItem(itemPtr, elem);
         }
-        else if ((bookmarkItem = dynamic_cast<BookmarkItem*>(item))) {
-            QDomElement elem = parentElement.ownerDocument().createElement("Bookmark");
+        else if ((bookmarkItem = dynamic_cast<BookmarkItem const *>(item))) {
+            auto elem =
+                    parentElement.ownerDocument().createElement(
+                        QStringLiteral("Bookmark"));
 
-            elem.setAttribute("key", bookmarkItem->englishKey());
-            elem.setAttribute("description", bookmarkItem->description());
-            elem.setAttribute("modulename", bookmarkItem->moduleName());
-            elem.setAttribute("moduledescription", bookmarkItem->module() ? bookmarkItem->module()->config(CSwordModuleInfo::Description) : QString());
-        if (!bookmarkItem->text().isEmpty()) {
-            elem.setAttribute("title", bookmarkItem->text());
-        }
+            elem.setAttribute(QStringLiteral("key"),
+                              bookmarkItem->englishKey());
+            elem.setAttribute(QStringLiteral("description"),
+                              bookmarkItem->description());
+            elem.setAttribute(QStringLiteral("modulename"),
+                              bookmarkItem->moduleName());
+            elem.setAttribute(QStringLiteral("moduledescription"),
+                              bookmarkItem->module()
+                              ? bookmarkItem->module()->config(
+                                    CSwordModuleInfo::Description)
+                              : QString());
+            if (!bookmarkItem->text().isEmpty()) {
+                elem.setAttribute(QStringLiteral("title"), bookmarkItem->text());
+            }
             parentElement.appendChild(elem);
         }
     }
 
 
-public: /* Fields */
+public: // fields:
 
     BookmarkFolder * m_rootItem;
     QTimer m_saveTimer;
     static BtBookmarksModel * m_defaultModel;
 
-    Q_DECLARE_PUBLIC(BtBookmarksModel);
+    Q_DECLARE_PUBLIC(BtBookmarksModel)
     BtBookmarksModel * const q_ptr;
 
 };
 
 BtBookmarksModel * BtBookmarksModelPrivate::m_defaultModel = nullptr;
 
-using BookmarkItemBase = BtBookmarksModelPrivate::BookmarkItemBase;
-using BookmarkItem = BtBookmarksModelPrivate::BookmarkItem;
-using BookmarkFolder = BtBookmarksModelPrivate::BookmarkFolder;
-
-
-BookmarkFolder::BookmarkFolder(const QString & name, BookmarkItemBase * parent)
+BookmarkFolder::BookmarkFolder(const QString & name, BookmarkFolder * parent)
         : BookmarkItemBase(parent) {
     setText(name);
-    setFlags(Qt::ItemIsEditable | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsEnabled);
-    setIcon(CResMgr::mainIndex::closedFolder::icon());
-}
-
-QList<BookmarkItemBase*> BookmarkFolder::getChildList() const {
-    QList<BookmarkItemBase*> list;
-    for (int i = 0; i < childCount(); i++) {
-        list.append(child(i));
-    }
-    return list;
 }
 
 bool BookmarkFolder::hasDescendant(BookmarkItemBase const * const item) const {
     if (this == item)
         return true;
-    if (getChildList().indexOf(const_cast<BookmarkItemBase *>(item)) > -1)
+    if (children().indexOf(const_cast<BookmarkItemBase *>(item)) > -1)
         return true;
-    Q_FOREACH(BookmarkItemBase const * const childItem, getChildList())
+    for (auto const * const childItem : children())
         if (BookmarkFolder const * const folder =
                 dynamic_cast<BookmarkFolder const *>(childItem))
             if (folder->hasDescendant(childItem))
@@ -472,7 +450,7 @@ bool BookmarkFolder::hasDescendant(BookmarkItemBase const * const item) const {
 
 BookmarkFolder * BookmarkFolder::deepCopy() const {
     BookmarkFolder* newFolder = new BookmarkFolder(this->text());
-    Q_FOREACH(BookmarkItemBase const * const subitem, getChildList()) {
+    for (auto const * const subitem : children()) {
         if (BookmarkItem const * const bmItem =
                 dynamic_cast<BookmarkItem const *>(subitem))
         {
@@ -493,29 +471,25 @@ BookmarkItem::BookmarkItem(CSwordModuleInfo const & module,
         : m_description(description)
         , m_moduleName(module.name())
 {
-    Q_UNUSED(title);
+    Q_UNUSED(title)
 
     if (((module.type() == CSwordModuleInfo::Bible) || (module.type() == CSwordModuleInfo::Commentary))) {
         /// here we only translate \param key into english
         sword::VerseKey vk(key.toUtf8().constData(), key.toUtf8().constData(),
-            static_cast<sword::VerseKey *>(module.module().getKey())->getVersificationSystem());
+            static_cast<sword::VerseKey *>(module.swordModule().getKey())->getVersificationSystem());
         CSwordVerseKey k(&vk, &module);
         k.setLocale("en");
         m_key = k.key();
     }
     else {
         m_key = key;
-    };
+    }
 
-    setIcon(CResMgr::mainIndex::bookmark::icon());
     setText(toHeader(key, module.name()));
-    setFlags(Qt::ItemIsSelectable /*| Qt::ItemIsEditable*/ | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsEnabled);
 }
 
-BookmarkItem::BookmarkItem(BookmarkItemBase * parent)
+BookmarkItem::BookmarkItem(BookmarkFolder * parent)
         : BookmarkItemBase(parent) {
-    setFlags(Qt::ItemIsSelectable /*| Qt::ItemIsEditable*/ | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsEnabled);
-    setIcon(CResMgr::mainIndex::bookmark::icon());
     setText(toHeader(key(), module() ? module()->name() : QObject::tr("unknown")));
 }
 
@@ -525,13 +499,11 @@ BookmarkItem::BookmarkItem(const BookmarkItem & other)
         , m_description(other.m_description)
         , m_moduleName(other.m_moduleName)
 {
-    setIcon(CResMgr::mainIndex::bookmark::icon());
     setText(toHeader(key(), module() ? module()->name() : QObject::tr("unknown")));
 }
 
-CSwordModuleInfo *BookmarkItem::module() const {
-    return CSwordBackend::instance()->findModuleByName(m_moduleName);
-}
+CSwordModuleInfo * BookmarkItem::module() const
+{ return CSwordBackend::instance().findModuleByName(m_moduleName); }
 
 QString BookmarkItem::key() const {
     const QString englishKeyName = englishKey();
@@ -543,9 +515,9 @@ QString BookmarkItem::key() const {
     if ((module()->type() == CSwordModuleInfo::Bible) || (module()->type() == CSwordModuleInfo::Commentary)) {
         /// here we only translate \param key into current book name language
         sword::VerseKey vk(englishKeyName.toUtf8().constData(), englishKeyName.toUtf8().constData(),
-            static_cast<sword::VerseKey *>(module()->module().getKey())->getVersificationSystem());
+            static_cast<sword::VerseKey *>(module()->swordModule().getKey())->getVersificationSystem());
         CSwordVerseKey k(&vk, module());
-        k.setLocale(CSwordBackend::instance()->booknameLanguage().toLatin1() );
+        k.setLocale(CSwordBackend::instance().booknameLanguage().toLatin1());
         returnKeyName = k.key();
     }
 
@@ -553,28 +525,28 @@ QString BookmarkItem::key() const {
 }
 
 QString BookmarkItem::toolTip() const {
-    if (!module())
+    auto const * const m = module();
+    if (!m)
         return QString();
 
     FilterOptions filterOptions = btConfig().getFilterOptions();
     filterOptions.footnotes = false;
     filterOptions.scriptureReferences = false;
-    CSwordBackend::instance()->setFilterOptions(filterOptions);
+    CSwordBackend::instance().setFilterOptions(filterOptions);
 
-    std::unique_ptr<CSwordKey> k(CSwordKey::createInstance(module()));
+    std::unique_ptr<CSwordKey> k(m->createKey());
     BT_ASSERT(k);
     k->setKey(key());
 
-    // const CLanguageMgr::Language* lang = module()->language();
+    // Language const * lang = m->language();
     // BtConfig::FontSettingsPair fontPair = getBtConfig().getFontForLanguage(lang);
 
-    QString const header(toHeader(key(), module()->name()));
-    QString ret("<b>");
-    ret.append(header).append(")</b>");
-    QString const txt(text());
-    if (txt != header)
-        ret.append("<br>").append(txt);
-    return ret.append("<hr>").append(description());
+    auto const header = toHeader(key(), m->name());
+    auto const & txt = text();
+    if (txt == header)
+        return QStringLiteral("<b>%1)</b><hr>%2").arg(header, description());
+    return QStringLiteral("<b>%1)</b><br>%2<hr>%3")
+            .arg(header, txt, description());
 }
 
 
@@ -602,11 +574,13 @@ BtBookmarksModel::~BtBookmarksModel() {
 int BtBookmarksModel::rowCount(const QModelIndex & parent) const {
     Q_D(const BtBookmarksModel);
 
-    return d->item(parent)->childCount();
+    if (auto const * const f = dynamic_cast<BookmarkFolder *>(d->item(parent)))
+        return f->children().size();
+    return 0;
 }
 
 int BtBookmarksModel::columnCount(const QModelIndex & parent) const {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     return 1;
 }
 
@@ -616,9 +590,9 @@ bool BtBookmarksModel::hasChildren(const QModelIndex & parent) const {
 QModelIndex BtBookmarksModel::index(int row, int column, const QModelIndex & parent) const {
     Q_D(const BtBookmarksModel);
 
-    const BookmarkItemBase * i = d->item(parent);
-    if(i->childCount() > row && row >= 0)
-        return createIndex(row, column, i->child(row));
+    auto const * const f = dynamic_cast<BookmarkFolder *>(d->item(parent));
+    if (f && f->children().size() > row && row >= 0)
+        return createIndex(row, column, f->children()[row]);
     return QModelIndex();
 }
 
@@ -647,9 +621,9 @@ QVariant BtBookmarksModel::data(const QModelIndex & index, int role) const {
         case TypeRole:
             {
                 if(isBookmark(index))
-                    return "bookmark";
+                    return QStringLiteral("bookmark");
                 else
-                    return "folder";
+                    return QStringLiteral("folder");
             }
     }
     return QVariant();
@@ -662,9 +636,9 @@ Qt::ItemFlags BtBookmarksModel::flags(const QModelIndex & index) const {
 }
 
 QVariant BtBookmarksModel::headerData(int section, Qt::Orientation orientation, int role) const {
-    Q_UNUSED(section);
-    Q_UNUSED(orientation);
-    Q_UNUSED(role);
+    Q_UNUSED(section)
+    Q_UNUSED(orientation)
+    Q_UNUSED(role)
 
     return QVariant();
 }
@@ -673,23 +647,11 @@ bool BtBookmarksModel::setData(const QModelIndex & index, const QVariant & val,
     Q_D(BtBookmarksModel);
 
     BookmarkItemBase * i = d->item(index);
-    switch(role)
-    {
-        case Qt::DisplayRole:
-        case Qt::EditRole:
-        {
-            i->setText(val.toString());
-            if(dynamic_cast<BookmarkFolder *>(i) || dynamic_cast<BookmarkItem *>(i))
-                d->needSave();
-            return true;
-        }
-        case Qt::ToolTipRole:
-        {
-            i->setToolTip(val.toString());
-            if(dynamic_cast<BookmarkFolder *>(i) || dynamic_cast<BookmarkItem *>(i))
-                d->needSave();
-            return true;
-        }
+    if (role == Qt::DisplayRole || role == Qt::EditRole) {
+        i->setText(val.toString());
+        if(dynamic_cast<BookmarkFolder *>(i) || dynamic_cast<BookmarkItem *>(i))
+            d->needSave();
+        return true;
     }
     return false;
 }
@@ -697,49 +659,42 @@ bool BtBookmarksModel::setData(const QModelIndex & index, const QVariant & val,
 bool BtBookmarksModel::removeRows(int row, int count, const QModelIndex & parent)
 {
     Q_D(BtBookmarksModel);
-
-    BT_ASSERT(rowCount(parent) >= row + count);
-
-    beginRemoveRows(parent, row, row + count - 1);
-
-    for(int i = 0; i < count; ++i) {
-        d->item(parent)->removeChild(row);
+    if (auto * const f = dynamic_cast<BookmarkFolder *>(d->item(parent))) {
+        BT_ASSERT(row + count <= f->children().size());
+        beginRemoveRows(parent, row, row + count - 1);
+        for(int i = 0; i < count; ++i)
+            f->removeChild(row);
+        endRemoveRows();
+        d->needSave();
+        return true;
     }
-    endRemoveRows();
-
-    d->needSave();
-
-    return true;
+    return false;
 }
 
 bool BtBookmarksModel::insertRows(int row, int count, const QModelIndex &parent)
 {
     Q_D(BtBookmarksModel);
-
-    BT_ASSERT(rowCount(parent) >= row + count - 1);
-
-    beginInsertRows(parent, row, row + count - 1);
-
-    for(int i = 0; i < count; ++i) {
-        d->item(parent)->insertChild(row, new BookmarkItemBase);
+    if (auto * const f = dynamic_cast<BookmarkFolder *>(d->item(parent))) {
+        BT_ASSERT(row <= f->children().size());
+        beginInsertRows(parent, row, row + count - 1);
+        for(int i = 0; i < count; ++i)
+            f->insertChild(row, new BookmarkItemBase);
+        endInsertRows();
+        return true;
     }
-    endInsertRows();
-
-    return true;
-
+    return false;
 }
 
 bool BtBookmarksModel::save(QString fileName, const QModelIndex & rootItem) {
     Q_D(BtBookmarksModel);
-
-    QString const serializedTree(
-            d->serializeTreeFromRootItem(d->item(rootItem)));
+    BT_ASSERT(dynamic_cast<BookmarkFolder *>(d->item(rootItem)));
+    auto const serializedTree =
+            d->serializeTreeFromRootItem(
+                static_cast<BookmarkFolder *>(d->item(rootItem)));
     if (fileName.isEmpty())
         fileName = BtBookmarksModelPrivate::defaultBookmarksFile();
 
-    util::tool::savePlainFile(fileName,
-                              serializedTree,
-                              QTextCodec::codecForName("UTF-8"));
+    util::tool::savePlainFile(fileName, serializedTree);
 
     if(d->m_saveTimer.isActive())
         d->m_saveTimer.stop();
@@ -749,8 +704,8 @@ bool BtBookmarksModel::save(QString fileName, const QModelIndex & rootItem) {
 
 bool BtBookmarksModel::load(QString fileName, const QModelIndex & rootItem) {
     Q_D(BtBookmarksModel);
-
-    BookmarkItemBase * i = d->item(rootItem);
+    BT_ASSERT(dynamic_cast<BookmarkFolder *>(d->item(rootItem)));
+    auto * const i = static_cast<BookmarkFolder *>(d->item(rootItem));
     QList<BookmarkItemBase *> items = d->loadTree(fileName);
 
     if(!rootItem.isValid() && fileName.isEmpty()) {
@@ -763,12 +718,10 @@ bool BtBookmarksModel::load(QString fileName, const QModelIndex & rootItem) {
     if(items.size() == 0)
         return false;
 
-    beginInsertRows(rootItem, i->childCount(), i->childCount() + items.size() - 1);
-
-    i->insertChildren(i->childCount(), items);
-
+    auto const numChildren = i->children().size();
+    beginInsertRows(rootItem, numChildren, numChildren + items.size() - 1);
+    i->insertChildren(numChildren, items);
     endInsertRows();
-
     return true;
 }
 
@@ -784,9 +737,11 @@ bool BtBookmarksModel::isBookmark(const QModelIndex &index) const
     return d->itemAs<BookmarkItem const>(index);
 }
 
-QModelIndexList BtBookmarksModel::copyItems(int row, const QModelIndex & parent, const QModelIndexList & toCopy)
+void BtBookmarksModel::copyItems(int row, const QModelIndex & parent, const QModelIndexList & toCopy)
 {
     Q_D(BtBookmarksModel);
+    BT_ASSERT(dynamic_cast<BookmarkFolder *>(d->item(parent)));
+    auto * const targetFolder = static_cast<BookmarkFolder *>(d->item(parent));
 
     bool bookmarksOnly = true;
     bool targetIncluded = false;
@@ -794,7 +749,7 @@ QModelIndexList BtBookmarksModel::copyItems(int row, const QModelIndex & parent,
 
     QList<BookmarkItemBase *> newList;
 
-    Q_FOREACH(QModelIndex const index, toCopy) {
+    for (auto const & index : toCopy) {
         if (BookmarkFolder const * const folder =
                 d->itemAs<BookmarkFolder const>(index))
         {
@@ -821,23 +776,17 @@ QModelIndexList BtBookmarksModel::copyItems(int row, const QModelIndex & parent,
     }
 
     if (moreThanOneFolder || targetIncluded) {
-        return QModelIndexList();
+        return;
     }
 
 
     beginInsertRows(parent, row, row + newList.size() - 1);
 
-    d->item(parent)->insertChildren(row, newList);
+    targetFolder->insertChildren(row, newList);
 
     endInsertRows();
 
     d->needSave();
-
-    QModelIndexList result;
-    for(int i = 0; i < newList.size(); ++i) {
-        result.append(index(row + i, 0, parent));
-    }
-    return result;
 }
 
 CSwordModuleInfo * BtBookmarksModel::module(const QModelIndex & index) const
@@ -953,16 +902,17 @@ void BtBookmarksModel::sortItems(QModelIndex const & parent,
             QList<BookmarkItemBase *> items;
             items.append(f);
             for(int i = 0; i < items.size(); ++i) {
-                items.append(items[i]->children());
-                if(BookmarkFolder * ff = dynamic_cast<BookmarkFolder *>(items[i]))
+                if (auto * const ff = dynamic_cast<BookmarkFolder *>(items[i])){
+                    items.append(ff->children());
                     parents.append(ff);
+                }
             }
         }
         else
             parents.append(f);
 
-        Q_FOREACH(BookmarkFolder * const f, parents) {
-            emit layoutAboutToBeChanged();
+        for (auto * const f : parents) {
+            Q_EMIT layoutAboutToBeChanged();
 
             QModelIndexList indexes;
             for(int i = 0; i < f->children().size(); ++i)
@@ -980,7 +930,7 @@ void BtBookmarksModel::sortItems(QModelIndex const & parent,
                     if(iii == indexes[ii].internalPointer())
                         changePersistentIndex(createIndex(ii, 0, iii), createIndex(i, 0, iii));
             }
-            emit layoutChanged();
+            Q_EMIT layoutChanged();
 
             d->needSave();
         }
@@ -988,12 +938,15 @@ void BtBookmarksModel::sortItems(QModelIndex const & parent,
 }
 
 QHash<int, QByteArray> BtBookmarksModel::roleNames() const {
-    QHash<int, QByteArray> roleNames;
-    roleNames[Qt::DisplayRole] = "display";
-    roleNames[Qt::DecorationRole] = "icon";
-    roleNames[Qt::EditRole] = "edit";
-    roleNames[TypeRole] = "itemtype";
-    return roleNames;
+    static auto const staticRoleNames = {
+        std::make_pair(static_cast<int>(Qt::DisplayRole),
+                       QByteArrayLiteral("display")),
+        std::make_pair(static_cast<int>(Qt::DecorationRole),
+                       QByteArrayLiteral("icon")),
+        std::make_pair(static_cast<int>(Qt::EditRole),
+                       QByteArrayLiteral("edit")),
+        std::make_pair(static_cast<int>(TypeRole),
+                       QByteArrayLiteral("itemtype"))
+    };
+    return staticRoleNames;
 }
-
-
