@@ -2,16 +2,15 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKMARKSMODEL_H
-#define BTBOOKMARKSMODEL_H
+#pragma once
 
 #include <QAbstractItemModel>
 
@@ -28,7 +27,7 @@ class BtBookmarksModel: public QAbstractItemModel {
     Q_OBJECT
 
 
-public: /* Methods: */
+public: // methods:
 
     enum BookmarksRoles {
         TypeRole = Qt::UserRole + 1
@@ -81,9 +80,8 @@ public: /* Methods: */
       \param[in] row new item will occupy given row.
       \param[in] parent if invalid new item will be placed on top level.
       \param[in] toCopy item to copy.
-      \returns newly created itemS that are copy of toCopy.
     */
-    QModelIndexList copyItems(int row, const QModelIndex & parent, const QModelIndexList & toCopy);
+    void copyItems(int row, const QModelIndex & parent, const QModelIndexList & toCopy);
 
     /**
       \returns whether item of index is a folder.
@@ -132,7 +130,7 @@ public: /* Methods: */
     */
     QHash<int, QByteArray> roleNames() const override;
 
-public slots:
+public Q_SLOTS:
 
     /**
       \brief Save bookmarks or specified branch to file.
@@ -157,12 +155,10 @@ public slots:
 
 private:
 
-    inline bool slotSave() { return save(); }
+    bool slotSave() { return save(); }
 
-private: /* Fields: */
+private: // fields:
     Q_DECLARE_PRIVATE(BtBookmarksModel)
     BtBookmarksModelPrivate * const d_ptr;
 
 };
-
-#endif // BTBOOKMARKSMODEL_H
