@@ -2,19 +2,20 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTSIGNAL_H
-#define BTSIGNAL_H
+#pragma once
 
 #include <QObject>
 
+#include <QString>
+
 
 /**
 * BtSignal
@@ -37,11 +38,10 @@ public:
     /**
       Immediately emits the beforeChanged() signal.
     */
-    inline void emitSignal() { emit signal(); }
+    void emitSignal() { Q_EMIT signal(); }
 
-signals:
+Q_SIGNALS:
 
     void signal();
 
 };
-#endif
