@@ -2,29 +2,30 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTSOURCESTHREAD_H
-#define BTSOURCESTHREAD_H
+#pragma once
 
 #include <QThread>
 
 #include <atomic>
+#include <QObject>
+#include <QString>
 
 
 class BtSourcesThread: public QThread {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
-    inline BtSourcesThread(QObject * parent = nullptr)
+    BtSourcesThread(QObject * parent = nullptr)
         : QThread(parent)
         , m_stop(false)
         , m_finishedSuccessfully(false)
@@ -32,28 +33,26 @@ public: /* Methods: */
 
     void stop() noexcept { m_stop.store(true, std::memory_order_release); }
 
-    inline bool finishedSuccessfully() const noexcept
+    bool finishedSuccessfully() const noexcept
     { return m_finishedSuccessfully.load(std::memory_order_acquire); }
 
-signals:
+Q_SIGNALS:
 
     void percentComplete(int percent);
     void showMessage(QString const & msg);
 
-protected: /* Methods: */
+protected: // methods:
 
     void run() override;
 
-private: /* Methods: */
+private: // methods:
 
-    inline bool shouldStop() const noexcept
+    bool shouldStop() const noexcept
     { return m_stop.load(std::memory_order_acquire); }
 
-private: /* Fields: */
+private: // fields:
 
     std::atomic<bool> m_stop;
     std::atomic<bool> m_finishedSuccessfully;
 
 }; /* class BtSourcesThread */
-
-#endif
