@@ -2,39 +2,43 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTCONFIG_H
-#define BTCONFIG_H
+#pragma once
 
-#include <QDataStream>
-#include <QFont>
-#include <QHash>
-#include <QKeySequence>
-#include <QMetaType>
-#include <QSet>
-#include <QSettings>
-#include <QString>
-#include <QStringList>
-#include <QVariant>
-#include "../btglobal.h"
-#include "../drivers/cswordmoduleinfo.h"
 #include "btconfigcore.h"
 
+#include <QCoreApplication>
+#include <QFont>
+#include <QHash>
+#include <QList>
+#include <QMap>
+#include <QMetaType>
+#include <QPair>
+#include <QString>
+#include <QStringList>
+#include "../../util/btassert.h"
+#include "../btglobal.h"
 
-class BibleTimeApp;
+
+class CSwordModuleInfo;
+class Language;
+class QKeySequence;
+namespace sword { class ListKey; }
 
 class BtConfig: public BtConfigCore {
 
+    Q_DECLARE_TR_FUNCTIONS(BtConfig)
+
     friend class BibleTimeApp;
 
-public: /* Types: */
+public: // types:
 
     /*!
     * The first parameter indicates whether the custom font should be used or not.
@@ -44,9 +48,7 @@ public: /* Types: */
     using StringMap = QMap<QString, QString>;
     using ShortcutsMap = QHash<QString, QList<QKeySequence> >;
 
-private: /* Types: */
-
-    using FontCacheMap = QHash<const CLanguageMgr::Language *, FontSettingsPair>;
+private: // types:
 
     enum InitState {
         INIT_NEED_UNIMPLEMENTED_BACKWARD_MIGRATE = -2,
@@ -54,10 +56,60 @@ private: /* Types: */
         INIT_NEED_UNIMPLEMENTED_FORWARD_MIGRATE = 2,
     };
 
-public: /* Methods: */
+public: // methods:
 
     static BtConfig & getInstance();
 
+    /**
+      \returns the key of the current session.
+    */
+    QString const & currentSessionKey() const { return m_currentSessionKey; }
+
+    /**
+      \returns the name of the current session.
+    */
+    QString currentSessionName() const {
+        auto it(m_sessionNames.constFind(m_currentSessionKey));
+        BT_ASSERT(it != m_sessionNames.constEnd());
+        return it.value();
+    }
+
+    /** \returns a hashmap with the keys and printable names of the sessions. */
+    QHash<QString, QString> sessionNames() const { return m_sessionNames; }
+
+    /**
+      \brief Notifies the configuration system that the session settings
+             should be read from and saved to the given session.
+
+      \pre The session with the given key must exist.
+      \param[in] key the key of the session to switch to.
+      \post the sessionValue() and value() methods will work with the settings
+            of the given session.
+    */
+    void setCurrentSession(const QString & key);
+
+    /**
+      \brief Creates a new session with the given name.
+
+      \pre The given name must not be an empty string.
+      \param[in] name the name of the session
+      \returns the key of the created session.
+    */
+    QString addSession(const QString & name);
+
+    /**
+      \brief Deletes the session with the given key.
+
+      \pre The session with the given key must exist.
+      \pre The session with the given key must not be the current session.
+      \param[in] key the key of the session to delete.
+      \post The session with the given key and its settings are deleted.
+      \returns whether deleting the session was successful.
+    */
+    void deleteSession(const QString & key);
+
+    BtConfigCore session() const;
+
     /*!
      * \brief Function to set a module decryption key.
      *
@@ -102,48 +154,42 @@ public: /* Methods: */
     void setShortcuts(QString const & shortcutGroup,
                       ShortcutsMap const & shortcuts);
 
-    /*!
-     * \brief Returns current filter options.
-     *
-     * Returns a structure containing the current
-     * settings to be used for filtering.
-     *
-     * \returns FilterOptions structure containing filter settings.
-     */
-    FilterOptions getFilterOptions();
+    /** \returns FilterOptions structure containing filter settings. */
+    static FilterOptions loadFilterOptionsFromGroup(BtConfigCore const & group);
 
-    /*!
-     * \brief Saves the current filter options.
-     *
-     * \param[in] options The filter options to save.
-     */
-    void setFilterOptions(const FilterOptions & options);
+    FilterOptions getFilterOptions() const {
+        auto const group = const_cast<BtConfig *>(this)->session();
+        return loadFilterOptionsFromGroup(group);
+    }
 
-    /*!
-     * \brief Returns current display options.
-     *
-     * Returns a structure containing the current
-     * settings to be used for displaying texts.
-     *
-     * \returns DisplayOptions structure containing display settings.
-     */
-    DisplayOptions getDisplayOptions();
+    /**
+       \brief Saves the current filter options.
+       \param[in] options The filter options to save.
+    */
+    static void storeFilterOptionsToGroup(FilterOptions const & options,
+                                          BtConfigCore & group);
 
-    /*!
-     * \brief Saves the current display options.
-     *
-     * \param[in] options The display options to save.
-     */
-    void setDisplayOptions(const DisplayOptions & options);
+    /** \returns DisplayOptions structure containing display settings. */
+    static DisplayOptions loadDisplayOptionsFromGroup(
+            BtConfigCore const & group);
+
+    DisplayOptions getDisplayOptions() const {
+        auto const group = const_cast<BtConfig *>(this)->session();
+        return loadDisplayOptionsFromGroup(group);
+    }
+
+    /**
+       \brief Saves the current display options.
+       \param[in] options The display options to save.
+    */
+    static void storeDisplayOptionsToGroup(DisplayOptions const & options,
+                                           BtConfigCore & group);
 
     /*!
      * Returns a default font that is suitable for the current language.
      * \returns QFont suitable for current language.
      */
-    inline const QFont & getDefaultFont() const {
-        QMutexLocker lock(&this->m_mutex);
-        return m_defaultFont;
-    }
+    QFont const & getDefaultFont() const { return m_defaultFont; }
 
     /// \todo: put FontSettingsPair in QVariant directly
     /*!
@@ -153,8 +199,8 @@ public: /* Methods: */
      * \param[in] language pointer to a language to set the font for
      * \param[in] fontSettings FontSettingsPair to set
      */
-    void setFontForLanguage(const CLanguageMgr::Language & language,
-                            const FontSettingsPair & fontSettings);
+    void setFontForLanguage(Language const & language,
+                            FontSettingsPair const & fontSettings);
 
     /*!
      * \brief Get font for a language.
@@ -164,7 +210,7 @@ public: /* Methods: */
      * \param[in] language pointer to a language to get the font for.
      * \returns FontSettingsPair for given language
      */
-    FontSettingsPair getFontForLanguage(const CLanguageMgr::Language & language);
+    FontSettingsPair getFontForLanguage(Language const & language);
 
     /// \todo: unit test these functions
     /*!
@@ -188,6 +234,10 @@ public: /* Methods: */
      * \param[in] searchScopes Search scopes in any locale.
      */
     void setSearchScopesWithCurrentLocale(const QStringList& scopeModules, StringMap searchScopes);
+
+    /** \returns the configured language code for book names. */
+    QString booknameLanguage();
+
     /*
      * Ensure that the verse range is valid for at least one of the scopeModules
      */
@@ -221,7 +271,7 @@ public: /* Methods: */
     void setDefaultSwordModuleByType(const QString & moduleType,
                                      const CSwordModuleInfo * const module);
 
-private: /* Methods: */
+private: // methods:
 
     explicit BtConfig(const QString & settingsFile);
 
@@ -230,16 +280,19 @@ private: /* Methods: */
 
     static void destroyInstance();
 
-private: /* Fields: */
+private: // fields:
 
     static BtConfig * m_instance; //!< singleton instance
 
     QFont m_defaultFont; //!< default font used when no special one is set
-    FontCacheMap m_fontCache; //!< a cache for the fonts saved in the configuration file for speed
+    QHash<Language const *, FontSettingsPair> m_fontCache; //!< a cache for the fonts saved in the configuration file for speed
 
     static StringMap m_defaultSearchScopes;
 
-};
+    QHash<QString, QString> m_sessionNames;
+    QString m_currentSessionKey;
+
+}; /* class BtConfig */
 
 // declare types used in configuration as metatype so they can be saved directly into the configuration
 Q_DECLARE_METATYPE(BtConfig::StringMap)
@@ -252,5 +305,3 @@ Q_DECLARE_METATYPE(QList<int>)
 inline BtConfig & btConfig() {
     return BtConfig::getInstance();
 }
-
-#endif // BTCONFIG_H
