@@ -2,16 +2,15 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTCONSTMODULESET_H
-#define BTCONSTMODULESET_H
+#pragma once
 
 #include <QSet>
 
@@ -20,17 +19,15 @@ class CSwordModuleInfo;
 
 class BtConstModuleSet: public QSet<CSwordModuleInfo const *> {
 
-public: /* Methods: */
+public: // methods:
 
     BtConstModuleSet(QSet<CSwordModuleInfo const *> const & copy)
         : QSet<CSwordModuleInfo const *>(copy)
     {}
 
     BtConstModuleSet(QSet<CSwordModuleInfo *> other) {
-        Q_FOREACH(CSwordModuleInfo const * const item, other)
+        for (auto const * const item : other)
             insert(item);
     }
 
 };
-
-#endif /* BTCONSTMODULESET_H */
