@@ -2,16 +2,15 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CSWORDCOMMENTARYMODULEINFO_H
-#define CSWORDCOMMENTARYMODULEINFO_H
+#pragma once
 
 #include "cswordbiblemoduleinfo.h"
 
@@ -21,18 +20,16 @@
 
   This CSwordModule implementation provides access to Sword's commentary modules.
 */
-class CSwordCommentaryModuleInfo: public CSwordBibleModuleInfo {
+class CSwordCommentaryModuleInfo final: public CSwordBibleModuleInfo {
         Q_OBJECT
 
-    public: /* Methods: */
+    public: // methods:
 
-        inline CSwordCommentaryModuleInfo(sword::SWModule & module,
-                                          CSwordBackend & backend)
+        CSwordCommentaryModuleInfo(sword::SWModule & module,
+                                   CSwordBackend & backend)
             : CSwordBibleModuleInfo(module,
                                     backend,
                                     CSwordModuleInfo::Commentary) {}
 
-        bool isWritable() const override;
+        bool isWritable() const final override;
 };
-
-#endif
