@@ -2,32 +2,50 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef FILTERS_GBFTOHTML_H
-#define FILTERS_GBFTOHTML_H
+#pragma once
 
 // Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wextra-semi"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wsuggest-destructor-override"
+#endif
 #include <gbfhtml.h>
+#include <swbasicfilter.h>
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+#pragma GCC diagnostic pop
 
 
+namespace sword {
+class SWBuf;
+class SWKey;
+class SWModule;
+} // namespace sword
+
 namespace Filters {
 
 /**
   \brief GBF to HTML conversion filter.
 */
 class GbfToHtml: public sword::GBFHTML {
-    protected: /* Types: */
+    protected: // types:
         class UserData: public sword::GBFHTML::MyUserData {
             public:
-                inline UserData(const sword::SWModule *module,
-                                 const sword::SWKey *key)
+                UserData(sword::SWModule const * module,
+                         sword::SWKey const * key)
                     : sword::GBFHTML::MyUserData(module, key),
                       swordFootnote(1)
                 {
@@ -37,7 +55,7 @@ class GbfToHtml: public sword::GBFHTML {
                 short unsigned int swordFootnote;
         };
 
-    public: /* Methods: */
+    public: // methods:
         GbfToHtml();
 
         /** Reimplemented from sword::OSISHTMLHREF. */
@@ -50,15 +68,12 @@ class GbfToHtml: public sword::GBFHTML {
                          const sword::SWKey *key,
                          const sword::SWModule *module = nullptr) override;
 
-    protected: /* Methods: */
+    protected: // methods:
         /** Reimplemented from sword::OSISHTMLHREF. */
-        inline sword::BasicFilterUserData *createUserData(
-                const sword::SWModule *module, const sword::SWKey *key) override
-        {
-            return new UserData(module, key);
-        }
+        sword::BasicFilterUserData * createUserData(
+                sword::SWModule const * module,
+                sword::SWKey const * key) override
+        { return new UserData(module, key); }
 };
 
 } // namespace Filters
-
-#endif
