@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,19 +13,100 @@
 #include "osistohtml.h"
 
 #include <QString>
-#include "../../util/btassert.h"
+#include <string_view>
 #include "../config/btconfig.h"
 #include "../drivers/cswordmoduleinfo.h"
-#include "../managers/clanguagemgr.h"
 #include "../managers/cswordbackend.h"
 #include "../managers/referencemanager.h"
 
 // Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
 #include <swbuf.h>
 #include <swmodule.h>
 #include <utilxml.h>
+#pragma GCC diagnostic pop
 
 
+namespace {
+
+template <typename UserData>
+void renderReference(char const * const osisRef,
+                     sword::SWBuf & buf,
+                     sword::SWModule const & myModule,
+                     UserData const & myUserData)
+{
+    QString const ref(osisRef);
+    //BT_ASSERT(!ref.isEmpty()); checked later
+
+    if (!ref.isEmpty()) {
+        /* find out the mod, using the current module makes sense if it's a
+           bible or commentary because the refs link into a bible by default.
+           If the osisRef is something like "ModuleID:key comes here" then the
+           modulename is given, so we'll use that one. */
+
+        auto const * mod =
+                CSwordBackend::instance().findSwordModuleByPointer(&myModule);
+        //BT_ASSERT(mod); checked later
+        if (!mod || (mod->type() != CSwordModuleInfo::Bible
+                     && mod->type() != CSwordModuleInfo::Commentary))
+        {
+            mod = btConfig().getDefaultSwordModuleByType(
+                      QStringLiteral("standardBible"));
+            if (!mod)
+                mod = CSwordBackend::instance().findFirstAvailableModule(
+                          CSwordModuleInfo::Bible);
+        }
+
+        // BT_ASSERT(mod); There's no necessarily a module or standard Bible
+
+        //if the osisRef like "GerLut:key" contains a module, use that
+        auto const pos = ref.indexOf(':');
+
+        QString hrefRef;
+        if ((pos >= 0)
+            && ref.at(pos - 1).isLetter()
+            && ref.at(pos + 1).isLetter())
+        {
+            auto const newModuleName(ref.left(pos));
+            hrefRef = ref.mid(pos + 1);
+
+            if (auto const * const moduleByName =
+                    CSwordBackend::instance().findModuleByName(newModuleName))
+                mod = moduleByName;
+        } else {
+            hrefRef = ref;
+        }
+
+        if (mod) {
+            using namespace ReferenceManager;
+            ParseOptions const options{
+                    mod->name(),
+                    QString::fromUtf8(myUserData.key->getText()),
+                    myModule.getLanguage()};
+
+            auto const hyperlink( // Hyperlink with key and mod
+                        encodeHyperlink(
+                              *mod,
+                              parseVerseReference(hrefRef, options)).toUtf8());
+
+            // Ref must contain the osisRef module marker if there was any:
+            auto const moduleMarker(parseVerseReference(ref, options).toUtf8());
+
+            buf.append("<a href=\"")
+               .append(hyperlink.constData())
+               .append("\" crossrefs=\"")
+               .append(moduleMarker.constData())
+               .append("\">");
+        }
+        /** \todo Should we add something if there were no referenced module
+                  available? */
+    }
+} // renderReference()
+
+} // anonymous namespace
+
 Filters::OsisToHtml::OsisToHtml() : sword::OSISHTMLHREF() {
     setPassThruUnknownEscapeString(true); //the HTML widget will render the HTML escape codes
 
@@ -53,22 +134,23 @@ Filters::OsisToHtml::OsisToHtml() : sword::OSISHTMLHREF() {
 }
 
 bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, sword::BasicFilterUserData *userData) {
+    using namespace std::literals;
     // manually process if it wasn't a simple substitution
 
     if (!substituteToken(buf, token)) {
-        UserData* myUserData = dynamic_cast<UserData*>(userData);
+        UserData* myUserData = static_cast<UserData*>(userData);
         sword::SWModule* myModule = const_cast<sword::SWModule*>(myUserData->module); //hack
 
-        sword::XMLTag tag(token);
+        sword::XMLTag const tag(token);
         //     qWarning("found %s", token);
-        const bool osisQToTick = ((!userData->module->getConfigEntry("OSISqToTick")) || (strcmp(userData->module->getConfigEntry("OSISqToTick"), "false")));
+        auto const osisQToTickEntry =
+                userData->module->getConfigEntry("OSISqToTick");
+        bool const osisQToTick =
+                !osisQToTickEntry || osisQToTickEntry != "false"sv;
 
-        if (!tag.getName()) {
-            return false;
-        }
+        std::string_view const tagName(tag.getName());
 
-        // <div> tag
-        if (!strcmp(tag.getName(), "div")) {
+        if (tagName == "div"sv) {
             if (tag.isEndTag()) {
                 buf.append("</div>");
             } else {
@@ -91,7 +173,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 }
             }
         }
-        else if (!strcmp(tag.getName(), "w")) {
+        else if (tagName == "w"sv) {
             if ((!tag.isEmpty()) && (!tag.isEndTag())) { //start tag
                 const char *attrib;
                 const char *val;
@@ -223,9 +305,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 buf.append("</span>");
             }
         }
-
-        // <note> tag
-        else if (!strcmp(tag.getName(), "note")) {
+        else if (tagName == "note"sv) {
             if (!tag.isEndTag()) { //start tag
                 const sword::SWBuf type( tag.getAttribute("type") );
 
@@ -291,11 +371,12 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 myUserData->suspendTextPassThru = false;
             }
         }
-        else if (!strcmp(tag.getName(), "reference")) { // <reference> tag
+        else if (tagName == "reference"sv) {
             if (!tag.isEndTag() && !tag.isEmpty()) {
-
-                renderReference(tag.getAttribute("osisRef"), buf, myModule, myUserData);
-
+                renderReference(tag.getAttribute("osisRef"),
+                                buf,
+                                *myModule,
+                                *myUserData);
             }
             else if (tag.isEndTag()) {
                 buf.append("</a>");
@@ -304,10 +385,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 // -- what should we do?  nothing for now.
             }
         }
-
-        // <l> is handled by OSISHTMLHref
-        // <title>
-        else if (!strcmp(tag.getName(), "title")) {
+        else if (tagName == "title"sv) {
             if (!tag.isEndTag() && !tag.isEmpty()) {
                 buf.append("<div class=\"sectiontitle\">");
             }
@@ -319,9 +397,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 buf.append("<br/>");
             }
         }
-
-        // <hi> highlighted text
-        else if (!strcmp(tag.getName(), "hi")) {
+        else if (tagName == "hi"sv) { // <hi> highlighted text
             const sword::SWBuf type = tag.getAttribute("type");
 
             if ((!tag.isEndTag()) && (!tag.isEmpty())) {
@@ -354,9 +430,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 buf.append("</span>");
             }
         }
-
-        //name
-        else if (!strcmp(tag.getName(), "name")) {
+        else if (tagName == "name"sv) {
             const sword::SWBuf type = tag.getAttribute("type");
 
             if ((!tag.isEndTag()) && (!tag.isEmpty())) {
@@ -383,7 +457,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 buf.append("</span></span> ");
             }
         }
-        else if (!strcmp(tag.getName(), "transChange")) {
+        else if (tagName == "transChange"sv) {
             sword::SWBuf type( tag.getAttribute("type") );
 
             if ( !type.length() ) {
@@ -421,16 +495,14 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 buf.append("</span></span>");
             }
         }
-        else if (!strcmp(tag.getName(), "p")) {
+        else if (tagName == "p"sv) {
             if (tag.isEndTag())
                 buf.append("</p>");
             else
                 buf.append("<p>");
 
         }
-
-        // <q> quote
-        else if (!strcmp(tag.getName(), "q")) {
+        else if (tagName == "q"sv) { // <q> quote
             //sword::SWBuf type = tag.getAttribute("type");
             sword::SWBuf who = tag.getAttribute("who");
             const char *lev = tag.getAttribute("level");
@@ -466,9 +538,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 myUserData->quote.who = "";
             }
         }
-
-        // abbr tag
-        else if (!strcmp(tag.getName(), "abbr")) {
+        else if (tagName == "abbr"sv) {
             if (!tag.isEndTag() && !tag.isEmpty()) {
                 const sword::SWBuf expansion = tag.getAttribute("expansion");
 
@@ -480,9 +550,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 buf.append("</span>");
             }
         }
-
-        // <milestone> tag
-        else if (!strcmp(tag.getName(), "milestone")) {
+        else if (tagName == "milestone"sv) {
             const sword::SWBuf type = tag.getAttribute("type");
 
             if ((type == "screen") || (type == "line")) {//line break
@@ -497,8 +565,7 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 }
             }
         }
-        //seg tag
-        else if (!strcmp(tag.getName(), "seg")) {
+        else if (tagName == "seg"sv) {
             if (!tag.isEndTag() && !tag.isEmpty()) {
 
                 const sword::SWBuf type = tag.getAttribute("type");
@@ -526,9 +593,8 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
             }
             //qWarning(QString("handled <seg> token. result: %1").arg(buf.c_str()).latin1());
         }
-
         //divine name, don't use simple tag replacing because it may have attributes
-        else if (!strcmp(tag.getName(), "divineName")) {
+        else if (tagName == "divineName"sv) {
             if (!tag.isEndTag()) {
                 buf.append("<span class=\"name\"><span class=\"divine\">");
             }
@@ -536,7 +602,6 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
                 buf.append("</span></span>");
             }
         }
-
         else { //all tokens handled by OSISHTMLHref will run through the filter now
             return sword::OSISHTMLHREF::handleToken(buf, token, userData);
         }
@@ -544,60 +609,3 @@ bool Filters::OsisToHtml::handleToken(sword::SWBuf &buf, const char *token, swor
 
     return false;
 }
-
-void Filters::OsisToHtml::renderReference(const char *osisRef, sword::SWBuf &buf, sword::SWModule *myModule, UserData *myUserData) {
-    QString ref( osisRef );
-    QString hrefRef( ref );
-    //BT_ASSERT(!ref.isEmpty()); checked later
-
-    if (!ref.isEmpty()) {
-        //find out the mod, using the current module makes sense if it's a bible or commentary because the refs link into a bible by default.
-        //If the osisRef is something like "ModuleID:key comes here" then the
-        // modulename is given, so we'll use that one
-
-        CSwordModuleInfo* mod = CSwordBackend::instance()->findSwordModuleByPointer(myModule);
-        //BT_ASSERT(mod); checked later
-        if (!mod || (mod->type() != CSwordModuleInfo::Bible
-                     && mod->type() != CSwordModuleInfo::Commentary)) {
-
-            mod = btConfig().getDefaultSwordModuleByType("standardBible");
-            if (! mod)
-                mod = CSwordBackend::instance()->findFirstAvailableModule(CSwordModuleInfo::Bible);
-        }
-
-        // BT_ASSERT(mod); There's no necessarily a module or standard Bible
-
-        //if the osisRef like "GerLut:key" contains a module, use that
-        int pos = ref.indexOf(":");
-
-        if ((pos >= 0) && ref.at(pos - 1).isLetter() && ref.at(pos + 1).isLetter()) {
-            QString newModuleName = ref.left(pos);
-            hrefRef = ref.mid(pos + 1);
-
-            if (CSwordBackend::instance()->findModuleByName(newModuleName)) {
-                mod = CSwordBackend::instance()->findModuleByName(newModuleName);
-            }
-        }
-
-        if (mod) {
-            ReferenceManager::ParseOptions const options(
-                    mod->name(),
-                    QString::fromUtf8(myUserData->key->getText()),
-                    myModule->getLanguage());
-
-            buf.append("<a href=\"")
-               .append( //create the hyperlink with key and mod
-                    ReferenceManager::encodeHyperlink(
-                        mod->name(),
-                        ReferenceManager::parseVerseReference(hrefRef, options),
-                        ReferenceManager::typeFromModule(mod->type())
-                    ).toUtf8().constData()
-                )
-               .append("\" crossrefs=\"")
-               .append(ReferenceManager::parseVerseReference(ref, options).toUtf8().constData()) //ref must contain the osisRef module marker if there was any
-               .append("\">");
-        }
-        // should we add something if there were no referenced module available?
-    }
-}
-
