@@ -2,23 +2,35 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef FILTERS_OSISTOHTML_H
-#define FILTERS_OSISTOHTML_H
+#pragma once
 
 #include <vector>
 
 // Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wextra-semi"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wsuggest-destructor-override"
+#endif
 #include <osishtmlhref.h>
 #include <swbuf.h>
 #include <swmodule.h>
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+#pragma GCC diagnostic pop
+
 
 namespace Filters {
 
@@ -26,11 +38,11 @@ namespace Filters {
   \brief OSIS to HTMl conversion filter.
 */
 class OsisToHtml: public sword::OSISHTMLHREF {
-    protected: /* Types: */
+    protected: // types:
         class UserData: public sword::OSISHTMLHREF::MyUserData {
             public:
-                inline UserData(const sword::SWModule *module,
-                                const sword::SWKey *key)
+                UserData(sword::SWModule const * module,
+                         sword::SWKey const * key)
                      : sword::OSISHTMLHREF::MyUserData(module, key)
                      , swordFootnote(1)
                      , inCrossrefNote(false)
@@ -54,7 +66,7 @@ class OsisToHtml: public sword::OSISHTMLHREF {
                 } quote;
         };
 
-    public: /* Methods: */
+    public: // methods:
         OsisToHtml();
 
         /** Reimplemented from sword::OSISHTMLHREF. */
@@ -62,20 +74,13 @@ class OsisToHtml: public sword::OSISHTMLHREF {
                          const char *token,
                          sword::BasicFilterUserData *userData) override;
 
-    protected: /* Methods: */
+    protected: // methods:
         /** Reimplemented from sword::OSISHTMLHREF. */
-        inline sword::BasicFilterUserData *createUserData(
-                const sword::SWModule *module,
-                const sword::SWKey *key) override
-        {
-            return new UserData(module, key);
-        }
+        sword::BasicFilterUserData * createUserData(
+                sword::SWModule const * module,
+                sword::SWKey const * key) override
+        { return new UserData(module, key); }
 
-    private: /* Methods: */
-        void renderReference(const char *osisRef, sword::SWBuf &buf,
-                             sword::SWModule *myModule, UserData *myUserData);
 };
 
 } // namespace Filters
-
-#endif
