@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,22 +12,33 @@
 
 #include "thmltohtml.h"
 
-#include <QRegExp>
-#include <QString>
-#include <QTextCodec>
+#include <QRegularExpression>
+#include <QRegularExpressionMatch>
 #include <QUrl>
+#include <utility>
 #include "../../util/btassert.h"
 #include "../config/btconfig.h"
 #include "../drivers/cswordmoduleinfo.h"
-#include "../managers/clanguagemgr.h"
 #include "../managers/cswordbackend.h"
 #include "../managers/referencemanager.h"
 
 // Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wextra-semi"
+#pragma GCC diagnostic ignored "-Wsuggest-override"
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#ifdef __clang__
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wsuggest-destructor-override"
+#endif
 #include <swmodule.h>
 #include <utilstr.h>
 #include <utilxml.h>
 #include <versekey.h>
+#ifdef __clang__
+#pragma clang diagnostic pop
+#endif
+#pragma GCC diagnostic pop
 
 
 namespace Filters {
@@ -51,62 +62,66 @@ char ThmlToHtml::processText(sword::SWBuf &buf, const sword::SWKey *key,
 {
     sword::ThMLHTML::processText(buf, key, module);
 
-    CSwordModuleInfo* m = CSwordBackend::instance()->findModuleByName( module->getName() );
-
-    if (m && !(m->has(CSwordModuleInfo::lemmas) || m->has(CSwordModuleInfo::strongNumbers))) { //only parse if the module has strongs or lemmas
-        return 1;
+    if (auto * const m =
+                CSwordBackend::instance().findModuleByName(module->getName()))
+    {
+        // only parse if the module has strongs or lemmas:
+        if (!m->has(CSwordModuleInfo::lemmas)
+            && !m->has(CSwordModuleInfo::strongNumbers))
+            return 1;
     }
 
-    QString result;
-
-    QString t = QString::fromUtf8(buf.c_str());
-    QRegExp tag("([.,;]?<sync[^>]+(type|value)=\"([^\"]+)\"[^>]+(type|value)=\"([^\"]+)\"([^<]*)>)+");
-
     QStringList list;
-    int lastMatchEnd = 0;
-    int pos = tag.indexIn(t, 0);
+    {
+        auto t = QString::fromUtf8(buf.c_str());
+        {
+            static QRegularExpression const tag(
+                QStringLiteral(R"PCRE(([.,;]?<sync[^>]+(type|value)=)PCRE"
+                               R"PCRE("([^"]+)"[^>]+(type|value)=)PCRE"
+                               R"PCRE("([^"]+)"([^<]*)>)+)PCRE"));
+            QRegularExpressionMatch match;
+            auto pos = t.indexOf(tag, 0, &match);
+            if (pos == -1) //no strong or morph code found in this text
+                return 1; //WARNING: Return already here
+            do {
+                auto const partLength = pos + match.capturedLength();
+                list.append(t.left(partLength));
+                t.remove(0, partLength);
+                pos = t.indexOf(tag, 0, &match);
+            } while (pos != -1);
+        }
 
-    if (pos == -1) { //no strong or morph code found in this text
-        return 1; //WARNING: Return already here
+        // Append the trailing text to the list:
+        if (!t.isEmpty())
+            list.append(std::move(t));
     }
 
-    while (pos != -1) {
-        list.append(t.mid(lastMatchEnd, pos + tag.matchedLength() - lastMatchEnd));
-
-        lastMatchEnd = pos + tag.matchedLength();
-        pos = tag.indexIn(t, pos + tag.matchedLength());
-    }
-
-    if (!t.right(t.length() - lastMatchEnd).isEmpty()) {
-        list.append(t.right(t.length() - lastMatchEnd));
-    }
-
-    tag = QRegExp("<sync[^>]+(type|value|class)=\"([^\"]+)\"[^>]+(type|value|class)=\"([^\"]+)\"[^>]+((type|value|class)=\"([^\"]+)\")*([^<]*)>");
-
-    for (QStringList::iterator it = list.begin(); it != list.end(); ++it) {
-        QString e( *it );
+    static QRegularExpression const tag(
+        QStringLiteral(R"PCRE(<sync[^>]+(type|value|class)="([^"]+)"[^>]+)PCRE"
+                       R"PCRE((type|value|class)="([^"]+)"[^>]+)PCRE"
+                       R"PCRE(((type|value|class)="([^"]+)")*([^<]*)>)PCRE"));
+    QString result;
+    for (auto & e : list) {
 
         // pass text ahead of <sync> stright through
-        int pos2 = tag.indexIn(e, 0);
-        if (pos2 >= 0) {
-            result.append(e.left(pos2));
-            e = e.remove(0, pos2);
+        if (auto const pos = e.indexOf(tag); pos > 0) {
+            result.append(e.left(pos));
+            e.remove(0, pos);
         }
 
         // parse <sync> and change to <span>
         bool hasLemmaAttr = false;
         bool hasMorphAttr = false;
 
-        int pos = tag.indexIn(e, 0);
+        QRegularExpressionMatch match;
+        auto pos = e.indexOf(tag, 0, &match);
         bool insertedTag = false;
-        QString value;
-        QString valueClass;
 
         while (pos != -1) {
             bool isMorph = false;
             bool isStrongs = false;
-            value = QString();
-            valueClass = QString();
+            QString value;
+            QString valueClass;
 
             // check 3 attribute/value pairs
 
@@ -114,23 +129,23 @@ char ThmlToHtml::processText(sword::SWBuf &buf, const sword::SWKey *key,
                 if (i > 4)
                     i++;
 
-                if (tag.cap(i) == "type") {
-                    isMorph   = (tag.cap(i + 1) == "morph");
-                    isStrongs = (tag.cap(i + 1) == "Strongs");
-                }
-                else if (tag.cap(i) == "value") {
-                    value = tag.cap(i + 1);
-                }
-                else if (tag.cap(i) == "class") {
-                    valueClass = tag.cap(i + 1);
+                auto const attrName = match.captured(i);
+                auto const attrValue = match.captured(i + 1);
+                if (attrName == QStringLiteral("type")) {
+                    isMorph   = (attrValue == QStringLiteral("morph"));
+                    isStrongs = (attrValue == QStringLiteral("Strongs"));
+                } else if (attrName == QStringLiteral("value")) {
+                    value = attrValue;
+                } else if (attrName == QStringLiteral("class")) {
+                    valueClass = attrValue;
+                } else { // optional 3rd attribute pair is not present:
+                    BT_ASSERT(attrName.isEmpty());
                 }
             }
 
             // prepend the class qualifier to the value
-            if (!valueClass.isEmpty()) {
-                value = valueClass + ":" + value;
-                //     value.append(":").append(value);
-            }
+            if (!valueClass.isEmpty())
+                value = QStringLiteral("%1:%2").arg(valueClass, value);
 
             if (value.isEmpty()) {
                 break;
@@ -138,10 +153,10 @@ char ThmlToHtml::processText(sword::SWBuf &buf, const sword::SWKey *key,
 
             //insert the span
             if (!insertedTag) {
-                e.replace(pos, tag.matchedLength(), "</span>");
+                e.replace(pos, match.capturedLength(), QStringLiteral("</span>"));
                 pos += 7;
 
-                QString rep = QString("<span lemma=\"").append(value).append("\">");
+                auto rep = QStringLiteral("<span lemma=\"%1\">").arg(value);
                 int startPos = 0;
                 QChar c = e[startPos];
 
@@ -153,20 +168,32 @@ char ThmlToHtml::processText(sword::SWBuf &buf, const sword::SWKey *key,
                 hasLemmaAttr = isStrongs;
                 hasMorphAttr = isMorph;
 
-                e.insert( startPos, rep );
                 pos += rep.length();
+                e.insert(startPos, std::move(rep));
             }
             else { //add the attribute to the existing tag
-                e.remove(pos, tag.matchedLength());
+                e.remove(pos, match.capturedLength());
 
                 if ((!isMorph && hasLemmaAttr) || (isMorph && hasMorphAttr)) { //we append another attribute value, e.g. 3000 gets 3000|5000
                     //search the existing attribute start
-                    QRegExp attrRegExp( isMorph ? "morph=\".+(?=\")" : "lemma=\".+(?=\")" );
-                    attrRegExp.setMinimal(true);
-                    const int foundAttrPos = e.indexOf(attrRegExp, pos);
+                    auto const & attrRegExp =
+                        [isMorph]{
+                            if (isMorph) {
+                                static QRegularExpression const re(
+                                    QStringLiteral("morph=\".+?(?=\")"));
+                                return re;
+                            } else {
+                                static QRegularExpression const re(
+                                    QStringLiteral("lemma=\".+?(?=\")"));
+                                return re;
+                            }
+                        }();
+                    QRegularExpressionMatch match;
+                    const int foundAttrPos = e.indexOf(attrRegExp, pos, &match);
 
                     if (foundAttrPos != -1) {
-                        e.insert(foundAttrPos + attrRegExp.matchedLength(), QString("|").append(value));
+                        e.insert(foundAttrPos + match.capturedLength(),
+                                 QStringLiteral("|%1").arg(value));
                         pos += value.length() + 1;
 
                         hasLemmaAttr = !isMorph;
@@ -174,29 +201,33 @@ char ThmlToHtml::processText(sword::SWBuf &buf, const sword::SWKey *key,
                     }
                 }
                 else { //attribute was not yet inserted
-                    const int attrPos = e.indexOf(QRegExp("morph=|lemma="), 0);
+                    static QRegularExpression const re(
+                        QStringLiteral("morph=|lemma="));
+                    const int attrPos = e.indexOf(re, 0);
 
                     if (attrPos >= 0) {
-                        QString attr;
-                        attr.append(isMorph ? "morph" : "lemma").append("=\"").append(value).append("\" ");
-                        e.insert(attrPos, attr);
-
                         hasMorphAttr = isMorph;
                         hasLemmaAttr = !isMorph;
 
+                        auto attr = QStringLiteral("%1=\"%2\" ")
+                                    .arg(isMorph
+                                         ? QStringLiteral("morph")
+                                         : QStringLiteral("lemma"),
+                                         value);
                         pos += attr.length();
+                        e.insert(attrPos, std::move(attr)); /// \bug e.replace() instead?
                     }
                 }
             }
 
             insertedTag = true;
-            pos = tag.indexIn(e, pos);
+            pos = e.indexOf(tag, pos, &match);
         }
 
-        result.append( e );
+        result.append(std::move(e));
     }
 
-    if (list.count())
+    if (!list.isEmpty())
         buf = result.toUtf8();
 
     return 1;
@@ -265,29 +296,27 @@ bool ThmlToHtml::handleToken(sword::SWBuf &buf, const char *token,
                                 btConfig().getDefaultSwordModuleByType(
                                         "standardBible"))
                         {
-                            ReferenceManager::ParseOptions options(
+                            ReferenceManager::ParseOptions options{
                                     mod->name(),
                                     // current module key:
                                     QString::fromUtf8(myUserData->key->getText()),
-                                    myModule->getLanguage());
+                                    myModule->getLanguage()};
 
                             //it's ok to split the reference, because to descriptive text is given
                             bool insertSemicolon = false;
                             buf.append("<span class=\"crossreference\">");
                             QStringList const refs(
                                 QString::fromUtf8(
-                                    myUserData->lastTextNode.c_str()).split(";"));
+                                    myUserData->lastTextNode.c_str()).split(
+                                            ';'));
                             QString oldRef; // the previous reference to use as a base for the next refs
-                            for (QStringList::const_iterator it(refs.begin());
-                                 it != refs.end();
-                                 ++it)
-                            {
+                            for (auto const & ref : refs) {
                                 if (!oldRef.isEmpty())
                                     options.refBase = oldRef; // Use the last ref as a base, e.g. Rom 1,2-3, when the next ref is only 3:3-10
 
                                 // Use the parsed result as the base for the next ref:
                                 oldRef = ReferenceManager::parseVerseReference(
-                                                (*it),
+                                                ref,
                                                 options);
 
                                 // Prepend a ref divider if we're after the first one
@@ -297,15 +326,14 @@ bool ThmlToHtml::handleToken(sword::SWBuf &buf, const char *token,
                                 buf.append("<a href=\"")
                                    .append(
                                         ReferenceManager::encodeHyperlink(
-                                            mod->name(),
-                                            oldRef,
-                                            ReferenceManager::typeFromModule(mod->type())
+                                            *mod,
+                                            oldRef
                                         ).toUtf8().constData()
                                     )
                                    .append("\" crossrefs=\"")
                                    .append(oldRef.toUtf8().constData())
                                    .append("\">")
-                                   .append(it->toUtf8().constData())
+                                   .append(ref.toUtf8().constData())
                                    .append("</a>");
                                 insertSemicolon = true;
                             }
@@ -318,31 +346,28 @@ bool ThmlToHtml::handleToken(sword::SWBuf &buf, const char *token,
                     myUserData->inscriptRef = true;
                     myUserData->suspendTextPassThru = false;
 
-                    CSwordModuleInfo * mod = btConfig().getDefaultSwordModuleByType("standardBible");
+                    auto * mod = btConfig().getDefaultSwordModuleByType(
+                                     QStringLiteral("standardBible"));
                     if (! mod)
-                        mod = CSwordBackend::instance()->findFirstAvailableModule(CSwordModuleInfo::Bible);
+                        mod = CSwordBackend::instance().findFirstAvailableModule(CSwordModuleInfo::Bible);
 
-                    if (mod)
-                    {
-                        ;
+                    if (mod) {
                         BT_ASSERT(tag.getAttribute("passage"));
                         QString const completeRef(
                                 ReferenceManager::parseVerseReference(
                                     QString::fromUtf8(
                                             tag.getAttribute("passage")),
-                                    ReferenceManager::ParseOptions(
+                                    ReferenceManager::ParseOptions{
                                         mod->name(),
                                         QString::fromUtf8(
                                                 myUserData->key->getText()),
-                                        myModule->getLanguage())));
+                                        myModule->getLanguage()}));
                         buf.append("<span class=\"crossreference\">")
                            .append("<a href=\"")
                            .append(
                                 ReferenceManager::encodeHyperlink(
-                                    mod->name(),
-                                    completeRef,
-                                    ReferenceManager::typeFromModule(
-                                        mod->type())
+                                    *mod,
+                                    completeRef
                                 ).toUtf8().constData()
                             )
                            .append("\" crossrefs=\"")
@@ -374,13 +399,21 @@ bool ThmlToHtml::handleToken(sword::SWBuf &buf, const char *token,
             if (value[0] == '/')
                 value++; //strip the first /
 
+            if (!myUserData->absolutePath.has_value()) {
+                auto const * const absoluteDataPath =
+                        myUserData->module->getConfigEntry("AbsoluteDataPath");
+                myUserData->absolutePath.emplace(
+                        myUserData->module->isUnicode()
+                        ? QString::fromUtf8(absoluteDataPath)
+                        : QString::fromLatin1(absoluteDataPath));
+            }
+
             buf.append("<img src=\"")
                .append(
                     QUrl::fromLocalFile(
-                        QTextCodec::codecForLocale()->toUnicode(
-                            myUserData->module->getConfigEntry(
-                                "AbsoluteDataPath")
-                        ).append('/').append(QString::fromUtf8(value))
+                        QStringLiteral("%1/%2").arg(
+                            *myUserData->absolutePath,
+                            QString::fromUtf8(value))
                     ).toString().toUtf8().constData())
                .append("\" />");
         } else { // Let unknown token pass thru:
