@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,20 +12,30 @@
 
 #include "cswordtreekey.h"
 
-#include <QDebug>
-#include <QTextCodec>
+#include <QByteArray>
 #include "../../util/btassert.h"
+#include "../../util/cp1252.h"
 #include "../drivers/cswordbookmoduleinfo.h"
+#include "../drivers/cswordmoduleinfo.h"
+#include "cswordkey.h"
+
+// Sword includes:
+#include <treekeyidx.h>
 
 
-CSwordTreeKey::CSwordTreeKey( const CSwordTreeKey& k ) : CSwordKey(k), TreeKeyIdx(k) {}
+CSwordTreeKey::CSwordTreeKey(CSwordTreeKey const & copy)
+    : CSwordKey(copy)
+    , m_key(copy.m_key)
+{}
 
-CSwordTreeKey::CSwordTreeKey(const TreeKeyIdx *k,
-                             const CSwordModuleInfo *module)
-    : CSwordKey(module), TreeKeyIdx(*k)
-{
-    // Intentionally empty
-}
+CSwordTreeKey::CSwordTreeKey(sword::TreeKeyIdx const * k,
+                             CSwordModuleInfo const * module)
+    : CSwordKey(module)
+    , m_key(*k)
+{}
+
+sword::TreeKeyIdx const & CSwordTreeKey::asSwordKey() const noexcept
+{ return m_key; }
 
 CSwordTreeKey* CSwordTreeKey::copy() const {
     return new CSwordTreeKey(*this);
@@ -36,16 +46,14 @@ QString CSwordTreeKey::key() const {
     //return getTextUnicode();
     BT_ASSERT(m_module);
     if (m_module->isUnicode()) {
-        return QString::fromUtf8(getText());
+        return QString::fromUtf8(m_key.getText());
     }
     else {
-        return cp1252Codec()->toUnicode(getText());
+        return util::cp1252::toUnicode(m_key.getText());
     }
 }
 
-const char * CSwordTreeKey::rawKey() const {
-    return getText();
-}
+const char * CSwordTreeKey::rawKey() const { return m_key.getText(); }
 
 bool CSwordTreeKey::setKey(const QString &newKey) {
     //return key( newKey.toLocal8Bit().constData() );
@@ -55,7 +63,7 @@ bool CSwordTreeKey::setKey(const QString &newKey) {
         return setKey(newKey.toUtf8().constData());
     }
     else {
-        return setKey(cp1252Codec()->fromUnicode(newKey).constData());
+        return setKey(util::cp1252::fromUnicode(newKey).constData());
     }
 }
 
@@ -63,13 +71,13 @@ bool CSwordTreeKey::setKey(const char *newKey) {
     BT_ASSERT(newKey);
 
     if (newKey) {
-        TreeKeyIdx::operator = (newKey);
+        m_key = newKey;
     }
     else {
-        root();
+        positionToRoot();
     }
 
-    return !popError();
+    return !m_key.popError();
 }
 
 QString CSwordTreeKey::getLocalNameUnicode() {
@@ -77,10 +85,10 @@ QString CSwordTreeKey::getLocalNameUnicode() {
     //Only UTF-8 and latin1 are legal Sword module encodings
     BT_ASSERT(m_module);
     if (m_module->isUnicode()) {
-        return QString::fromUtf8(getLocalName());
+        return QString::fromUtf8(m_key.getLocalName());
     }
     else {
-        return cp1252Codec()->toUnicode(getLocalName());
+        return util::cp1252::toUnicode(m_key.getLocalName());
     }
 }
 
@@ -88,17 +96,18 @@ void CSwordTreeKey::setModule(const CSwordModuleInfo *newModule) {
     BT_ASSERT(newModule);
     if (m_module == newModule) return;
     BT_ASSERT(newModule->type() == CSwordModuleInfo::GenericBook);
+    BT_ASSERT(dynamic_cast<CSwordBookModuleInfo const *>(newModule));
 
     m_module = newModule;
 
     const QString oldKey = key();
 
-    const CSwordBookModuleInfo *newBook = dynamic_cast<const CSwordBookModuleInfo*>(newModule);
-    copyFrom( *(newBook->tree()) );
+    m_key.copyFrom(
+                *static_cast<CSwordBookModuleInfo const *>(newModule)->tree());
 
     setKey(oldKey); //try to restore our old key
 
     //set the key to the root node
-    root();
-    firstChild();
+    positionToRoot();
+    positionToFirstChild();
 }
