@@ -2,21 +2,25 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTEDITBOOKMARKDIALOG_H
-#define BTEDITBOOKMARKDIALOG_H
+#pragma once
 
 #include <QDialog>
+
 #include <QLineEdit>
+#include <QObject>
+#include <QString>
+#include <Qt>
 #include <QTextEdit>
 
+
 class QDialogButtonBox;
 class QFormLayout;
 class QLabel;
@@ -28,7 +32,7 @@ class QWidget;
 class BtEditBookmarkDialog : public QDialog  {
         Q_OBJECT
 
-    public: /* Methods: */
+    public: // methods:
         BtEditBookmarkDialog(const QString &key,
                              const QString &title,
                              const QString &description,
@@ -38,19 +42,17 @@ class BtEditBookmarkDialog : public QDialog  {
         /**
         * Returns the description written in the description box.
         */
-        inline const QString descriptionText() {
-            return m_descriptionEdit->toPlainText();
-        }
+        QString descriptionText() { return m_descriptionEdit->toPlainText(); }
 
         /**
         * Returns the title written in the title box.
         */
-        inline const QString titleText() { return m_titleEdit->text(); }
+        QString titleText() { return m_titleEdit->text(); }
 
-    protected: /* Methods: */
+    protected: // methods:
         void retranslateUi();
 
-    private: /* Fields: */
+    private: // fields:
         QFormLayout *m_layout;
             QLabel *m_keyLabel;
                 QLabel *m_keyTextLabel;
@@ -61,5 +63,3 @@ class BtEditBookmarkDialog : public QDialog  {
         QDialogButtonBox *m_buttonBox;
 
 };
-
-#endif
