@@ -2,20 +2,20 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CBOOKMARKINDEX_H
-#define CBOOKMARKINDEX_H
+#pragma once
 
 #include <QTimer>
 #include <QToolTip>
 #include <QTreeView>
+#include "../../backend/rendering/btinforendering.h"
 
 
 class BTMimeData;
@@ -38,7 +38,7 @@ class CBookmarkIndex: public QTreeView {
 
     Q_OBJECT
 
-public: /* Types: */
+public: // types:
 
     enum MenuAction {
         NewFolder = 0,
@@ -58,16 +58,17 @@ public: /* Types: */
         ActionEnd = ActionCount
     };
 
-public: /* Methods: */
+public: // methods:
 
     CBookmarkIndex(QWidget * const parent = nullptr);
 
-signals:
+Q_SIGNALS:
 
     /** \brief Emitted when a module should be opened. */
     void createReadDisplayWindow(QList<CSwordModuleInfo *>, QString const &);
+    void magInfoProvided(Rendering::InfoType const, QString const & data);
 
-protected: /* Methods: */
+protected: // methods:
 
     QMimeData * dragObject();
 
@@ -81,52 +82,9 @@ protected: /* Methods: */
     void mouseMoveEvent(QMouseEvent * event) override;
     void leaveEvent(QEvent * event) override;
 
-protected slots:
+private: // methods:
 
-    /** Prevents annoying folder collapsing while dropping. */
-    void expandAutoCollapsedItem(QModelIndex const & index) { expand(index); }
-
-    /** Is called when an item was clicked or activated. */
-    void slotExecuted(QModelIndex const & index);
-
-    /** Shows the context menu at the given position. */
-    void contextMenu(QPoint const & p);
-
-    /** Adds a new subfolder to the current item. */
-    void createNewFolder();
-
-    /** Opens a dialog to change the current folder. */
-    void changeFolder();
-
-    /** Exports the bookmarks from the selected folder. */
-    void exportBookmarks();
-
-    /** Changes the current bookmark. */
-    void editBookmark();
-
-    /** Sorts the current folder bookmarks. */
-    void sortFolderBookmarks();
-
-    /** Sorts all bookmarks. */
-    void sortAllBookmarks();
-
-    /** Import bookmarks from a file and add them to the selected folder. */
-    void importBookmarks();
-
-    /** Deletes the selected entries after user confirmation. */
-    void confirmDeleteEntries();
-
-    /** Deletes the selected entries. */
     void deleteEntries();
-
-    /** Prints the selected bookmarks. */
-    void printBookmarks();
-
-    /** Slot for the mag update timer. */
-    void magTimeout();
-
-private: /* Methods: */
-
     bool enableAction(QModelIndex const & index,
                       MenuAction const type) const;
 
@@ -135,7 +93,7 @@ private: /* Methods: */
     void showExtraItem();
     void hideExtraItem();
 
-private: /* Fields: */
+private: // fields:
 
     QAction * m_actions[ActionCount];
 
@@ -151,5 +109,3 @@ private: /* Fields: */
     BtBookmarksModel * m_bookmarksModel;
 
 };
-
-#endif
