@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,12 +12,14 @@
 
 #include "btbookshelfremovefinalpage.h"
 
-#include <QDebug>
 #include <QLabel>
+#include <QSizePolicy>
 #include <QSpacerItem>
+#include <QStringLiteral>
+#include <Qt>
 #include <QVBoxLayout>
+#include "../../backend/drivers/btmoduleset.h"
 #include "../../backend/managers/cswordbackend.h"
-#include "../../util/btconnect.h"
 #include "btbookshelfwizard.h"
 
 
@@ -30,7 +32,6 @@ BtBookshelfRemoveFinalPage::BtBookshelfRemoveFinalPage(QWidget * parent)
     : BtBookshelfWizardPage(parent)
 {
     m_verticalLayout = new QVBoxLayout(this);
-    m_verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
 
     m_verticalLayout->addItem(new QSpacerItem(20,
                                               40,
@@ -39,7 +40,6 @@ BtBookshelfRemoveFinalPage::BtBookshelfRemoveFinalPage(QWidget * parent)
 
     m_msgLabel = new QLabel(this);
     m_msgLabel->setAlignment(Qt::AlignCenter);
-    m_msgLabel->setObjectName(QStringLiteral("msgLabel"));
     m_msgLabel->setWordWrap(true);
     m_verticalLayout->addWidget(m_msgLabel);
 
@@ -56,7 +56,7 @@ void BtBookshelfRemoveFinalPage::initializePage() {
     retranslateUi();
 
     // Remove works:
-    CSwordBackend::instance()->uninstallModules(btWizard().selectedWorks());
+    CSwordBackend::instance().uninstallModules(btWizard().selectedWorks());
 }
 
 bool BtBookshelfRemoveFinalPage::isComplete() const { return true; }
