@@ -2,48 +2,45 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFREMOVEFINALPAGE
-#define BTBOOKSHELFREMOVEFINALPAGE
+#pragma once
 
 #include "btbookshelfwizardpage.h"
 
-#include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
-#include "../../backend/drivers/btmoduleset.h"
+#include <QObject>
+#include <QString>
 
 
-class BtBookshelfWizard;
 class QLabel;
 class QVBoxLayout;
+class QWidget;
 
 class BtBookshelfRemoveFinalPage final: public BtBookshelfWizardPage {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
-    BtBookshelfRemoveFinalPage(QWidget * parent = 0);
+    BtBookshelfRemoveFinalPage(QWidget * parent = nullptr);
 
     bool isComplete() const final override;
     void initializePage() final override;
     int nextId() const final override;
 
-private: /* Methods: */
+private: // methods:
 
     void retranslateUi();
 
-private: /* Fields: */
+private: // fields:
 
     QLabel * m_msgLabel;
     QVBoxLayout * m_verticalLayout;
 
 }; /* class BtBookshelfRemoveFinalPage */
-
-#endif
