@@ -2,34 +2,36 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFSOURCESPROGRESSPAGE
-#define BTBOOKSHELFSOURCESPROGRESSPAGE
+#pragma once
 
 #include "btbookshelfwizardpage.h"
 
+#include <QObject>
+#include <QString>
+
 
 class BtSourcesThread;
 class QLabel;
 class QProgressBar;
 class QPushButton;
+class QWidget;
 
 class BtBookshelfSourcesProgressPage final: public BtBookshelfWizardPage {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
-    BtBookshelfSourcesProgressPage(QWidget * parent = 0);
-    inline ~BtBookshelfSourcesProgressPage() noexcept override
-    { destroyThread(); }
+    BtBookshelfSourcesProgressPage(QWidget * parent = nullptr);
+    ~BtBookshelfSourcesProgressPage() noexcept override { destroyThread(); }
 
     void destroyThread() noexcept;
 
@@ -37,18 +39,18 @@ public: /* Methods: */
     bool isComplete() const final override;
     int nextId() const final override;
 
-public slots:
+public Q_SLOTS:
     void slotStopInstall();
 
-private slots:
+private Q_SLOTS:
 
     void slotThreadFinished();
 
-private: /* Methods: */
+private: // methods:
 
     void retranslateUi();
 
-private: /* Methods: */
+private: // methods:
 
     bool m_installCompleted = false;
     QLabel * m_msgLabel;
@@ -57,5 +59,3 @@ private: /* Methods: */
     BtSourcesThread * m_thread = nullptr;
 
 };
-
-#endif
