@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,27 +12,52 @@
 
 #include "btbookshelfworkspage.h"
 
+#include <algorithm>
+#include <QAbstractItemView>
 #include <QApplication>
+#include <QByteArray>
 #include <QComboBox>
+#include <QDir>
+#include <QFileInfo>
 #include <QHBoxLayout>
 #include <QHeaderView>
 #include <QLabel>
 #include <QLineEdit>
+#include <QMenu>
+#include <QNonConstOverload>
 #include <QSet>
+#include <QSizePolicy>
+#include <QStringList>
+#include <QStringLiteral>
+#include <Qt>
 #include <QToolButton>
 #include <QVBoxLayout>
+#include <QWizard>
+#include <utility>
 #include "../../backend/btinstallbackend.h"
+#include "../../backend/bookshelfmodel/btbookshelfmodel.h"
 #include "../../backend/bookshelfmodel/btbookshelffiltermodel.h"
+#include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
 #include "../../backend/config/btconfig.h"
+#include "../../backend/drivers/btmoduleset.h"
+#include "../../backend/drivers/cswordmoduleinfo.h"
+#include "../../backend/language.h"
 #include "../../backend/managers/cswordbackend.h"
 #include "../../util/btassert.h"
 #include "../../util/btconnect.h"
-#include "../../util/directory.h"
 #include "../btbookshelfgroupingmenu.h"
 #include "../btbookshelfview.h"
 #include "btbookshelfwizard.h"
 #include "btinstallpagemodel.h"
 
+// Sword includes:
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wzero-as-null-pointer-constant"
+#include <installmgr.h>
+#include <swbuf.h>
+#include <swversion.h>
+#pragma GCC diagnostic pop
+
 
 namespace {
 QString const groupingOrderKey("GUI/BookshelfWizard/InstallPage/grouping");
@@ -44,19 +69,19 @@ inline bool filter(WizardTaskType const taskType,
                    CSwordModuleInfo const * const mInfo)
 {
     if (taskType == WizardTaskType::installWorks) {
-        return !CSwordBackend::instance()->findModuleByName(mInfo->name())
+        return !CSwordBackend::instance().findModuleByName(mInfo->name())
                && languages.contains(mInfo->language()->translatedName());
     } else if (taskType == WizardTaskType::updateWorks) {
         using CSMI = CSwordModuleInfo;
         using CSV = sword::SWVersion const;
         CSMI const * const installedModule =
-                CSwordBackend::instance()->findModuleByName(mInfo->name());
+                CSwordBackend::instance().findModuleByName(mInfo->name());
         return installedModule
                && (CSV(installedModule->config(CSMI::ModuleVersion).toLatin1())
                    < CSV(mInfo->config(CSMI::ModuleVersion).toLatin1()));
     } else {
         BT_ASSERT(taskType == WizardTaskType::removeWorks);
-        return CSwordBackend::instance()->findModuleByName(mInfo->name());
+        return CSwordBackend::instance().findModuleByName(mInfo->name());
     }
 }
 
@@ -66,17 +91,19 @@ BtBookshelfWorksPage::BtBookshelfWorksPage(WizardTaskType iType,
                                            QWidget * parent)
     : BtBookshelfWizardPage(parent)
     , m_taskType(iType)
-    , m_groupingOrder(groupingOrderKey)
 {
+    if (!m_groupingOrder.loadFrom(btConfig(), groupingOrderKey))
+        m_groupingOrder = BtBookshelfTreeModel::Grouping::DEFAULT;
+
     // Initialize menus:
     m_groupingMenu = new BtBookshelfGroupingMenu(this);
+    m_groupingMenu->setGrouping(m_groupingOrder);
     m_contextMenu = new QMenu(this);
     m_contextMenu->addMenu(m_groupingMenu);
     m_itemContextMenu = m_contextMenu;
 
     // Setup UI:
     QVBoxLayout * const verticalLayout = new QVBoxLayout(this);
-    verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
 
     QHBoxLayout * horizontalLayout = new QHBoxLayout;
     m_nameFilterLabel = new QLabel(this);
@@ -87,7 +114,6 @@ BtBookshelfWorksPage::BtBookshelfWorksPage(WizardTaskType iType,
     verticalLayout->addLayout(horizontalLayout);
 
     m_bookshelfView = new BtBookshelfView(this);
-    m_bookshelfView->setObjectName(QStringLiteral("worksTreeView"));
     m_bookshelfView->setHeaderHidden(false);
     m_bookshelfView->header()->setSectionResizeMode(
             QHeaderView::ResizeToContents);
@@ -140,9 +166,10 @@ BtBookshelfWorksPage::BtBookshelfWorksPage(WizardTaskType iType,
         m_installPageModel->setDefaultChecked(BtBookshelfTreeModel::CHECKED);
     filterModel->setSourceModel(m_installPageModel);
 
-    m_bookshelfModel = new BtBookshelfModel(this);
+    /// \todo is this useless if m_taskType == WizardTaskType::removeWorks?
+    m_bookshelfModel = BtBookshelfModel::newInstance();
     if (m_taskType == WizardTaskType::removeWorks) {
-        m_installPageModel->setSourceModel(CSwordBackend::instance()->model());
+        m_installPageModel->setSourceModel(CSwordBackend::instance().model());
     } else {
         m_installPageModel->setSourceModel(m_bookshelfModel);
     }
@@ -155,20 +182,18 @@ BtBookshelfWorksPage::BtBookshelfWorksPage(WizardTaskType iType,
                this,
                &BtBookshelfWorksPage::slotGroupingActionTriggered);
     if (m_taskType != WizardTaskType::removeWorks) {
-        BT_CONNECT(m_pathCombo,
-                   static_cast<void (QComboBox::*)(int)>(
-                        &QComboBox::currentIndexChanged),
+        BT_CONNECT(m_pathCombo, qOverload<int>(&QComboBox::currentIndexChanged),
                    this, &BtBookshelfWorksPage::slotPathChanged);
         BT_CONNECT(
-                CSwordBackend::instance(), &CSwordBackend::sigSwordSetupChanged,
+                &CSwordBackend::instance(), &CSwordBackend::sigSwordSetupChanged,
                 this, &BtBookshelfWorksPage::slotInitPathCombo);
     }
     BT_CONNECT(m_installPageModel, &BtBookshelfTreeModel::moduleChecked,
                this,               &BtBookshelfWorksPage::completeChanged);
     BT_CONNECT(m_installPageModel, &BtInstallPageModel::groupingOrderChanged,
                this, &BtBookshelfWorksPage::slotGroupingOrderChanged);
-    BT_CONNECT(m_nameFilterEdit, SIGNAL(textEdited(QString)),
-               filterModel, SLOT(setNameFilterFixedString(QString)));
+    BT_CONNECT(m_nameFilterEdit, &QLineEdit::textEdited,
+               filterModel, &BtBookshelfFilterModel::setNameFilterFixedString);
 
     retranslateUi();
 }
@@ -241,10 +266,13 @@ void BtBookshelfWorksPage::initializePage() {
     {
         QSet<QString> addedModuleNames;
         m_bookshelfModel->clear();
+        m_usedBackends.clear();
         for (auto const & sourceName : sources) {
             sword::InstallSource const source =
                     BtInstallBackend::source(sourceName);
-            CSwordBackend * const backend = BtInstallBackend::backend(source);
+            std::unique_ptr<CSwordBackend const> backend(
+                        BtInstallBackend::backend(source));
+            bool backendUsed = false;
             for (auto * const module : backend->moduleList()) {
                 if (filter(m_taskType, languages, module)) {
                     QString const & moduleName = module->name();
@@ -254,8 +282,11 @@ void BtBookshelfWorksPage::initializePage() {
                     m_bookshelfModel->addModule(module);
                     module->setProperty("installSourceName",
                                         QString(source.caption.c_str()));
+                    backendUsed = true;
                 }
             }
+            if (backendUsed)
+                m_usedBackends.emplace_back(std::move(backend));
         }
         if (m_taskType != WizardTaskType::installWorks)
             m_bookshelfView->expandAll();
@@ -268,9 +299,8 @@ void BtBookshelfWorksPage::initializePage() {
     }
 
     // Set grouping:
-    static BtBookshelfTreeModel::Grouping const cat(
-            BtBookshelfTreeModel::GROUP_CATEGORY);
-    static BtBookshelfTreeModel::Grouping const catLang; // No grouping
+    auto const & cat = BtBookshelfTreeModel::Grouping::CAT;
+    auto const & catLang = BtBookshelfTreeModel::Grouping::CAT_LANG;
     if (languages.count() == 1) {
         slotGroupingActionTriggered(cat);
     } else if (languages.count() > 1 && m_groupingOrder == cat) {
@@ -282,7 +312,7 @@ void BtBookshelfWorksPage::slotGroupingActionTriggered(
         BtBookshelfTreeModel::Grouping const & grouping)
 {
     m_installPageModel->setGroupingOrder(grouping);
-    m_bookshelfView->setRootIsDecorated(!grouping.isEmpty());
+    m_bookshelfView->setRootIsDecorated(!grouping.list().isEmpty());
 }
 
 bool BtBookshelfWorksPage::isComplete() const
@@ -292,7 +322,7 @@ void BtBookshelfWorksPage::slotGroupingOrderChanged(
         BtBookshelfTreeModel::Grouping const & g)
 {
     m_groupingOrder = g;
-    m_groupingOrder.saveTo(groupingOrderKey);
+    m_groupingOrder.saveTo(btConfig(), groupingOrderKey);
 }
 
 BtModuleSet const & BtBookshelfWorksPage::checkedModules() const
@@ -315,11 +345,10 @@ static bool installPathIsUsable(QString const & path) {
 
 void BtBookshelfWorksPage::slotInitPathCombo() {
     m_pathCombo->clear();
-    QStringList const targets(BtInstallBackend::targetList());
     bool haveUsableTargets = false;
-    for (auto const & target : targets) {
+    for (auto const & target : CSwordBackend::instance().swordDirList()) {
         if (installPathIsUsable(target)) {
-            m_pathCombo->addItem(util::directory::convertDirSeparators(target));
+            m_pathCombo->addItem(QDir::toNativeSeparators(target));
             haveUsableTargets = true;
         }
     }
