@@ -2,21 +2,24 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFWORKSPAGE
-#define BTBOOKSHELFWORKSPAGE
+#pragma once
 
 #include "btbookshelfwizardpage.h"
 
+#include <memory>
+#include <QObject>
+#include <QString>
+#include <vector>
 #include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
-#include "../../backend/drivers/btmoduleset.h"
+#include "../../backend/managers/cswordbackend.h"
 #include "btbookshelfwizardenums.h"
 
 
@@ -24,17 +27,19 @@ class BtBookshelfGroupingMenu;
 class BtBookshelfModel;
 class BtBookshelfView;
 class BtInstallPageModel;
+class BtModuleSet;
 class QComboBox;
 class QLabel;
 class QLineEdit;
 class QMenu;
 class QToolButton;
+class QWidget;
 
 class BtBookshelfWorksPage final: public BtBookshelfWizardPage {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
     BtBookshelfWorksPage(WizardTaskType iType, QWidget * parent = nullptr);
 
@@ -44,7 +49,7 @@ public: /* Methods: */
     QString installPath() const;
     int nextId() const final override;
 
-private slots:
+private Q_SLOTS:
 
     void slotGroupingActionTriggered(
             BtBookshelfTreeModel::Grouping const & grouping);
@@ -52,11 +57,11 @@ private slots:
     void slotPathChanged(int const index);
     void slotInitPathCombo();
 
-private: /* Methods: */
+private: // methods:
 
     void retranslateUi();
 
-private: /* Fields: */
+private: // fields:
 
     WizardTaskType const m_taskType;
     BtBookshelfTreeModel::Grouping m_groupingOrder;
@@ -72,12 +77,11 @@ private: /* Fields: */
     QLineEdit * m_nameFilterEdit;
 
     BtInstallPageModel * m_installPageModel;
-    BtBookshelfModel * m_bookshelfModel;
+    std::vector<std::unique_ptr<CSwordBackend const>> m_usedBackends;
+    std::shared_ptr<BtBookshelfModel> m_bookshelfModel;
 
     QMenu * m_contextMenu;
     BtBookshelfGroupingMenu * m_groupingMenu;
     QMenu * m_itemContextMenu;
 
 }; /* class BtBookshelfWorksPage */
-
-#endif
