@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,6 +12,8 @@
 
 #include "btinstallpagemodel.h"
 
+#include <QtGlobal>
+#include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
 #include "../../backend/drivers/cswordmoduleinfo.h"
 #include "../../backend/managers/cswordbackend.h"
 
@@ -35,12 +37,13 @@ QVariant BtInstallPageModel::data(QModelIndex const & i, int role) const {
                             module(index(i.row(), 0, i.parent())))
                     {
                         if (CSwordModuleInfo * imodule =
-                                CSwordBackend::instance()->findModuleByName(
+                                CSwordBackend::instance().findModuleByName(
                                         m->name()))
-                            return imodule->config(
-                                        CSwordModuleInfo::ModuleVersion)
-                                   + " => "
-                                   + m->config(CSwordModuleInfo::ModuleVersion);
+                            return QStringLiteral("%1 => %2")
+                                    .arg(imodule->config(
+                                             CSwordModuleInfo::ModuleVersion),
+                                         m->config(
+                                             CSwordModuleInfo::ModuleVersion));
                         return m->config(CSwordModuleInfo::ModuleVersion);
                     }
                     break;
@@ -63,7 +66,7 @@ QVariant BtInstallPageModel::data(QModelIndex const & i, int role) const {
 }
 
 int BtInstallPageModel::columnCount(QModelIndex const & parent) const {
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     return 3;
 }
 
