@@ -2,27 +2,33 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTABOUTDIALOG_H
-#define BTABOUTDIALOG_H
+#pragma once
 
 #include <QDialog>
 
+#include <QObject>
+#include <QString>
+#include <Qt>
+
+
 class QDialogButtonBox;
 class QLabel;
+class QResizeEvent;
 class QTabWidget;
-class QUrl;
 class QTextBrowser;
+class QWidget;
 
 class BtAboutDialog: public QDialog {
         Q_OBJECT
+        class LicenseTab;
     public:
         BtAboutDialog(QWidget *parent = nullptr, Qt::WindowFlags wflags = Qt::Dialog);
 
@@ -30,7 +36,6 @@ class BtAboutDialog: public QDialog {
         void resizeEvent(QResizeEvent* event) override;
 
     private:
-        void initTab(QTextBrowser *&tab);
 
         void retranslateUi();
         void retranslateBtTab();
@@ -39,19 +44,14 @@ class BtAboutDialog: public QDialog {
         void retranslateQtTab();
         void retranslateLicenceTab();
 
-    private slots:
-        void linkClicked(const QUrl &url);
-
     private:
         QTabWidget *m_tabWidget;
         QTextBrowser *m_bibletimeTab;
         QTextBrowser *m_contributorsTab;
         QTextBrowser *m_swordTab;
         QTextBrowser *m_qtTab;
-        QTextBrowser *m_licenceTab;
+        LicenseTab * m_licenseTab = nullptr;
         QDialogButtonBox *m_buttonBox;
         QLabel *m_iconLabel;
         QLabel *m_versionLabel;
 };
-
-#endif
