@@ -2,64 +2,59 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFDOCKWIDGET_H
-#define BTBOOKSHELFDOCKWIDGET_H
+#pragma once
 
 #include <QDockWidget>
 
+#include <QObject>
+#include <QString>
+#include <Qt>
 #include "../backend/bookshelfmodel/btbookshelftreemodel.h"
-#include "btbookshelfwidget.h"
 
 
+class BtBookshelfWidget;
+class CSwordModuleInfo;
 class QAction;
-class QActionGroup;
 class QLabel;
 class QMenu;
 class QPushButton;
 class QStackedWidget;
+class QWidget;
 
 class BtBookshelfDockWidget: public QDockWidget {
         Q_OBJECT
     public:
         BtBookshelfDockWidget(QWidget *parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());
 
-        static inline BtBookshelfDockWidget *getInstance() { return m_instance; }
+        static BtBookshelfDockWidget * getInstance() { return m_instance; }
 
-        inline const BtBookshelfTreeModel::Grouping &groupingOrder() const {
-            return m_treeModel->groupingOrder();
-        }
+        BtBookshelfTreeModel::Grouping const & groupingOrder() const
+        { return m_treeModel->groupingOrder(); }
 
         void loadBookshelfState();
         void saveBookshelfState();
 
-    signals:
+    Q_SIGNALS:
         void moduleHovered(CSwordModuleInfo *module);
         void moduleOpenTriggered(CSwordModuleInfo *module);
         void moduleSearchTriggered(CSwordModuleInfo *module);
         void moduleUnlockTriggered(CSwordModuleInfo *module);
         void moduleAboutTriggered(CSwordModuleInfo *module);
         void groupingOrderChanged(BtBookshelfTreeModel::Grouping newGrouping);
+        void installWorksClicked();
 
     protected:
         void initMenus();
         void retranslateUi();
 
-    protected slots:
-        void slotModuleActivated(CSwordModuleInfo *module);
-        void slotModuleChecked(CSwordModuleInfo *module, bool checked);
-        void slotItemActionTriggered(QAction *action);
-        void slotPrepareItemContextMenu();
-        void slotModulesChanged();
-        void slotGroupingOrderChanged(const BtBookshelfTreeModel::Grouping &g);
-
     protected:
         BtBookshelfTreeModel *m_treeModel;
 
@@ -71,7 +66,6 @@ class BtBookshelfDockWidget: public QDockWidget {
 
         // Item context menu:
         QMenu *m_itemContextMenu;
-        QActionGroup *m_itemActionGroup;
         QAction *m_itemOpenAction;
         QAction *m_itemSearchAction;
         QAction *m_itemUnlockAction;
@@ -79,5 +73,3 @@ class BtBookshelfDockWidget: public QDockWidget {
 
         static BtBookshelfDockWidget *m_instance;
 };
-
-#endif // BTBOOKSHELFDOCKWIDGET_H
