@@ -2,21 +2,28 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTBOOKSHELFVIEW_H
-#define BTBOOKSHELFVIEW_H
+#pragma once
 
 #include <QTreeView>
 
+#include <QObject>
+#include <QString>
+
 
 class CSwordModuleInfo;
+class QKeyEvent;
+class QModelIndex;
+class QMouseEvent;
+class QPoint;
+class QWidget;
 
 class BtBookshelfView: public QTreeView {
         Q_OBJECT
@@ -25,7 +32,7 @@ class BtBookshelfView: public QTreeView {
 
         CSwordModuleInfo *getModule(const QModelIndex &index) const;
 
-    signals:
+    Q_SIGNALS:
         void contextMenuActivated(QPoint pos);
         void moduleContextMenuActivated(CSwordModuleInfo *item,
                                         QPoint pos);
@@ -36,9 +43,4 @@ class BtBookshelfView: public QTreeView {
         void keyPressEvent(QKeyEvent *event) override;
         void mousePressEvent(QMouseEvent *event) override;
 
-    protected slots:
-        void slotItemActivated(const QModelIndex &index);
-        void slotItemHovered(const QModelIndex &index);
 };
-
-#endif // BTBOOKSHELFVIEW_H
