@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,32 +12,34 @@
 
 #include "btbookshelfwidget.h"
 
-#include <QActionGroup>
+#include <QAction>
 #include <QApplication>
 #include <QHBoxLayout>
-#include <QHeaderView>
 #include <QEvent>
 #include <QKeyEvent>
 #include <QLabel>
 #include <QLineEdit>
 #include <QMenu>
+#include <QModelIndex>
 #include <QToolButton>
+#include <QVariant>
 #include <QVBoxLayout>
+#include <utility>
 #include "../backend/bookshelfmodel/btbookshelffiltermodel.h"
+#include "../backend/bookshelfmodel/btbookshelftreemodel.h"
 #include "../backend/config/btconfig.h"
 #include "../util/btassert.h"
 #include "../util/btconnect.h"
 #include "../util/cresmgr.h"
-#include "../util/directory.h"
-#include "bibletimeapp.h"
-#include "btbookshelfdockwidget.h"
 #include "btbookshelfgroupingmenu.h"
 #include "btbookshelfview.h"
 
 
+class CSwordModuleInfo;
+class QPoint;
+
 BtBookshelfWidget::BtBookshelfWidget(QWidget *parent, Qt::WindowFlags flags)
     : QWidget(parent, flags)
-    , m_sourceModel(nullptr)
     , m_treeModel(nullptr)
     , m_leftCornerWidget(nullptr)
     , m_rightCornerWidget(nullptr)
@@ -55,20 +57,31 @@ BtBookshelfWidget::BtBookshelfWidget(QWidget *parent, Qt::WindowFlags flags)
 
     retranslateUi();
 
-    BT_CONNECT(m_nameFilterEdit,  SIGNAL(textEdited(QString)),
-               m_postFilterModel, SLOT(setNameFilterFixedString(QString)));
-    BT_CONNECT(m_treeView, SIGNAL(contextMenuActivated(QPoint)),
-               this,       SLOT(slotShowContextMenu(QPoint)));
-    BT_CONNECT(m_treeView,
-               SIGNAL(moduleContextMenuActivated(CSwordModuleInfo *, QPoint)),
-               this, SLOT(slotShowItemContextMenu(CSwordModuleInfo *, QPoint)));
+    BT_CONNECT(m_nameFilterEdit,  &QLineEdit::textEdited,
+               m_postFilterModel,
+               &BtBookshelfFilterModel::setNameFilterFixedString);
+    BT_CONNECT(m_treeView, &BtBookshelfView::contextMenuActivated,
+               [this](QPoint const & pos){ m_contextMenu->popup(pos); });
+    BT_CONNECT(m_treeView, &BtBookshelfView::moduleContextMenuActivated,
+               [this](CSwordModuleInfo * const module, QPoint const & pos) {
+                   if (!m_itemContextMenu)
+                       m_itemContextMenu = m_contextMenu;
+                   m_itemContextMenu->setProperty(
+                               "BtModule",
+                               QVariant::fromValue(
+                                   static_cast<void *>(module)));
+                   m_itemContextMenu->popup(pos);
+               });
 }
 
-void BtBookshelfWidget::setSourceModel(QAbstractItemModel *model) {
+void
+BtBookshelfWidget::setSourceModel(std::shared_ptr<QAbstractItemModel> model) {
     BT_ASSERT(model);
-    m_sourceModel = model;
-    if (m_treeModel != nullptr) {
-        m_treeModel->setSourceModel(model);
+    if (m_treeModel) {
+        m_sourceModel = model;
+        m_treeModel->setSourceModel(std::move(model));
+    } else {
+        m_sourceModel = std::move(model);
     }
 }
 
@@ -76,6 +89,9 @@ void BtBookshelfWidget::setTreeModel(BtBookshelfTreeModel *model) {
     BT_ASSERT(model);
     BT_ASSERT(!m_treeModel);
     m_treeModel = model;
+    m_groupingMenu->setGrouping(m_treeModel->groupingOrder());
+    BT_CONNECT(m_treeModel, &BtBookshelfTreeModel::groupingOrderChanged,
+               m_groupingMenu, &BtBookshelfGroupingMenu::setGrouping);
     if (m_sourceModel != nullptr) {
         model->setSourceModel(m_sourceModel);
     }
@@ -98,19 +114,19 @@ void BtBookshelfWidget::initActions() {
     m_showHideAction = new QAction(this);
     m_showHideAction->setIcon(CResMgr::mainIndex::showHide::icon());
     m_showHideAction->setCheckable(true);
-    BT_CONNECT(m_showHideAction,  SIGNAL(toggled(bool)),
-               m_postFilterModel, SLOT(setShowHidden(bool)));
+    BT_CONNECT(m_showHideAction,  &QAction::toggled,
+               m_postFilterModel, &BtBookshelfFilterModel::setShowHidden);
 }
 
 void BtBookshelfWidget::initMenus() {
     // Grouping menu:
     m_groupingMenu = new BtBookshelfGroupingMenu(this);
     BT_CONNECT(m_groupingMenu,
-               SIGNAL(signalGroupingOrderChanged(
-                          BtBookshelfTreeModel::Grouping)),
-               this,
-               SLOT(slotGroupingActionTriggered(
-                        BtBookshelfTreeModel::Grouping)));
+               &BtBookshelfGroupingMenu::signalGroupingOrderChanged,
+               [this](BtBookshelfTreeModel::Grouping const & grouping) {
+                   m_treeModel->setGroupingOrder(grouping);
+                   m_treeView->setRootIsDecorated(!grouping.list().isEmpty());
+               });
 
     // Context menu
     m_contextMenu = new QMenu(this);
@@ -179,28 +195,6 @@ bool BtBookshelfWidget::eventFilter(QObject *object, QEvent *event) {
     return false;
 }
 
-void BtBookshelfWidget::slotGroupingActionTriggered(const BtBookshelfTreeModel::Grouping &grouping) {
-    m_treeModel->setGroupingOrder(grouping);
-    m_treeView->setRootIsDecorated(!grouping.isEmpty());
-}
-
-void BtBookshelfWidget::slotShowContextMenu(const QPoint &pos) {
-    m_contextMenu->popup(pos);
-}
-
-void BtBookshelfWidget::slotShowItemContextMenu(CSwordModuleInfo *module, const QPoint &pos)
-{
-    if (m_itemContextMenu != nullptr) {
-        m_itemContextMenu->setProperty("BtModule",
-                                       QVariant::fromValue(
-                                           static_cast<void *>(module)));
-        m_itemContextMenu->popup(pos);
-    } else {
-        m_itemContextMenu = m_contextMenu;
-        slotShowItemContextMenu(module, pos);
-    }
-}
-
 void BtBookshelfWidget::findExpanded(
         const QModelIndex& index,
         QString prefix,
@@ -208,7 +202,7 @@ void BtBookshelfWidget::findExpanded(
     QString path = index.data(Qt::DisplayRole).toString();
     if (m_treeView->isExpanded(index)) {
         if (! prefix.isEmpty())
-            path = prefix + QString("/") + path;
+            path = QStringLiteral("%1/%2").arg(prefix, path);
         expandedPaths->append(path);
     }
     int rows = m_postFilterModel->rowCount(index);
@@ -237,10 +231,12 @@ void BtBookshelfWidget::restoreExpanded(const QModelIndex& index, const QStringL
 }
 
 void BtBookshelfWidget::loadBookshelfState() {
-    QStringList paths = btConfig().value<QStringList>("GUI/MainWindow/Docks/Bookshelf/expandPaths");
+    auto const paths =
+            btConfig().value<QStringList>(
+                QStringLiteral("GUI/MainWindow/Docks/Bookshelf/expandPaths"));
     auto rootIndex = m_treeView->rootIndex();
-    for (QString path: paths) {
-        QStringList nodeList = path.split("/");
+    for (auto const & path : paths) {
+        QStringList nodeList = path.split('/');
         restoreExpanded(rootIndex, nodeList);
     }
 }
@@ -250,6 +246,8 @@ void BtBookshelfWidget::saveBookshelfState() {
     QString prefix;
     auto rootIndex = m_treeView->rootIndex();
     findExpanded(rootIndex, prefix, &paths);
-    btConfig().setValue("GUI/MainWindow/Docks/Bookshelf/expandPaths", paths);
+    btConfig().setValue(
+                QStringLiteral("GUI/MainWindow/Docks/Bookshelf/expandPaths"),
+                paths);
 }
 
