@@ -2,24 +2,28 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTMENUVIEW_H
-#define BTMENUVIEW_H
+#pragma once
 
 #include <QMenu>
 
-#include <QPersistentModelIndex>
+#include <QObject>
+#include <QString>
 
 
 class QAbstractItemModel;
+class QAction;
 class QActionGroup;
+class QEvent;
+class QModelIndex;
+class QWidget;
 
 /**
   This is a special menu, which shows the contents of an item model. The menu is repopulated
@@ -45,7 +49,7 @@ class BtMenuView: public QMenu {
     public:
         BtMenuView(QWidget * parent = nullptr);
         BtMenuView(QString const & title, QWidget * parent = nullptr);
-        virtual ~BtMenuView();
+        ~BtMenuView() override;
 
         /**
           Sets or resets the data model for this menu and resets the parent index to an
@@ -59,11 +63,11 @@ class BtMenuView: public QMenu {
           Returns a pointer to the data model associated with this menu.
           \retval 0 If this menu is not associated to any model.
         */
-        inline QAbstractItemModel *model() const { return m_model; }
+        QAbstractItemModel * model() const { return m_model; }
 
         bool event(QEvent * e) override;
 
-    signals:
+    Q_SIGNALS:
         /**
           This signal is emitted when the user activates a menu item corresponding to an
           index in the associated model.
@@ -115,16 +119,14 @@ class BtMenuView: public QMenu {
         /** \brief Rebuilds the menu. */
         void rebuildMenu();
 
-    private: /* Methods: */
+    private: // methods:
 
         void buildMenu(QMenu *parentMenu, const QModelIndex &parentIndex);
         void removeMenus();
 
-    private: /* Fields: */
+    private: // fields:
 
         QAbstractItemModel *m_model;
         QActionGroup *m_actions;
 
 };
-
-#endif // BTMENUVIEW_H
