@@ -2,25 +2,27 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTMODULECHOOSERDIALOG_H
-#define BTMODULECHOOSERDIALOG_H
+#pragma once
 
 #include <QDialog>
 
-#include "btbookshelfwidget.h"
+#include <QObject>
+#include <QString>
+#include <Qt>
 
 
-class CSwordModuleInfo;
+class BtBookshelfWidget;
 class QDialogButtonBox;
 class QLabel;
+class QWidget;
 
 class BtModuleChooserDialog : public QDialog {
     Q_OBJECT
@@ -30,17 +32,15 @@ class BtModuleChooserDialog : public QDialog {
 
         void retranslateUi();
 
-        inline QLabel *label() const { return m_captionLabel; }
-        inline BtBookshelfWidget *bookshelfWidget() const { return m_bookshelfWidget; }
-        inline QDialogButtonBox *buttonBox() const { return m_buttonBox; }
+        QLabel * label() const { return m_captionLabel; }
 
-    protected slots:
-        void slotModuleAbout(CSwordModuleInfo *module);
+        BtBookshelfWidget * bookshelfWidget() const
+        { return m_bookshelfWidget; }
+
+        QDialogButtonBox * buttonBox() const { return m_buttonBox; }
 
     private:
         QLabel            *m_captionLabel;
         BtBookshelfWidget *m_bookshelfWidget;
         QDialogButtonBox  *m_buttonBox;
 };
-
-#endif // BTMODULECHOOSERDIALOG_H
