@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -15,6 +15,8 @@
 #include <QColorDialog>
 #include <QMouseEvent>
 #include <QPalette>
+#include <QSizePolicy>
+#include <Qt>
 
 
 BtColorWidget::BtColorWidget(QWidget * parent)
@@ -44,7 +46,7 @@ void BtColorWidget::mouseReleaseEvent(QMouseEvent * event) {
             this));
         if (color.isValid()) {
             setColor(color);
-            emit changed(color);
+            Q_EMIT changed(color);
         }
     }
 }
