@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -14,7 +14,9 @@
 
 #include <QCompleter>
 #include <QFontDatabase>
-#include <QValidator>
+#include <QIntValidator>
+#include <QNonConstOverload>
+#include <QVariant>
 #include "../../util/btconnect.h"
 
 
@@ -26,18 +28,19 @@ BtFontSizeWidget::BtFontSizeWidget(QWidget * parent)
     setValidator(m_validator);
     completer()->setCompletionMode(QCompleter::PopupCompletion);
 
-    Q_FOREACH (int const size, QFontDatabase().standardSizes()) {
+    #if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
+    for (int const size : QFontDatabase().standardSizes()) {
+    #else
+    for (int const size : QFontDatabase::standardSizes()) {
+    #endif
         if (size > m_validator->top())
             m_validator->setTop(size);
         addItem(QString::number(size), QVariant(size));
     }
 
-    BT_CONNECT(this, SIGNAL(currentTextChanged(QString const &)),
-               this, SLOT(changed(QString const &)));
-}
-
-void BtFontSizeWidget::changed(QString const & text) {
-    emit fontSizeChanged(text.toInt());
+    BT_CONNECT(this, qOverload<QString const &>(&QComboBox::currentTextChanged),
+               [this](QString const & text)
+               { Q_EMIT fontSizeChanged(text.toInt()); });
 }
 
 void BtFontSizeWidget::setFontSize(int size) {
