@@ -2,48 +2,45 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTFONTSIZEWIDGET_H
-#define BTFONTSIZEWIDGET_H
+#pragma once
 
 #include <QComboBox>
 
+#include <QObject>
+#include <QString>
+
 
 class QIntValidator;
+class QWidget;
 
 class BtFontSizeWidget: public QComboBox {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
     BtFontSizeWidget(QWidget * parent = nullptr);
 
     int fontSize() const;
 
-public slots:
+public Q_SLOTS:
 
     void setFontSize(int size);
 
-private slots:
-
-    virtual void changed(QString const & text);
-
-signals:
+Q_SIGNALS:
 
     void fontSizeChanged(int);
 
-private: /* Fields: */
+private: // fields:
 
     QIntValidator * const m_validator;
 
 }; /* class BtFontSizeWidget { */
-
-#endif
