@@ -2,49 +2,45 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
+#pragma once
+
 /**
     The BtQuickWidget is a subclass of QQuickWidget. The subclass was
     needed to be able to catch the drop event when a bookmark is dropped
     on a read window.
   */
 
-#ifndef BTQUICKWIDGET_H
-#define BTQUICKWIDGET_H
-
 #include <QTimer>
 #include <QWidget>
 #include <QQuickWidget>
-#include "btqmlscrollview.h"
 
+
+class CSwordKey;
 class BtQmlInterface;
 
 class BtQuickWidget : public QQuickWidget {
     Q_OBJECT
 
 public:
-    BtQuickWidget(BtQmlScrollView* widget);
+    BtQuickWidget(QWidget * const parent = nullptr);
 
-    void mousePressed(int x, int y);
-    void mouseMove(int x, int y);
-    void mouseReleased(int x, int y);
-
-    void saveContextMenuIndex(int x, int y);
     void scroll(int pixels);
     void updateReferenceText();
+    void pageDown();
+    void pageUp();
 
-    int getSelectedColumn() const;
-    int getFirstSelectedIndex() const;
-    int getLastSelectedIndex() const;
     CSwordKey* getMouseClickedKey();
 
+    BtQmlInterface * qmlInterface() const noexcept { return m_qmlInterface; }
+
 protected:
        void dragMoveEvent(QDragMoveEvent * event) override;
        void dragEnterEvent( QDragEnterEvent* e ) override;
@@ -57,23 +53,21 @@ protected:
        virtual void mouseDoubleClickEvent(QMouseEvent *event) override;
        virtual void wheelEvent(QWheelEvent * event) override;
 
-private slots:
-    void scrollTimerSlot();
+private: // methods:
+
+   template <typename ... Args>
+   void callQml(char const * const method, Args && ... args) {
+       QMetaObject::invokeMethod(rootObject(),
+                                 method,
+                                 Q_ARG(QVariant, args)...);
+   }
 
 private:
-    BtQmlInterface* getQmlInterface() const;
-    void setupScrollTimer();
-    void startScrollTimer();
-    void stopScrollTimer();
 
+    BtQmlInterface * const m_qmlInterface;
 
-    BtQmlScrollView* m_scrollView;
+    QTimer m_scrollTimer;
 
-    QTimer m_timer;
-
-signals:
+Q_SIGNALS:
     void referenceDropped(const QString& reference);
 };
-
-
-#endif
