@@ -2,16 +2,15 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BT_ACTION_COLLECTION_H
-#define BT_ACTION_COLLECTION_H
+#pragma once
 
 #include <QObject>
 
@@ -19,7 +18,6 @@
 #include <QKeySequence>
 #include <QMap>
 #include <QString>
-#include "../../backend/config/btconfig.h"
 #include "../../util/btassert.h"
 
 
@@ -27,55 +25,26 @@ class BtActionCollection: public QObject {
 
     Q_OBJECT
 
-private: /* Types: */
+public: // methods:
 
-    class Item: public QObject {
-
-    public: /* Methods: */
-
-        Item(QAction * const action, QObject * const parent)
-            : QObject{parent}
-            , m_defaultKeys{action->shortcut()}
-            , m_action{action}
-        {}
-
-    public: /* Fields: */
-
-        QKeySequence const m_defaultKeys;
-        QAction * const m_action;
-
-    };
-    using ActionMap = QMap<QString, Item *>;
-
-public: /* Methods: */
-
-    inline BtActionCollection(QObject * const parent = nullptr)
+    BtActionCollection(QObject * const parent = nullptr)
             : QObject{parent}
     {}
 
+    QMap<QString, QAction *> const & actions() const noexcept
+    { return m_actions; }
+
     void addAction(QString const & name, QAction * const action);
 
-    void addAction(QString const & name,
-                   QObject const * const receiver,
-                   const char * const member = nullptr);
-
-    void removeAction(QString const & name);
-
     QAction & action(QString const & name) const;
 
     template <typename T>
-    inline T & actionAs(QString const & name) const {
+    T & actionAs(QString const & name) const {
         QAction & a = action(name);
         BT_ASSERT(dynamic_cast<T *>(&a));
         return static_cast<T &>(a);
     }
 
-    template <typename F>
-    inline void foreachQAction(F && f) const {
-        for (Item const * const item : m_actions)
-            f(*(item->m_action), item->m_defaultKeys);
-    }
-
     /*!
      * \brief Read shortcuts from config.
      *
@@ -97,16 +66,10 @@ public: /* Methods: */
      */
     void writeShortcuts(QString const & group) const;
 
-    QKeySequence getDefaultShortcut(QAction * const action) const;
+    static QKeySequence getDefaultShortcut(QAction & action);
 
-private: /* Methods: */
+private: // fields:
 
-    Item * findActionItem(QString const & name) const;
-
-private: /* Fields: */
-
-    ActionMap m_actions;
+    QMap<QString, QAction *> m_actions;
 
 };
-
-#endif
