@@ -2,25 +2,28 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTDISPLAYSETTINGSBUTTON_H
-#define BTDISPLAYSETTINGSBUTTON_H
+#pragma once
 
 #include <QToolButton>
 
+#include <QObject>
+#include <QString>
 #include "../../backend/btglobal.h"
-#include "../../backend/managers/cswordbackend.h"
+#include "../../backend/drivers/btmodulelist.h"
+#include "../../backend/drivers/cswordmoduleinfo.h"
 
 
-class CSwordModuleInfo;
+class QAction;
 class QMenu;
+class QWidget;
 
 /** This class manages the display options of the selected modules.
   * @author The BibleTime team
@@ -31,30 +34,29 @@ class BtDisplaySettingsButton: public QToolButton {
     public:
         BtDisplaySettingsButton(QWidget *parent = nullptr);
 
-    public slots:
-        void setDisplayOptions(const DisplayOptions &displaySettings,
-                               bool repopulate = true);
-        void setFilterOptions(const FilterOptions &moduleSettings,
-                              bool repopulate = true);
+        void setDisplayOptionsNoRepopulate(
+                DisplayOptions const & displaySettings);
+        void setFilterOptionsNoRepopulate(FilterOptions const & moduleSettings);
+
+    public Q_SLOTS:
+        void setDisplayOptions(DisplayOptions const & displaySettings);
+        void setFilterOptions(FilterOptions const & moduleSettings);
 
         void setModules(const BtConstModuleList &modules);
 
-    signals:
+    Q_SIGNALS:
         void sigFilterOptionsChanged(FilterOptions filterOptions);
         void sigDisplayOptionsChanged(DisplayOptions displayOptions);
         void sigModulesChanged(const BtConstModuleList &modules);
         void sigChanged();
 
-    protected slots:
-        void slotOptionToggled(QAction *action);
-
     protected:
         void initMenu();
         void retranslateUi();
         void retranslateToolTip();
         void repopulateMenu();
 
-        bool isOptionAvailable(const CSwordModuleInfo::FilterTypes option);
+        bool isOptionAvailable(CSwordModuleInfo::FilterOption const & option);
         void addMenuEntry(QAction *action, bool checked);
 
     private:
@@ -74,5 +76,3 @@ class BtDisplaySettingsButton: public QToolButton {
         QAction *m_footnotesAction;
         QAction *m_morphSegmentationAction;
 };
-
-#endif
