@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,27 +12,39 @@
 
 #include "btmodulechoosermenu.h"
 
+#include <QAbstractItemModel>
+#include <QAction>
+#include <QActionGroup>
+#include <QModelIndex>
 #include <QSortFilterProxyModel>
+#include <QVariant>
+#include <utility>
+#include "../../backend/bookshelfmodel/btbookshelfmodel.h"
 #include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
 #include "../../backend/config/btconfig.h"
+#include "../../backend/drivers/cswordmoduleinfo.h"
 #include "../../backend/managers/cswordbackend.h"
+#include "../../util/btassert.h"
 #include "../../util/btconnect.h"
+#include "../btmenuview.h"
 
 
 namespace {
 
 struct SortModel final: public QSortFilterProxyModel {
 
-/* Methods: */
+// Methods:
 
     SortModel(CSwordModuleInfo::ModuleType moduleType,
               QObject * parent = nullptr)
         : QSortFilterProxyModel(parent)
         , m_moduleType(moduleType)
-        , m_showHidden(btConfig().value<bool>("GUI/bookshelfShowHidden", false))
+        , m_showHidden(btConfig().value<bool>(
+                           QStringLiteral("GUI/bookshelfShowHidden"),
+                           false))
         , m_sourceModel(new BtBookshelfTreeModel(this))
     {
-        m_sourceModel->setSourceModel(CSwordBackend::instance()->model());
+        m_sourceModel->setSourceModel(CSwordBackend::instance().model());
         setSourceModel(m_sourceModel);
     }
 
@@ -76,7 +88,7 @@ struct SortModel final: public QSortFilterProxyModel {
                    && (module->type() == CSwordModuleInfo::Commentary));
     }
 
-/* Fields: */
+// Fields:
 
     CSwordModuleInfo::ModuleType const m_moduleType;
     bool const m_showHidden;
@@ -103,11 +115,11 @@ BtModuleChooserMenu::BtModuleChooserMenu(
                     if (itemIndex.isValid()) {
                         auto const & sortedModel =
                                 *static_cast<SortModel *>(m_sortedModel);
-                        emit sigModuleChosen(
+                        Q_EMIT sigModuleChosen(
                                     sortedModel.m_sourceModel->module(
                                         sortedModel.mapToSource(itemIndex)));
                     } else {
-                        emit sigModuleChosen(nullptr);
+                        Q_EMIT sigModuleChosen(nullptr);
                     }
                });
 }
@@ -117,17 +129,17 @@ void BtModuleChooserMenu::preBuildMenu(QActionGroup * actionGroup) {
     actionGroup->setExclusive(true);
 
     if (m_flags & AddNoneButton) {
-        m_noneAction = new QAction(this);
-        m_noneAction->setCheckable(true);
-        m_noneAction->setText(tr("NONE"));
-        m_noneAction->setChecked(m_selectedModule.isEmpty());
-        m_noneAction->setDisabled(
+        QAction * noneAction = new QAction(this);
+        noneAction->setCheckable(true);
+        noneAction->setText(tr("NONE"));
+        noneAction->setChecked(!m_selectedModule);
+        noneAction->setDisabled(
                     m_newModulesToUse.size() <= 1
                     || (m_buttonIndex <= 0 && m_leftLikeModules <= 1));
-        m_noneAction->setActionGroup(actionGroup);
-        BT_CONNECT(m_noneAction, &QAction::triggered,
-                   [this]{ emit triggered(QModelIndex()); });
-        addAction(m_noneAction);
+        noneAction->setActionGroup(actionGroup);
+        BT_CONNECT(noneAction, &QAction::triggered,
+                   [this]{ Q_EMIT triggered(QModelIndex()); });
+        addAction(noneAction);
 
         addSeparator();
     }
@@ -141,20 +153,19 @@ QAction * BtModuleChooserMenu::newAction(QMenu * parentMenu,
     auto const & sortedModel = *static_cast<SortModel *>(m_sortedModel);
 
     auto const sourceItemIndex = sortedModel.mapToSource(itemIndex);
-    auto const * const module =
+    auto * const module =
             sortedModel.m_sourceModel->module(sourceItemIndex);
     BT_ASSERT(module);
     action->setCheckable(true);
-    auto const & moduleName = module->name();
-    action->setChecked(moduleName == m_selectedModule);
+    action->setChecked(module == m_selectedModule);
 
     if (m_flags & DisableSelectedModule) {
-        action->setDisabled(moduleName == m_selectedModule
-                            || m_newModulesToUse.contains(moduleName)
+        action->setDisabled(module == m_selectedModule
+                            || m_newModulesToUse.contains(module)
                             || module->isLocked());
     } else {
-        action->setDisabled((moduleName != m_selectedModule
-                             && m_newModulesToUse.contains(moduleName))
+        action->setDisabled((module != m_selectedModule
+                             && m_newModulesToUse.contains(module))
                             || module->isLocked());
     }
 
@@ -168,8 +179,8 @@ QAction * BtModuleChooserMenu::newAction(QMenu * parentMenu,
     return action;
 }
 
-void BtModuleChooserMenu::update(QStringList newModulesToUse,
-                                 QString newSelectedModule,
+void BtModuleChooserMenu::update(BtModuleList newModulesToUse,
+                                 CSwordModuleInfo * newSelectedModule,
                                  int newButtonIndexIndex,
                                  int newLeftLikeModules)
 {
@@ -180,7 +191,9 @@ void BtModuleChooserMenu::update(QStringList newModulesToUse,
     rebuildMenu();
 }
 
-void BtModuleChooserMenu::setSelectedModule(QString newSelectedModule) noexcept{
-    m_selectedModule = std::move(newSelectedModule);
+void BtModuleChooserMenu::setSelectedModule(
+        CSwordModuleInfo * const newSelectedModule) noexcept
+{
+    m_selectedModule = newSelectedModule;
     rebuildMenu();
 }
