@@ -2,22 +2,20 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CBIBLEREADWINDOW_H
-#define CBIBLEREADWINDOW_H
+#pragma once
 
-#include "clexiconreadwindow.h"
+#include "cdisplaywindow.h"
 
 #include <QAction>
 #include "../cexportmanager.h"
-#include "../../util/btconnect.h"
 #include "btactioncollection.h"
 
 
@@ -28,42 +26,36 @@ class QEvent;
 class QMenu;
 class QObject;
 
-class CBibleReadWindow: public CLexiconReadWindow  {
+class CBibleReadWindow: public CDisplayWindow  {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // Types:
 
-    inline CBibleReadWindow(const QList<CSwordModuleInfo*> & modules, CMDIArea* parent)
-        : CLexiconReadWindow(modules, parent) {}
+    class ActionCollection : public CDisplayWindow::ActionCollection {
+
+    public: // Methods:
+
+        ActionCollection(QObject * parent = nullptr);
+
+    };
+
+public: // methods:
+
+    CBibleReadWindow(QList<CSwordModuleInfo *> const & modules,
+                     QString const & key,
+                     CMDIArea * parent);
 
     CSwordModuleInfo::ModuleType moduleType() const override
     { return CSwordModuleInfo::Bible; }
 
-    void storeProfileSettings(QString const & windowGroup) const override;
-    void applyProfileSettings(const QString & windowGroup) override;
-    static void insertKeyboardActions( BtActionCollection* const a );
+    void storeProfileSettings(BtConfigCore & windowConf) const override;
+    void applyProfileSettings(BtConfigCore const & windowConf) override;
 
-protected: /* Methods: */
-
-    template <typename ... Args>
-    QAction & initAction(QString actionName, Args && ... args) {
-        QAction & action = m_actionCollection->action(std::move(actionName));
-        BT_CONNECT(&action,
-                   &QAction::triggered,
-                   std::forward<Args>(args)...);
-        addAction(&action);
-        return action;
-    }
+protected: // methods:
 
     void initActions() override;
-    void initToolbars() override;
-    void initConnections() override;
-    void initView() override;
-    void setupMainWindowToolBars() override;
-    void setupPopupMenu() override;
-    void updatePopupMenu() override;
-    bool eventFilter( QObject* o, QEvent* e) override;
+    QMenu * newDisplayWidgetPopupMenu() override;
 
     struct {
         QAction* findText;
@@ -98,7 +90,7 @@ protected: /* Methods: */
     m_actions;
 
 
-public slots:
+public Q_SLOTS:
 
     void nextBook();
     void previousBook();
@@ -107,9 +99,9 @@ public slots:
     void nextVerse();
     void previousVerse();
 
-    void reload(CSwordBackend::SetupChangedReason reason) override;
+    void reload() override;
 
-protected slots:
+protected Q_SLOTS:
 
     /**
         * Copies the current chapter into the clipboard.
@@ -126,7 +118,7 @@ protected slots:
     void lookupSwordKey(CSwordKey * newKey) override;
     void syncWindows();
 
-private: /* Methods: */
+private: // methods:
 
     /**
         * Wrapper around key() to return the right type of key.
@@ -136,5 +128,3 @@ private: /* Methods: */
     void saveChapter(CExportManager::Format const format);
 
 };
-
-#endif /* CBIBLEREADWINDOW_H */
