@@ -2,29 +2,34 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BT_EDIT_TEXT_WIZARD_H
-#define BT_EDIT_TEXT_WIZARD_H
+#pragma once
 
 #include <QWizard>
-#include "../../util/btassert.h"
+
+#include <QObject>
+#include <QString>
+#include <Qt>
+
 
 class BtPlainOrHtmlPage;
 class BtEditTextPage;
+class QFont;
+class QWidget;
 
 /** \brief The Edit Text wizard for editing the personal commentary. */
 class BtEditTextWizard final: public QWizard {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
     BtEditTextWizard(QWidget * parent = nullptr, Qt::WindowFlags flags = Qt::WindowFlags());
 
@@ -34,7 +39,7 @@ public: /* Methods: */
     void setTitle(const QString& text);
     QString text() const;
 
-public slots:
+public Q_SLOTS:
 
     void accept() final override;
 
@@ -46,5 +51,3 @@ private:
     BtEditTextPage * const m_editTextPage;
 
 }; /* class BtEditTextWizard */
-
-#endif
