@@ -2,22 +2,26 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BT_PLAIN_OR_HTML_PAGE
-#define BT_PLAIN_OR_HTML_PAGE
+#pragma once
 
 #include <QWizardPage>
 
+#include <QObject>
+#include <QString>
+
+
 class QGroupBox;
 class QRadioButton;
 class QVBoxLayout;
+class QWidget;
 
 class BtPlainOrHtmlPage final: public QWizardPage {
 
@@ -25,7 +29,7 @@ class BtPlainOrHtmlPage final: public QWizardPage {
 
 public:
 
-    BtPlainOrHtmlPage(QWidget * parent = 0);
+    BtPlainOrHtmlPage(QWidget * parent = nullptr);
     bool htmlMode() const;
     void setHtmlMode(bool html);
 
@@ -38,5 +42,3 @@ private:
     QGroupBox * m_groupBox;
     QVBoxLayout * m_verticalLayout;
 };
-
-#endif
