@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,38 +12,40 @@
 
 #include "cbookkeychooser.h"
 
-#include <QDebug>
+#include <algorithm>
+#include <memory>
+#include <QComboBox>
 #include <QHBoxLayout>
-#include <QList>
+#include <QStringList>
+#include <Qt>
+#include <QtAlgorithms>
+#include <QtGlobal>
+#include <QVariant>
 #include <QWidget>
 #include "../../backend/config/btconfig.h"
+#include "../../backend/drivers/btmodulelist.h"
 #include "../../backend/drivers/cswordbookmoduleinfo.h"
+#include "../../backend/drivers/cswordmoduleinfo.h"
+#include "../../backend/keys/cswordkey.h"
 #include "../../backend/keys/cswordtreekey.h"
 #include "../../util/btassert.h"
 #include "../../util/btconnect.h"
-#include "bthistory.h"
+#include "ckeychooserwidget.h"
 
 
 #define ID_PROPERTY_NAME "CBookKeyChooser_ID"
 
 CBookKeyChooser::CBookKeyChooser(const BtConstModuleList & modules,
-                                 BTHistory * historyPtr,
                                  CSwordKey * key,
                                  QWidget * parent)
-    : CKeyChooser(modules, historyPtr, parent)
+    : CKeyChooser(parent)
     , m_layout(nullptr)
 {
-    setModules(modules, false);
     m_key = dynamic_cast<CSwordTreeKey * >(key);
-    if (!m_modules.count())
-        m_key = nullptr;
-
     setModules(modules, true);
     setKey(key);
 
     adjustFont();
-    BT_CONNECT(this,      SIGNAL(keyChanged(CSwordKey *)),
-               history(), SLOT(add(CSwordKey *)));
 }
 
 void CBookKeyChooser::setKey(CSwordKey * newKey) {
@@ -58,25 +60,21 @@ void CBookKeyChooser::setKey(CSwordKey * newKey, const bool emitSignal) {
     QString oldKey(m_key->key());
 
     if (oldKey.isEmpty()) { // Don't set keys equal to "/", always use a key which may have content
-        m_key->firstChild();
+        m_key->positionToFirstChild();
         oldKey = m_key->key();
     }
 
-    const int oldOffset = m_key->getOffset();
+    auto const oldOffset = m_key->offset();
 
     QStringList siblings; // Split up key
     if (m_key && !oldKey.isEmpty())
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-        siblings = oldKey.split('/', QString::SkipEmptyParts);
-#else
         siblings = oldKey.split('/', Qt::SkipEmptyParts);
-#endif
 
     int depth = 0;
 
-    m_key->root(); //start iteration at root node
+    m_key->positionToRoot(); //start iteration at root node
 
-    while (m_key->firstChild() && (depth < siblings.count())) {
+    while (m_key->positionToFirstChild() && (depth < siblings.count())) {
         QString key = m_key->key();
         int index = (depth == 0) ? -1 : 0;
 
@@ -85,7 +83,7 @@ void CBookKeyChooser::setKey(CSwordKey * newKey, const bool emitSignal) {
         do { //look for matching sibling
             ++index;
             found = (m_key->getLocalNameUnicode() == siblings[depth]);
-        } while (!found && m_key->nextSibling());
+        } while (!found && m_key->positionToNextSibling());
 
         if (found) {
             key = m_key->key(); //found: change key to this level
@@ -97,7 +95,7 @@ void CBookKeyChooser::setKey(CSwordKey * newKey, const bool emitSignal) {
 
         //last iteration: check to see if another box can be filled with child entries
         if (depth == siblings.count() - 1 && m_key->hasChildren()) {
-            m_key->firstChild();
+            m_key->positionToFirstChild();
             setupCombo(m_key->key(), ++depth, 0);
         }
 
@@ -112,14 +110,14 @@ void CBookKeyChooser::setKey(CSwordKey * newKey, const bool emitSignal) {
     }
 
     if (oldKey.isEmpty()) {
-        m_key->root();
+        m_key->positionToRoot();
     } else {
         //m_key->key(oldKey);
         m_key->setOffset(oldOffset);
     }
 
     if (emitSignal)
-        emit keyChanged(m_key);
+        Q_EMIT keyChanged(m_key);
 }
 
 /** Returns the key of this kechooser. */
@@ -131,17 +129,12 @@ CSwordKey * CBookKeyChooser::key() {
 void CBookKeyChooser::setModules(const BtConstModuleList & modules,
                                  bool refresh)
 {
-    using CSBMI = CSwordBookModuleInfo;
     m_modules.clear();
 
     //   for (modules.first(); modules.current(); modules.next()) {
-    Q_FOREACH(const CSwordModuleInfo * const m, modules) {
-        if (m->type() == CSwordModuleInfo::GenericBook ) {
-            const CSBMI * const book = dynamic_cast<const CSBMI *>(m);
-            if (book != nullptr)
-                m_modules.append(book);
-        }
-    }
+    for (auto const * const m : modules)
+        if (m->type() == CSwordModuleInfo::GenericBook)
+            m_modules.append(static_cast<CSwordBookModuleInfo const *>(m));
 
     //refresh the number of combos
     if (refresh && m_modules.count() && m_key) {
@@ -176,8 +169,10 @@ void CBookKeyChooser::setModules(const BtConstModuleList & modules,
             w->comboBox().setMaximumWidth(maxWidth);
             w->comboBox().setCurrentIndex(0);
 
-            BT_CONNECT(w, SIGNAL(changed(int)),  SLOT(keyChooserChanged(int)));
-            BT_CONNECT(w, SIGNAL(focusOut(int)), SLOT(keyChooserChanged(int)));
+            BT_CONNECT(w, &CKeyChooserWidget::changed,
+                       this, &CBookKeyChooser::keyChooserChanged);
+            BT_CONNECT(w, &CKeyChooserWidget::focusOut,
+                       this, &CBookKeyChooser::keyChooserChanged);
 
             m_layout->addWidget(w);
             w->setProperty(ID_PROPERTY_NAME, i+1);
@@ -207,9 +202,10 @@ void CBookKeyChooser::setModules(const BtConstModuleList & modules,
 /** No descriptions */
 void CBookKeyChooser::adjustFont() {
     //Make sure the entries are displayed correctly.
-    QListIterator<CKeyChooserWidget *> it(m_chooserWidgets);
-    while (it.hasNext())
-        it.next()->comboBox().setFont(btConfig().getFontForLanguage(*m_modules.first()->language()).second);
+    auto const & font =
+        btConfig().getFontForLanguage(*m_modules.first()->language()).second;
+    for (CKeyChooserWidget * const w : m_chooserWidgets)
+        w->comboBox().setFont(font);
 }
 
 /** Refreshes the content. */
@@ -226,8 +222,8 @@ void CBookKeyChooser::setupCombo(const QString & key,
 
     CSwordTreeKey tmpKey(*m_key);
     tmpKey.setKey(key);
-    tmpKey.sword::TreeKeyIdx::parent();
-    tmpKey.firstChild();
+    tmpKey.positionToParent();
+    tmpKey.positionToFirstChild();
 
     QStringList items;
     if (depth > 0)
@@ -235,7 +231,7 @@ void CBookKeyChooser::setupCombo(const QString & key,
 
     do {
         items.append(tmpKey.getLocalNameUnicode());
-    } while (tmpKey.nextSibling());
+    } while (tmpKey.positionToNextSibling());
 
     if (chooserWidget)
         chooserWidget->reset(items, currentItem, false);
@@ -243,10 +239,10 @@ void CBookKeyChooser::setupCombo(const QString & key,
 
 /** A keychooser changed. Update and emit a signal if necessary. */
 void CBookKeyChooser::keyChooserChanged(int newIndex) {
-    Q_UNUSED(newIndex);
+    Q_UNUSED(newIndex)
     QStringList items;
 
-    const int max = std::min(m_chooserWidgets.count(),
+    const int max = std::min(static_cast<int>(m_chooserWidgets.size()),
                              sender()->property(ID_PROPERTY_NAME).toInt());
     for (int i = 0; i < max; i++) {
         CKeyChooserWidget * const chooser = m_chooserWidgets.at(i);
@@ -258,10 +254,7 @@ void CBookKeyChooser::keyChooserChanged(int newIndex) {
         items.append(currentText);
     }
 
-    QString newKey("/");
-    newKey.append(items.join("/"));
-
-    m_key->setKey(newKey);
+    m_key->setKey('/' + items.join('/'));
     setKey(m_key);
 }
 
@@ -269,8 +262,3 @@ void CBookKeyChooser::keyChooserChanged(int newIndex) {
 void CBookKeyChooser::updateKey(CSwordKey * key) {
     setKey(key, false);
 }
-
-void CBookKeyChooser::setKey(const QString & newKey) {
-    m_key->setKey(newKey);
-    setKey(m_key);
-}
