@@ -2,22 +2,25 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTVERSEKEYMENU_H
-#define BTVERSEKEYMENU_H
+#pragma once
 
 #include <QMenu>
 
+#include <QObject>
+#include <QString>
+
 
 class QMouseEvent;
 class QTimerEvent;
+class QWidget;
 
 /**
 * Menu for book/ch/v dropdown lists.
@@ -33,13 +36,8 @@ class BtVerseKeyMenu : public QMenu {
         void mouseReleaseEvent(QMouseEvent* event) override;
         /** Frees the mouse button release after the delay has elapsed.*/
         void timerEvent(QTimerEvent* event) override;
-    private slots:
-        /** Starts the delay timer for the first mouse button release.*/
-        void startFirstClickDelayTimer();
 
     private:
         int m_timerId;
         bool m_firstClickLock;
 };
-
-#endif
