@@ -2,24 +2,28 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTINDEXDIALOG_H
-#define BTINDEXDIALOG_H
+#pragma once
 
 #include <QDialog>
 
+#include <QObject>
+#include <QString>
+#include <Qt>
+
 
 class QCheckBox;
 class QPushButton;
 class QTreeWidget;
 class QTreeWidgetItem;
+class QWidget;
 
 /**
 * This class encapsulates the "Manage search indices" page of the Bookshelf
@@ -30,24 +34,24 @@ class BtIndexDialog final: public QDialog {
 
     Q_OBJECT
 
-public: /* Methods: */
+public: // methods:
 
     BtIndexDialog(QWidget * parent = nullptr,
                   Qt::WindowFlags f = Qt::WindowFlags());
 
-private: /* Methods: */
+private: // methods:
 
     void populateModuleList();
     void retranslateUi();
 
-private slots:
+private Q_SLOTS:
 
     void autoDeleteOrphanedIndicesChanged(int newState);
     void slotSwordSetupChanged();
     void createIndices();
     void deleteIndices();
 
-private: /* Fields: */
+private: // fields:
 
     QCheckBox * m_autoDeleteOrphanedIndicesBox;
     QTreeWidget * m_moduleList;
@@ -59,5 +63,3 @@ private: /* Fields: */
     QTreeWidgetItem * m_modsWithoutIndices;
 
 };
-
-#endif /* BTINDEXDIALOG_H */
