@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -21,7 +21,6 @@
 #include <QLineEdit>
 #include <QPushButton>
 #include <QRadioButton>
-#include "../../backend/bookshelfmodel/btbookshelftreemodel.h"
 #include "../../backend/config/btconfig.h"
 #include "../../backend/drivers/btconstmoduleset.h"
 #include "../../backend/drivers/cswordmoduleinfo.h"
@@ -29,14 +28,13 @@
 #include "../../util/btconnect.h"
 #include "../../util/cresmgr.h"
 #include "../../util/tool.h"
-#include "../bibletimeapp.h"
 #include "btsearchmodulechooserdialog.h"
 #include "btsearchsyntaxhelpdialog.h"
 #include "crangechooserdialog.h"
 
 
 namespace {
-const QString SearchTypeKey = "GUI/SearchDialog/searchType";
+auto const SearchTypeKey = QStringLiteral("GUI/SearchDialog/searchType");
 } // anonymous namespace
 
 namespace Search {
@@ -125,10 +123,15 @@ void BtSearchOptionsArea::initView() {
     int tsLeft, tsTop, tsRight, tsBottom;
     // Added space looks nicer and enhances readability
     typeSelectorLayout->getContentsMargins(&tsLeft, &tsTop, &tsRight, &tsBottom);
-    typeSelectorLayout->setContentsMargins(tsLeft, 0, tsRight, tsBottom + util::tool::mWidth(this, 1) );
-    typeSelectorLayout->setSpacing(typeSelectorLayout->spacing() + util::tool::mWidth(this, 1));
+    typeSelectorLayout->setContentsMargins(
+        tsLeft,
+        0,
+        tsRight,
+        tsBottom + util::tool::mWidth(*this, 1));
+    typeSelectorLayout->setSpacing(typeSelectorLayout->spacing()
+                                   + util::tool::mWidth(*this, 1));
     QHBoxLayout* fullButtonLayout = new QHBoxLayout();
-    fullButtonLayout->setSpacing(util::tool::mWidth(this, 1) / 2);
+    fullButtonLayout->setSpacing(util::tool::mWidth(*this, 1) / 2);
     m_typeAndButton = new QRadioButton(tr("All words"));
     m_typeAndButton->setChecked(true);
     m_typeOrButton = new QRadioButton(tr("Some words"));
@@ -196,18 +199,43 @@ void BtSearchOptionsArea::initView() {
 }
 
 void BtSearchOptionsArea::initConnections() {
-    BT_CONNECT(m_searchTextCombo->lineEdit(), SIGNAL(returnPressed()),
-               this, SLOT(slotSearchTextEditReturnPressed()));
-    BT_CONNECT(m_chooseModulesButton, SIGNAL(clicked()),
-               this,                  SLOT(chooseModules()));
-    BT_CONNECT(m_chooseRangeButton, SIGNAL(clicked()),
-               this,                SLOT(setupRanges()));
-    BT_CONNECT(m_modulesCombo, SIGNAL(activated(int)),
-               this,           SLOT(moduleListTextSelected(int)));
-    BT_CONNECT(m_helpLabel, SIGNAL(linkActivated(QString)),
-               this,        SLOT(syntaxHelp()));
-    BT_CONNECT(m_searchTextCombo, SIGNAL(editTextChanged(QString const &)),
-               this,              SLOT(slotValidateText(QString const &)));
+    auto startSearch =
+            [this]{
+                m_searchTextCombo->addToHistory(
+                            m_searchTextCombo->currentText());
+                Q_EMIT sigStartSearch();
+            };
+    BT_CONNECT(m_searchButton, &QPushButton::clicked, startSearch);
+    BT_CONNECT(m_searchTextCombo->lineEdit(), &QLineEdit::returnPressed,
+               std::move(startSearch));
+    BT_CONNECT(m_chooseModulesButton, &QPushButton::clicked,
+               this,                  &BtSearchOptionsArea::chooseModules);
+    BT_CONNECT(m_chooseRangeButton, &QPushButton::clicked,
+               [this]{
+                   CRangeChooserDialog(getUniqueWorksList(), this).exec();
+                   refreshRanges();
+               });
+    BT_CONNECT(m_modulesCombo, qOverload<int>(&QComboBox::activated),
+               [this](int const index) {
+                   BtConstModuleList moduleList;
+                   for (auto const & name
+                        : m_modulesCombo->itemText(index).split(
+                            QStringLiteral(", ")))
+                       moduleList.append(
+                            CSwordBackend::instance().findModuleByName(name));
+                   // Set the list and the combobox list and text:
+                   setModules(moduleList);
+               });
+    BT_CONNECT(m_helpLabel, &QLabel::linkActivated,
+               [this]{
+                   auto * const dlg = new BtSearchSyntaxHelpDialog(this);
+                   dlg->setAttribute(Qt::WA_DeleteOnClose);
+                   dlg->show();
+               });
+    #if 0
+    BT_CONNECT(m_searchTextCombo, &CHistoryComboBox::editTextChanged,
+               this,              &BtSearchOptionsArea::slotValidateText);
+    #endif
 }
 
 /** Sets the modules used by the search. */
@@ -215,22 +243,18 @@ void BtSearchOptionsArea::setModules(const BtConstModuleList &modules) {
     QString t;
 
     m_modules.clear(); //remove old modules
-    BtConstModuleList::const_iterator end_it = modules.end();
-
-    for (BtConstModuleList::const_iterator it(modules.begin()); it != end_it; ++it) {
+    for (auto * const modulePtr : modules) {
         /// \todo Check for containsRef compat
-        if (*it == nullptr) { //don't operate on null modules.
+        if (!modulePtr) //don't operate on null modules.
             continue;
+        qDebug() << "new module:" << modulePtr->name();
+        if (!m_modules.contains(modulePtr)) {
+            m_modules.append(modulePtr);
+            t.append(modulePtr->name());
+            if (modulePtr != modules.last())
+                t += QStringLiteral(", "); // so that it will become a readable list (WLC, LXX, GerLut...)
         }
-        qDebug() << "new module:" << (*it)->name();
-        if ( !m_modules.contains(*it) ) {
-            m_modules.append( *it );
-            t.append( (*it)->name() );
-            if (*it != modules.last()) {
-                t += QString::fromLatin1(", "); // so that it will become a readable list (WLC, LXX, GerLut...)
-            }
-        }
-    };
+    }
     //m_modulesLabel->setText(t);
     int existingIndex = m_modulesCombo->findText(t);
     qDebug() << "index of the module list string which already exists in combobox:" << existingIndex;
@@ -250,54 +274,34 @@ void BtSearchOptionsArea::setModules(const BtConstModuleList &modules) {
     for (int i = 0; i < m_modulesCombo->count(); ++i) {
         historyList.append(m_modulesCombo->itemText(i));
     }
-    btConfig().setValue("history/searchModuleHistory", historyList);
-    emit sigSetSearchButtonStatus(!modules.isEmpty());
-}
-
-// Catch activated signal of module selector combobox
-void BtSearchOptionsArea::moduleListTextSelected(int index) {
-    //create the module list
-    QString text = m_modulesCombo->itemText(index);
-    QStringList moduleNamesList = text.split(", ");
-    BtConstModuleList moduleList;
-    Q_FOREACH(QString const & name, moduleNamesList)
-        moduleList.append(CSwordBackend::instance()->findModuleByName(name));
-    //set the list and the combobox list and text
-    setModules(moduleList);
+    btConfig().setValue(QStringLiteral("history/searchModuleHistory"),
+                        historyList);
 }
 
 QStringList BtSearchOptionsArea::getUniqueWorksList() {
     QSet<QString> moduleSet;
-    QStringList historyList = btConfig().value<QStringList>("history/searchModuleHistory", QStringList());
-    Q_FOREACH(const QString& value, historyList) {
-        QStringList moduleNamesList = value.split(", ");
-        Q_FOREACH(const QString& name, moduleNamesList) {
+    for (auto const & value
+         : btConfig().value<QStringList>(
+             QStringLiteral("history/searchModuleHistory")))
+        for (auto const & name : value.split(QStringLiteral(", ")))
             moduleSet.insert(name);
-        }
-    }
-    QStringList modules = moduleSet.values();
-    return modules;
+    return moduleSet.values();
 }
 
 void BtSearchOptionsArea::chooseModules() {
-    BtSearchModuleChooserDialog* dlg = new BtSearchModuleChooserDialog(this);
-    QSet<const CSwordModuleInfo *> moduleSet;
-    for (const CSwordModuleInfo * module:modules())
-        moduleSet.insert(module);
-    dlg->setCheckedModules(moduleSet);
-    if (dlg->exec() == QDialog::Accepted) {
-        BtConstModuleList ms;
-        Q_FOREACH(CSwordModuleInfo const * const m, dlg->checkedModules())
-            ms.append(m);
-        setModules(ms);
+    BtSearchModuleChooserDialog dlg(this);
+    auto & ms = modules();
+    dlg.setCheckedModules(QSet<CSwordModuleInfo const *>(ms.begin(), ms.end()));
+    if (dlg.exec() == QDialog::Accepted) {
+        auto const cms(dlg.checkedModules());
+        setModules(BtConstModuleList(cms.begin(), cms.end()));
     }
-    delete dlg;
 }
 
 void BtSearchOptionsArea::reset() {
-
-    QString currentSearchScope = btConfig().value<QString>("searchScopeCurrent");
-    int index = m_rangeChooserCombo->findText(currentSearchScope);
+    int index = m_rangeChooserCombo->findText(
+                    btConfig().value<QString>(
+                        QStringLiteral("searchScopeCurrent")));
     if (index >= 0)
         m_rangeChooserCombo->setCurrentIndex(index);
     else
@@ -306,8 +310,10 @@ void BtSearchOptionsArea::reset() {
 }
 
 void BtSearchOptionsArea::saveSettings() {
-    btConfig().setValue("searchScopeCurrent", m_rangeChooserCombo->currentText());
-    btConfig().setValue("properties/searchTexts", m_searchTextCombo->historyItems());
+    btConfig().setValue(QStringLiteral("searchScopeCurrent"),
+                        m_rangeChooserCombo->currentText());
+    btConfig().setValue(QStringLiteral("properties/searchTexts"),
+                        m_searchTextCombo->historyItems());
     CSwordModuleSearch::SearchType t = CSwordModuleSearch::FullType;
     if (m_typeAndButton->isChecked()) {
         t = CSwordModuleSearch::AndType;
@@ -319,17 +325,26 @@ void BtSearchOptionsArea::saveSettings() {
 }
 
 void BtSearchOptionsArea::readSettings() {
-    const QStringList texts = btConfig().value<QStringList>("properties/searchTexts", QStringList());
+    auto const texts =
+            btConfig().value<QStringList>(
+                QStringLiteral("properties/searchTexts"));
     //for some reason the slot was called when setting the upmost item
-    disconnect(m_searchTextCombo, SIGNAL(editTextChanged(const QString&)), this, SLOT(slotValidateText(const QString&)));
-    Q_FOREACH (const QString & text, texts) {
+    #if 0
+    disconnect(m_searchTextCombo, &CHistoryComboBox::editTextChanged,
+               this,              &BtSearchOptionsArea::slotValidateText);
+    #endif
+    for (auto const & text : texts)
         if (text.size() > 0)
             m_searchTextCombo->addItem(text);
-    }
-    BT_CONNECT(m_searchTextCombo, SIGNAL(editTextChanged(QString const &)),
-               this,              SLOT(slotValidateText(QString const &)));
+    #if 0
+    BT_CONNECT(m_searchTextCombo, &CHistoryComboBox::editTextChanged,
+               this,              &BtSearchOptionsArea::slotValidateText);
+    #endif
 
-    m_modulesCombo->insertItems(0, btConfig().value<QStringList>("history/searchModuleHistory", QStringList()));
+    m_modulesCombo->insertItems(
+                0,
+                btConfig().value<QStringList>(
+                    QStringLiteral("history/searchModuleHistory")));
     for (int i = 0; i < m_modulesCombo->count(); ++i) {
         m_modulesCombo->setItemData(i, m_modulesCombo->itemText(i), Qt::ToolTipRole);
     }
@@ -347,29 +362,10 @@ void BtSearchOptionsArea::readSettings() {
     }
 }
 
-void BtSearchOptionsArea::aboutToShow() {
-    m_searchTextCombo->setFocus();
-}
-
-void BtSearchOptionsArea::setupRanges() {
-    QStringList modules = getUniqueWorksList();
-    CRangeChooserDialog * chooser = new CRangeChooserDialog(modules, this);
-    chooser->exec();
-    delete chooser;
-
-    refreshRanges();
-}
-
-void BtSearchOptionsArea::syntaxHelp() {
-    BtSearchSyntaxHelpDialog * dlg = new BtSearchSyntaxHelpDialog(this);
-    dlg->setAttribute(Qt::WA_DeleteOnClose);
-    dlg->show();
-}
-
 void BtSearchOptionsArea::refreshRanges() {
     //the first option is fixed, the others can be edited using the "Setup ranges" button.
     m_rangeChooserCombo->clear();
-    m_rangeChooserCombo->insertItem(0, QString("[") + tr("No search scope") + QString("]"));
+    m_rangeChooserCombo->insertItem(0, tr("[No search scope]"));
     /// \todo what about this?
     //m_rangeChooserCombo->insertItem(tr("Last search result"));
 
@@ -389,19 +385,10 @@ sword::ListKey BtSearchOptionsArea::searchScope() {
     return sword::ListKey();
 }
 
-bool BtSearchOptionsArea::hasSearchScope() {
-    return (searchScope().getCount() > 0);
-}
-
 void BtSearchOptionsArea::addToHistory(const QString& text) {
     m_searchTextCombo->addToHistory(text);
 }
 
-void BtSearchOptionsArea::slotSearchTextEditReturnPressed() {
-    m_searchTextCombo->addToHistory( m_searchTextCombo->currentText() );
-    emit sigStartSearch();
-}
-
 bool BtSearchOptionsArea::eventFilter(QObject* obj, QEvent* event) {
     if (event->type() == QEvent::KeyPress || event->type() == QEvent::KeyRelease) {
         if (obj == m_searchTextCombo->view() || obj == m_searchTextCombo || obj == m_searchTextCombo->lineEdit()) {
@@ -414,32 +401,30 @@ bool BtSearchOptionsArea::eventFilter(QObject* obj, QEvent* event) {
     return QWidget::eventFilter(obj, event);
 }
 
-void BtSearchOptionsArea::slotValidateText(const QString& /*newText*/) {
-//     static const QRegExp re("\\b(AND|OR)\\b");
-//     if (newText.isEmpty() || !newText.contains(re) ) {
-//         if (!m_typeAndButton->isEnabled()) {
-//             m_typeOrButton->setEnabled(true);
-//             m_typeAndButton->setEnabled(true);
-//             m_typeAndButton->setToolTip(tr("All of the words (AND is added between the words)"));
-//             m_typeOrButton->setToolTip(tr("Some of the words"));
-//         }
-//     }
-//     else {
-//         if (m_typeAndButton->isEnabled()) {
-//             m_typeOrButton->setChecked(true);
-//             m_typeOrButton->setEnabled(false);
-//             m_typeAndButton->setEnabled(false);
-//             m_typeAndButton->setToolTip(tr("Full syntax is used because text includes AND or OR"));
-//             m_typeOrButton->setToolTip(tr("Full syntax is used because text includes AND or OR"));
-//         }
-//     }
+#if 0
+void BtSearchOptionsArea::slotValidateText(QString const & newText) {
+    static const QRegExp re("\\b(AND|OR)\\b");
+    if (newText.isEmpty() || !newText.contains(re)) {
+        if (!m_typeAndButton->isEnabled()) {
+            m_typeOrButton->setEnabled(true);
+            m_typeAndButton->setEnabled(true);
+            m_typeAndButton->setToolTip(
+                    tr("All of the words (AND is added between the words)"));
+            m_typeOrButton->setToolTip(tr("Some of the words"));
+        }
+    } else {
+        if (m_typeAndButton->isEnabled()) {
+            m_typeOrButton->setChecked(true);
+            m_typeOrButton->setEnabled(false);
+            m_typeAndButton->setEnabled(false);
+            m_typeAndButton->setToolTip(
+                    tr("Full syntax is used because text includes AND or OR"));
+            m_typeOrButton->setToolTip(
+                    tr("Full syntax is used because text includes AND or OR"));
+        }
+    }
 }
-
-//bool BtSearchOptionsArea::isAndSearchType()
-//{
-//
-//}
-
+#endif
 
 } // namespace Search
 
