@@ -2,22 +2,20 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTSEARCHOPTIONSAREA_H
-#define BTSEARCHOPTIONSAREA_H
+#pragma once
 
 #include <QWidget>
 
 #include "../../backend/cswordmodulesearch.h"
 #include "../../backend/drivers/btmodulelist.h"
-#include "../../backend/keys/cswordversekey.h"
 #include "chistorycombobox.h"
 
 
@@ -54,14 +52,10 @@ class BtSearchOptionsArea : public QWidget {
 
         CSwordModuleSearch::SearchType searchType();
 
-        inline QPushButton * searchButton() const { return m_searchButton; }
-
         /**
           Returns the list of used modules.
         */
-        inline const BtConstModuleList & modules() const {
-            return m_modules;
-        }
+        BtConstModuleList const & modules() const { return m_modules; }
 
         /**
         * Sets all options back to the default.
@@ -72,10 +66,17 @@ class BtSearchOptionsArea : public QWidget {
         */
         sword::ListKey searchScope();
 
-        bool hasSearchScope();
+        /**
+         * Opens the modules chooser dialog.
+         */
+        void chooseModules();
 
+        /**
+          Sets the modules used by the search.
+        */
+        void setModules(const BtConstModuleList &modules);
 
-    protected:
+    private: // methods:
         /**
         * Initializes this page.
         */
@@ -91,39 +92,24 @@ class BtSearchOptionsArea : public QWidget {
         void saveSettings();
         bool eventFilter(QObject* obj, QEvent* event) override;
 
-    public slots:
-        /**
-          Sets the modules used by the search.
-        */
-        void setModules(const BtConstModuleList &modules);
-        /**
-          Get unique works list from the Works combobox
-        */
-        QStringList getUniqueWorksList();
-        /** Sets the modules when user selects them from the combobox.*/
-        void moduleListTextSelected(int index);
-
-        /**
-        * Reimplementation.
-        */
-        void aboutToShow();
         /**
         * Refreshes the list of ranges and the range combobox.
         */
         void refreshRanges();
+
         /**
-         * Opens the modules chooser dialog.
-         */
-        void chooseModules();
+          Get unique works list from the Works combobox
+        */
+        QStringList getUniqueWorksList();
 
-    protected slots:
-        void setupRanges();
-        void syntaxHelp();
-        void slotSearchTextEditReturnPressed();
+    protected Q_SLOTS:
+
+        /// \todo Implement validation
+        #if 0
         void slotValidateText(const QString& newText);
+        #endif
 
-    signals:
-        void sigSetSearchButtonStatus(bool);
+    Q_SIGNALS:
         void sigStartSearch();
 
     private:
@@ -149,6 +135,3 @@ class BtSearchOptionsArea : public QWidget {
 };
 
 }
-
-
-#endif
