@@ -2,24 +2,21 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTSEARCHRESULTAREA_H
-#define BTSEARCHRESULTAREA_H
+#pragma once
 
 #include <QList>
 #include <QSplitter>
 #include <QStringList>
 #include <QWidget>
-#include "../../backend/managers/cswordbackend.h"
 #include "../../backend/cswordmodulesearch.h"
-#include "../display/creaddisplay.h"
 #include "analysis/csearchanalysisdialog.h"
 #include "../bttextbrowser.h"
 
@@ -29,8 +26,10 @@ class CModuleResultView;
 class CSearchResultView;
 }
 class CSwordModuleInfo;
+class QAction;
 class QFrame;
 class QHBoxLayout;
+class QMenu;
 class QTreeWidget;
 
 namespace Search {
@@ -49,62 +48,44 @@ namespace Search {
 *   To add a new verse to a strongs text result use addKeyName.
 */
 class StrongsResult {
-    public: /* Methods: */
-        inline StrongsResult() {}
-        inline StrongsResult(const QString &text,
-                             const QString &keyName)
+    public: // methods:
+        StrongsResult() {}
+        StrongsResult(QString const & text,
+                      QString const & keyName)
             : m_text(text)
         {
             m_keyNameList.append(keyName);
         }
 
         const QString &keyText() const { return m_text; }
-        inline int keyCount() const { return m_keyNameList.count(); }
-        inline void addKeyName(const QString &keyName) {
+        int keyCount() const { return m_keyNameList.count(); }
+        void addKeyName(QString const & keyName) {
             if (m_keyNameList.contains(keyName)) return;
             m_keyNameList.append(keyName);
         }
 
-        inline const QStringList &getKeyList() const { return m_keyNameList; }
+        QStringList const & getKeyList() const { return m_keyNameList; }
 
-    private: /* Fields: */
+    private: // fields:
         QString m_text;
         QStringList m_keyNameList;
 };
 
-/**
-* \todo Fix comment!
-* This class is used to keep track of the text strongs results.
-* It keeps track of all instances of all strongs text results.
-* This class makes use of the above class StrongsResult.
-*/
-class StrongsResultList: public QList<StrongsResult> {
-    public: /* Methods: */
-        StrongsResultList(const CSwordModuleInfo *module,
-                          const sword::ListKey &results,
-                          const QString &strongsNumber);
-
-    private: /* Methods: */
-        QString getStrongsNumberText(const QString &verseContent,
-                                     int &startIndex,
-                                     const QString &lemmaText);
-};
-
 
 /** The page of the search dialog which contains the search result part.
   * @author The BibleTime team
   */
 class BtSearchResultArea : public QWidget {
         Q_OBJECT
-    public: /* Methods: */
-        BtSearchResultArea(QWidget *parent = nullptr);
-        inline ~BtSearchResultArea() override { saveDialogSettings(); }
+    public: // methods:
+        BtSearchResultArea(QWidget * parent = nullptr);
+        ~BtSearchResultArea() override { saveDialogSettings(); }
 
         /**
         * Sets the modules which contain the result of each.
         */
-        void setSearchResult(
-            const CSwordModuleSearch::Results &results);
+        void setSearchResult(QString searchedText,
+                             CSwordModuleSearch::Results results);
 
         QSize sizeHint() const override {
             return baseSize();
@@ -114,22 +95,17 @@ class BtSearchResultArea : public QWidget {
             return minimumSize();
         }
 
-    public slots:
+    public Q_SLOTS:
         /**
         * Resets the current list of modules and the displayed list of found entries.
         */
         void reset();
 
-    protected: /* Methods: */
-        /**
-        * Initializes the view of this widget.
-        */
-        void initView();
+        /** Shows a dialog with the search analysis of the current search. */
+        void showAnalysis()
+        { CSearchAnalysisDialog(m_searchedText, m_results, this).exec(); }
 
-        /**
-        * Initializes the signal slot conections of the child widgets
-        */
-        void initConnections();
+    protected: // methods:
 
         /**
         * Load the settings from the resource file
@@ -143,7 +119,7 @@ class BtSearchResultArea : public QWidget {
 
         void setBrowserFont(const CSwordModuleInfo* const module);
 
-    protected slots:
+    protected Q_SLOTS:
         /**
         * Update the preview of the selected key.
         */
@@ -154,40 +130,30 @@ class BtSearchResultArea : public QWidget {
          */
         void clearPreview();
 
-        /**
-        * Shows a dialog with the search analysis of the current search.
-        */
-        inline void showAnalysis() {
-            CSearchAnalysisDialog(m_results, this).exec();
-        }
-
-        /**
-        * Select all text
-        */
-        inline void selectAll() { m_previewDisplay->selectAll(); }
-
         /**
         * Copy selected text
         */
-        inline void copySelection() {
+        void copySelection() {
             m_previewDisplay->copy();
         }
 
-        void slotContextMenu(const QPoint& point);
-
-    private: /* Fields: */
+    private: // fields:
+        QString m_searchedText;
         CSwordModuleSearch::Results m_results;
 
         CModuleResultView* m_moduleListBox;
         CSearchResultView* m_resultListBox;
 
         QFrame *m_displayFrame;
-        BtTextBrowser * m_previewDisplay;
+
+        QMenu * m_contextMenu;
+            QAction * m_selectAllAction;
+            QAction * m_copyAction;
+
+        BtTextBrowser* m_previewDisplay;
 
         QSplitter *m_mainSplitter;
         QSplitter *m_resultListSplitter;
 };
 
 } //namespace Search
-
-#endif
