@@ -2,19 +2,24 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CHISTORYCOMBOBOX_H
-#define CHISTORYCOMBOBOX_H
+#pragma once
 
 #include <QComboBox>
 
+#include <QObject>
+#include <QString>
+#include <QStringList>
+
+
+class QWidget;
 
 namespace Search {
 
@@ -22,7 +27,7 @@ class CHistoryComboBox : public QComboBox {
         Q_OBJECT
     public:
         CHistoryComboBox(QWidget* parent = nullptr);
-        ~CHistoryComboBox();
+        ~CHistoryComboBox() override;
         void addToHistory(const QString& item);
         QStringList historyItems() const;
 
@@ -32,5 +37,3 @@ class CHistoryComboBox : public QComboBox {
 };
 
 } //end of namespace Search
-
-#endif
