@@ -2,26 +2,26 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTFONTSETTINGS_H
-#define BTFONTSETTINGS_H
+#pragma once
 
 #include "btconfigdialog.h"
 
-#include <QWidget>
+#include <QObject>
+#include <QString>
 #include <vector>
 #include "../../backend/config/btconfig.h"
-#include "../../backend/managers/clanguagemgr.h"
 
 
 class CConfigurationDialog;
+class Language;
 class QCheckBox;
 class QComboBox;
 class QFontDialog;
@@ -32,29 +32,29 @@ class BtFontSettingsPage: public BtConfigDialog::Page {
 
         Q_OBJECT
 
-    private: /* Types: */
+    private: // types:
 
         struct WorkSetting {
-            CLanguageMgr::Language const & language;
+            Language const & language;
             BtConfig::FontSettingsPair settings;
         };
 
-    public: /* Methods: */
+    public: // methods:
 
         BtFontSettingsPage(CConfigurationDialog *parent = nullptr);
 
-        void save() const;
+        void save() const final override;
 
-    protected slots:
+    protected Q_SLOTS:
 
         // This slot is called when the "Use own font for language" button was clicked.
         void useOwnFontClicked(bool);
 
-    private: /* Methods: */
+    private: // methods:
 
         void retranslateUi();
 
-    private: /* Fields: */
+    private: // fields:
 
         QGroupBox *m_fontsGroupBox;
         QLabel *m_languageLabel;
@@ -65,5 +65,3 @@ class BtFontSettingsPage: public BtConfigDialog::Page {
         std::vector<WorkSetting> m_workSettings;
 
 };
-
-#endif
