@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,11 +13,14 @@
 #include "btshortcutsdialog.h"
 
 #include <QDialogButtonBox>
+#include <QFlags>
+#include <QFrame>
 #include <QGridLayout>
 #include <QKeyEvent>
 #include <QLabel>
 #include <QRadioButton>
 #include <QVBoxLayout>
+#include <memory>
 #include "../../util/btconnect.h"
 #include "../messagedialog.h"
 
@@ -25,46 +28,48 @@
 // *************** BtShortcutsDialog ***************************************************************************
 // A dialog to allow the user to input a shortcut for a primary and alternate key
 
-BtShortcutsDialog::BtShortcutsDialog(QWidget* parent)
-        : QDialog(parent), m_primaryLabel(nullptr), m_alternateLabel(nullptr), m_primaryButton(nullptr), m_alternateButton(nullptr) {
-    setWindowTitle(tr("Configure shortcuts"));
+BtShortcutsDialog::BtShortcutsDialog(QWidget * parent, Qt::WindowFlags f)
+    : QDialog(parent, f)
+{
     setMinimumWidth(350);
 
-    QVBoxLayout* vLayout = new QVBoxLayout(this);
-    setLayout(vLayout);
+    auto * const vLayout = new QVBoxLayout(this);
 
-    QGridLayout* gridLayout = new QGridLayout();
-    vLayout->addLayout(gridLayout);
+    {
+        auto gridLayout = std::make_unique<QGridLayout>();
 
-    QString dialogTooltip = tr("Select first or second shortcut and type the shortcut with keyboard");
+        m_primaryButton = new QRadioButton(this);
+        m_primaryButton->setChecked(true);
+        gridLayout->addWidget(m_primaryButton, 0, 0);
 
-    m_primaryButton = new QRadioButton(tr("First shortcut"));
-    m_primaryButton->setToolTip(dialogTooltip);
-    m_primaryButton->setChecked(true);
-    gridLayout->addWidget(m_primaryButton, 0, 0);
+        m_alternateButton = new QRadioButton(this);
+        gridLayout->addWidget(m_alternateButton, 1, 0);
 
-    m_alternateButton = new QRadioButton(tr("Second shortcut"));
-    m_alternateButton->setToolTip(dialogTooltip);
-    gridLayout->addWidget(m_alternateButton, 1, 0);
+        m_primaryLabel = new QLabel(this);
+        m_primaryLabel->setMinimumWidth(100);
+        m_primaryLabel->setFrameShape(QFrame::Panel);
+        gridLayout->addWidget(m_primaryLabel, 0, 1);
 
-    m_primaryLabel = new QLabel();
-    m_primaryLabel->setToolTip(dialogTooltip);
-    m_primaryLabel->setMinimumWidth(100);
-    m_primaryLabel->setFrameShape(QFrame::Panel);
-    gridLayout->addWidget(m_primaryLabel, 0, 1);
+        m_alternateLabel = new QLabel(this);
+        m_alternateLabel->setMinimumWidth(100);
+        m_alternateLabel->setFrameShape(QFrame::Panel);
+        gridLayout->addWidget(m_alternateLabel, 1, 1);
 
-    m_alternateLabel = new QLabel();
-    m_alternateLabel->setToolTip(dialogTooltip);
-    m_alternateLabel->setMinimumWidth(100);
-    m_alternateLabel->setFrameShape(QFrame::Panel);
-    gridLayout->addWidget(m_alternateLabel, 1, 1);
+        vLayout->addLayout(gridLayout.get());
+        gridLayout.release();
+    }
 
-    QDialogButtonBox* buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    auto * const buttons = new QDialogButtonBox(QDialogButtonBox::Ok
+                                                | QDialogButtonBox::Cancel,
+                                                this);
     message::prepareDialogBox(buttons);
+    BT_CONNECT(buttons, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    BT_CONNECT(buttons, &QDialogButtonBox::rejected, this, &QDialog::reject);
     vLayout->addWidget(buttons);
 
-    BT_CONNECT(buttons, SIGNAL(accepted()), this, SLOT(accept()));
-    BT_CONNECT(buttons, SIGNAL(rejected()), this, SLOT(reject()));
+    setLayout(vLayout);
+
+    retranslateUi();
 }
 
 // get new primary key from dialog
@@ -96,25 +101,41 @@ void BtShortcutsDialog::keyReleaseEvent(QKeyEvent* event) {
     QKeySequence keys(key);
     QString keyStr = keys.toString();
     if ( (event->modifiers() & Qt::AltModifier) == Qt::AltModifier)
-        keyStr = "Alt+" + keyStr;
+        keyStr = QStringLiteral("Alt+") + keyStr;
     if ( (event->modifiers() & Qt::ShiftModifier) == Qt::ShiftModifier)
-        keyStr = "Shift+" + keyStr;
+        keyStr = QStringLiteral("Shift+") + keyStr;
     if ( (event->modifiers() & Qt::ControlModifier) == Qt::ControlModifier)
-        keyStr = "Ctrl+" + keyStr;
+        keyStr = QStringLiteral("Ctrl+") + keyStr;
 
-    QKeySequence completeKeys(keyStr);
-    QString completeStr = completeKeys.toString();
-
-    keyChangeRequest(completeStr);
+    keyChangeRequest(keyStr);
 }
 
 // complete the keyChangeRequest
-void BtShortcutsDialog::changeSelectedShortcut(const QString& keys) {
+void BtShortcutsDialog::changeSelectedShortcut(QKeySequence const & keys) {
+    if (!m_primaryButton->isChecked() || !m_alternateButton->isChecked())
+        return;
+
+    auto const keysString(keys.toString());
     if (m_primaryButton->isChecked())
-        m_primaryLabel->setText(keys);
+        m_primaryLabel->setText(keysString);
 
     if (m_alternateButton->isChecked())
-        m_alternateLabel->setText(keys);
+        m_alternateLabel->setText(keysString);
 }
 
+void BtShortcutsDialog::retranslateUi() {
+    setWindowTitle(tr("Configure shortcuts"));
+    auto dialogTooltip = tr("Select first or second shortcut and type the "
+                            "shortcut with keyboard");
+
+    m_primaryButton->setText(tr("First shortcut"));
+    m_primaryButton->setToolTip(dialogTooltip);
+
+    m_alternateButton->setText(tr("Second shortcut"));
+    m_alternateButton->setToolTip(dialogTooltip);
+
+    m_primaryLabel->setToolTip(dialogTooltip);
+
+    m_alternateLabel->setToolTip(dialogTooltip);
+}
 
