@@ -2,22 +2,23 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTSTANDARDWORKSTAB_H
-#define BTSTANDARDWORKSTAB_H
+#pragma once
 
 #include <QWidget>
 
+#include <QObject>
+#include <QString>
+
 
 class CSwordSettingsPage;
-class QCheckBox;
 class QComboBox;
 class QLabel;
 
@@ -25,17 +26,17 @@ class BtStandardWorksTab: public QWidget {
 
     Q_OBJECT
 
-    public: /* Methods: */
+    public: // methods:
 
         BtStandardWorksTab(CSwordSettingsPage * parent);
 
         void save();
 
-    protected: /* Methods: */
+    protected: // methods:
 
         void retranslateUi();
 
-    private: /* Fields: */
+    private: // fields:
 
         QLabel * m_explanationLabel;
 
@@ -51,6 +52,5 @@ class BtStandardWorksTab: public QWidget {
         STANDARD_WORKS_TAB_FIELD(standardGreekStrongsLexicon);
         STANDARD_WORKS_TAB_FIELD(standardHebrewMorphLexicon);
         STANDARD_WORKS_TAB_FIELD(standardGreekMorphLexicon);
+#undef STANDARD_WORKS_TAB_FIELD
 };
-
-#endif /* BTSTANDARDWORKSTAB_H */
