@@ -2,19 +2,22 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTTEXTFILTERSTAB_H
-#define BTTEXTFILTERSTAB_H
+#pragma once
 
 #include <QWidget>
 
+#include <QObject>
+#include <QString>
+
+
 class CSwordSettingsPage;
 class QCheckBox;
 class QLabel;
@@ -24,17 +27,17 @@ class BtTextFiltersTab: public QWidget {
 
     Q_OBJECT
 
-    public: /* Methods: */
+    public: // methods:
 
         BtTextFiltersTab(CSwordSettingsPage * parent);
 
         void save();
 
-    protected: /* Methods: */
+    protected: // methods:
 
         void retranslateUi();
 
-    private: /* Fields: */
+    private: // fields:
 
         QLabel * m_explanationLabel;
 
@@ -50,5 +53,3 @@ class BtTextFiltersTab: public QWidget {
         TEXT_FILTERS_TAB_FIELD(scriptureReferences);
 
 };
-
-#endif /* BTTEXTFILTERSTAB_H */
