@@ -2,20 +2,21 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CDISPLAYSETTINGS_H
-#define CDISPLAYSETTINGS_H
+#pragma once
 
 #include "btconfigdialog.h"
 
-#include <QWidget>
+#include <QObject>
+#include <QString>
+#include <QVector>
 
 
 class CConfigurationDialog;
@@ -27,34 +28,35 @@ class CDisplaySettingsPage: public BtConfigDialog::Page {
 
         Q_OBJECT
 
-    public: /* Methods: */
+    public: // methods:
 
         CDisplaySettingsPage(CConfigurationDialog *parent = nullptr);
 
-        void save();
+        void save() const final override;
 
         static void resetLanguage();
 
-    protected: /* Methods: */
+    protected: // methods:
 
         void retranslateUi();
 
-    protected slots:
+    private Q_SLOTS:
         /** Update the style preview widget. */
         void updateStylePreview();
 
-    private: /* Methods: */
+    private: // methods:
 
         static QVector<QString> bookNameAbbreviationsTryVector();
         void initSwordLocaleCombo();
-        void updateColors(const QString& style = QString());
 
-    private: /* Fields: */
+    private: // fields:
 
         QLabel* m_showLogoLabel;
         QCheckBox* m_showLogoCheck;
         QLabel *m_languageNamesLabel;
         QComboBox* m_swordLocaleCombo;
+        QLabel* m_lightDarkLabel;
+        QComboBox* m_lightDarkCombo;
         QLabel *m_transifexLabel;
         QComboBox* m_styleChooserCombo;
         QLabel *m_availableLabel;
@@ -62,5 +64,3 @@ class CDisplaySettingsPage: public BtConfigDialog::Page {
         QLabel *m_previewLabel;
 
 };
-
-#endif
