@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -12,9 +12,9 @@
 
 #include "cswordsettings.h"
 
+#include <QTabWidget>
 #include <QVBoxLayout>
 #include "../../util/cresmgr.h"
-#include "../bibletimeapp.h"
 #include "btstandardworkstab.h"
 #include "bttextfilterstab.h"
 #include "cconfigurationdialog.h"
@@ -46,7 +46,7 @@ void CSwordSettingsPage::retranslateUi() {
     m_tabWidget->setTabText(m_tabWidget->indexOf(m_filtersTab), tr("Text filters"));
 }
 
-void CSwordSettingsPage::save() {
+void CSwordSettingsPage::save() const {
     m_worksTab->save();
     m_filtersTab->save();
 }
