@@ -2,46 +2,45 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef CSWORDSETTINGS_H
-#define CSWORDSETTINGS_H
+#pragma once
 
 #include "btconfigdialog.h"
 
-#include <QWidget>
+#include <QObject>
+#include <QString>
 
 
 class BtTextFiltersTab;
 class CConfigurationDialog;
 class BtStandardWorksTab;
+class QTabWidget;
 
 class CSwordSettingsPage: public BtConfigDialog::Page {
 
         Q_OBJECT
 
-    public: /* Methods: */
+    public: // methods:
 
         CSwordSettingsPage(CConfigurationDialog * parent = nullptr);
 
-        void save();
+        void save() const final override;
 
-    protected: /* Methods: */
+    protected: // methods:
 
         void retranslateUi();
 
-    private: /* Fields: */
+    private: // fields:
 
         QTabWidget * m_tabWidget;
         BtStandardWorksTab * m_worksTab;
         BtTextFiltersTab * m_filtersTab;
 
 };
-
-#endif
