@@ -2,9 +2,9 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
@@ -13,47 +13,61 @@
 #include "bttipdialog.h"
 
 #include <QCheckBox>
+#include <QColor>
 #include <QDesktopServices>
 #include <QDialogButtonBox>
+#include <QFlags>
+#include <QFont>
 #include <QHBoxLayout>
+#include <QPalette>
 #include <QPushButton>
+#include <QSizePolicy>
 #include <QTextBrowser>
 #include <QVBoxLayout>
+#include <QWidget>
 #include "../../backend/config/btconfig.h"
 #include "../../util/btconnect.h"
 #include "../../util/bticons.h"
 #include "../../util/cresmgr.h"
-#include "../../util/directory.h"
-#include "../bibletimeapp.h"
 #include "../messagedialog.h"
 
 
+class QUrl;
+
 namespace {
 
 inline QString vertical_align(const QString &text) {
-    return "<table height=\"100%\"><tr><td style=\"vertical-align:middle\" "
-            "height=\"100%\">" + text + "</td></tr></table>";
+    return QStringLiteral(
+                "<table height=\"100%\"><tr>"
+                "<td style=\"vertical-align:middle\" height=\"100%\">%1</td>"
+                "</tr></table>").arg(text);
 }
 
 inline QString make_style(QWidget *widget) {
-    const QPalette &p = widget->palette();
-    return "<style type=\"text/css\">"
-        "body{"
-            "background-color:" + p.color(QPalette::Base).name() + ";"
-            "color:" + p.color(QPalette::Text).name() + "}"
-        "h3{font-weight:bold;text-align:center}"
-        "a{text-decoration:underline}"
-        "a:link{color:" + p.color(QPalette::Link).name() + "}"
-        "a:visited{color:" + p.color(QPalette::LinkVisited).name() + "}"
-    "</style>";
+    auto const & p = widget->palette();
+    return QStringLiteral(
+                "<style type=\"text/css\">"
+                    "body{"
+                        "background-color:%1;"
+                        "color:%2"
+                    "}"
+                    "h3{font-weight:bold;text-align:center}"
+                    "a{text-decoration:underline}"
+                    "a:link{color:%3}"
+                    "a:visited{color:%4}"
+                "</style>")
+            .arg(p.color(QPalette::Base).name(),
+                 p.color(QPalette::Text).name(),
+                 p.color(QPalette::Link).name(),
+                 p.color(QPalette::LinkVisited).name());
 }
 
 inline QString make_html(QWidget *widget, const QString &text) {
-    return "<html><head>" + make_style(widget) + "</head><body>"
-            + vertical_align(text) + "</body></html>";
+    return QStringLiteral("<html><head>%1</head><body>%2</body></html>")
+            .arg(make_style(widget), vertical_align(text));
 }
 
-const QString LastTipNumberKey = "GUI/lastTipNumber";
+auto const LastTipNumberKey = QStringLiteral("GUI/lastTipNumber");
 
 } // anonymous namespace
 
@@ -71,7 +85,8 @@ BtTipDialog::BtTipDialog(QWidget *parent, Qt::WindowFlags wflags)
     m_tipView = new QTextBrowser(this);
     m_tipView->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     m_tipView->setOpenExternalLinks(true);
-    m_tipView->setStyleSheet("QTextEdit { background-color: rgb(255, 255, 255) }");
+    m_tipView->setStyleSheet(
+                QStringLiteral("QTextEdit{background-color:rgb(255,255,255)}"));
     QFont font = m_tipView->font();
     font.setPointSize(font.pointSize()+2);
     m_tipView->setFont(font);
@@ -81,8 +96,9 @@ BtTipDialog::BtTipDialog(QWidget *parent, Qt::WindowFlags wflags)
 
     m_showTipsCheckBox = new QCheckBox;
     m_showTipsCheckBox->setText(tr("Show tips at startup"));
-    bool showTips = btConfig().value<bool>("GUI/showTipAtStartup", true);
-    m_showTipsCheckBox->setChecked(showTips);
+    m_showTipsCheckBox->setChecked(
+                btConfig().value<bool>(QStringLiteral("GUI/showTipAtStartup"),
+                                       true));
     hLayout->addWidget(m_showTipsCheckBox);
 
     m_buttonBox = new QDialogButtonBox(QDialogButtonBox::Close,
@@ -98,21 +114,24 @@ BtTipDialog::BtTipDialog(QWidget *parent, Qt::WindowFlags wflags)
     mainLayout->addLayout(hLayout);
     setLayout(mainLayout);
 
-    BT_CONNECT(m_showTipsCheckBox, SIGNAL(toggled(bool)),
-               this,               SLOT(startupBoxChanged(bool)));
-    BT_CONNECT(m_buttonBox, SIGNAL(rejected()),
-               this,        SLOT(reject()));
-    BT_CONNECT(nextButton, SIGNAL(clicked()),
-               this,       SLOT(nextTip()));
-    BT_CONNECT(m_tipView, SIGNAL(anchorClicked(QUrl const &)),
-               this,              SLOT(linkClicked(QUrl const &)));
+    BT_CONNECT(m_showTipsCheckBox, &QCheckBox::toggled,
+               [](bool v) { btConfig().setValue("GUI/showTipAtStartup", v); });
+    BT_CONNECT(m_buttonBox, &QDialogButtonBox::rejected,
+               this,        &BtTipDialog::reject);
+    BT_CONNECT(nextButton, &QPushButton::clicked,
+               [this]{
+                   m_tipNumber = (m_tipNumber + 1) % m_tips.size();
+                   btConfig().setValue(LastTipNumberKey, m_tipNumber);
+                   displayTip();
+               });
+    BT_CONNECT(m_tipView, &QTextBrowser::anchorClicked,
+               [](QUrl const & url) { QDesktopServices::openUrl(url); });
 
     m_tipNumber = btConfig().value<int>(LastTipNumberKey, 0);
-    initTips();
-    displayTip();
+    retranslateUi();
 }
 
-void BtTipDialog::initTips() {
+void BtTipDialog::retranslateUi() {
     m_tips.clear();
 
     m_tips << tr("The currently active window can be auto scrolled up or down."
@@ -132,7 +151,7 @@ void BtTipDialog::initTips() {
         + "<br><center>" + iconToHtml(CResMgr::modules::commentary::icon_add()) + "</center>";
 
     m_tips << tr("To learn more about the BibleTime project please go to our web site.")
-        + "<br><center><a href=\"http://www.bibletime.info\">www.bibletime.info</a></center>";
+        + "<br><center><a href=\"https://bibletime.info\">bibletime.info</a></center>";
 
     m_tips << tr("To synchronize a commentary window with the active Bible window, activate the"
         " commentary window and select this icon.") + "<br><center>"
@@ -174,25 +193,9 @@ void BtTipDialog::initTips() {
     m_tips << tr("You can save your open windows in a session. Such a session can easily be restored"
         " later on. You can save as many sessions as you like. The session feature can be"
         " accessed under the Window menu entry.");
-}
 
-void BtTipDialog::displayTip() {
-    m_tipView->setHtml(make_html(this, m_tips[m_tipNumber]));
-}
-
-void BtTipDialog::startupBoxChanged(bool checked) {
-    btConfig().setValue("GUI/showTipAtStartup", checked);
-}
-
-void BtTipDialog::nextTip() {
-    m_tipNumber++;
-    if (m_tipNumber >= m_tips.count()) {
-        m_tipNumber = 0;
-    }
-    btConfig().setValue(LastTipNumberKey, m_tipNumber);
     displayTip();
 }
 
-void BtTipDialog::linkClicked(const QUrl& url) {
-    QDesktopServices::openUrl(url);
-}
+void BtTipDialog::displayTip()
+{ m_tipView->setHtml(make_html(this, m_tips[m_tipNumber])); }
