@@ -2,16 +2,15 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef BTICONS_H
-#define BTICONS_H
+#pragma once
 
 #include <QIcon>
 #include <QString>
@@ -20,38 +19,38 @@
 
 class BtIcons {
 
-public: /* Types: */
+public: // types:
 
     class RegularIcon: public QIcon {
 
-    public: /* Methods: */
+    public: // methods:
 
-        RegularIcon(char const * const name);
+        RegularIcon(QString const & name);
 
     };
 
     class OverlayedIcon: public QIcon {
 
-    public: /* Methods: */
+    public: // methods:
 
         OverlayedIcon(QIcon const & icon, QIcon const & overlayedIcon);
 
     };
 
-public: /* Methods: */
+public: // methods:
 
     BtIcons();
 
-    static inline BtIcons & instance() { 
+    static BtIcons & instance() {
         BT_ASSERT(m_instance);
-        return *m_instance; 
+        return *m_instance;
     }
 
-private: /* Fields: */
+private: // fields:
 
     static BtIcons * m_instance;
 
-public: /* Fields: */
+public: // fields:
 
     QIcon const icon_null;
 
@@ -146,5 +145,3 @@ public: /* Fields: */
 };
 
 QString iconToHtml(QIcon const & icon, int const extent = 32);
-
-#endif /* BTICONS_H */
