@@ -2,17 +2,15 @@
 *
 * In the name of the Father, and of the Son, and of the Holy Spirit.
 *
-* This file is part of BibleTime's source code, http://www.bibletime.info/
+* This file is part of BibleTime's source code, https://bibletime.info/
 *
-* Copyright 1999-2020 by the BibleTime developers.
+* Copyright 1999-2025 by the BibleTime developers.
 * The BibleTime source code is licensed under the GNU General Public License
 * version 2.0.
 *
 **********/
 
-#ifndef MACROS_H
-#define MACROS_H
-
+#pragma once
 
 /**
   \file macros.h
@@ -45,6 +43,3 @@
     #define LIKELY(c)   !!(c)
     #define UNLIKELY(c) !!(c)
 #endif
-
-
-#endif // #ifdef MACROS_H
